# 1 "advection2.F"
c =====================================================================
c
c     SUBROUTINE ADVECTION2
c 
c     PURPOSE: this routine calculates the contribution of the
c                  advection to the mixed layer budget. Only executed
c                  if sol_scheme is 'adv', it also computes the horizontal
c                  velocity u to close the budget
c                  
c
c     VARIABLES:
c 
c     IN : k              : time loop counter
c          ts             : time step
c          sol_scheme     : solution scheme
c          dc_dh          : horizontal C gradient
c          ddc13_dh       : horizontal dC13 gradient
c          c              : obs c concentration
c          c13            : obs c13 concentraton
c          h              : obs mixed layer depth
c     
c
c     OUT: u              : horizontal velocity
c          D_C            : modified array holding the rates of change for C
c          D_C13          : modified array holding the rates of change for C13
c          fluxes         : modified array holding the fluxes
c 
c     REVISION:
c
c     date     author  remarks
c   
c     17.10.99   ng    first implementation, based on advection.F
c     05.05.02   ng    set u to 0 in case dc_dh = 0

c =====================================================================
c
      subroutine advection2(k,ts,sol_scheme,
     $     dc_dh,dc13_dh,
     $     c,c13,h,
     $     u_var,D_C,D_c13,fluxes)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 49 "advection2.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 50 "advection2.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 51 "advection2.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 52 "advection2.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/input.h" 1
c======================== include file input.h  =============================
c
c input data for the seasonal model, stemming from the harmonic 
c      regression (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp        dp s  mixed layer temperature                       deg C
c sal         dp s  mixed layer salinity                          psu
c ws          dp s  wind-speed                                    m s-1
c fCO2_o      dp s  CO2 fugacity in the mixed layer               uatm
c pco2_a      dp s  pCO2 in the atmosphere                        ppm
c dc13_a      dp s  dC13 in the atmosphere                        per mil
c dCdz_var    dp s  vertical C gradient below the mixed layer   umol/kg/m
c kz_var      dp s  vertical diffusion coefficient                m2 s-1
c salk        dp s  salinity normalized alkalinity              umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp,sal,ws,fCO2_o,pco2_a,dc13_a
      double precision dCdz_var,kz_var,salk


# 53 "advection2.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 54 "advection2.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/c13_params.h" 1
cc=================== include file c13_params.h =============================
c
c parameters for C13 and dC13
c
c REVISIONS:
c
c date     author    remarks
c
c 2.08.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c r_Std          dp  s  C13/C12 ratio of PDB standard
c rstar_Std      dp  s  C13/(C12+C13) ratio of PDB standard
c
c---------------------------------------------------------------------------
c
      double precision r_std,rstar_std
      parameter (r_std = 0.0112372d0, rstar_std = 0.011112328d0)



# 55 "advection2.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/solution.h" 1
c================== include file solution.h =========================
c
c variables for sensitivity analysis
c
c REVISIONS:
c
c date     author    remarks
c
c 21.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c 
c u_var           dp a   inverse calculated horizontal velocity m s-1
c 
c===========================================================================
c
      double precision u_var(nstepmax)
# 56 "advection2.F" 2
      integer k
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
      double precision rates_to_fluxes ! functions
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      integer i
      double precision sec_day, day_year
      double precision sum_c
      parameter (sec_day = 24.d0 * 3600.d0)
      parameter (day_year = 365.)

c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c --------------------------------------------------------------------
c     calculate horizontal velocity
c --------------------------------------------------------------------
c 
      sum_c = 0.d0
      do i = 1,3
         sum_c = sum_c + D_C(i,k)
      enddo
      sum_c = sum_c + D_C(5,k)
      if (dc_dh .ne. 0.d0) then
         u_var(k) = - ((D_C(7,k) - sum_c)/dc_dh) 
     $        / (ts * sec_day * day_year) ! gives m s-1
      else
          u_var(k) = 0.0d0
       endif
         
c     
c --------------------------------------------------------------------
c     calculate rate of change and fluxes due to advection
c       multiply with ts and sec_day because u is given in m s-1
c       17.10.99 ng added day_year since ts is in years
c     do this only for old standard solution scheme
c --------------------------------------------------------------------
c
      D_C(4,k) = - u_var(k) * dc_dh * ts * sec_day * day_year
      fluxes(4,k) = rates_to_fluxes(D_C(4,k),ts,h)
      D_c13(4,k) = - u_var(k) * dc13_dh * ts * sec_day * day_year
c      
c --------------------------------------------------------------------
c     for debugging purposes
c --------------------------------------------------------------------
c
# 126 "advection2.F"

c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

