# 1 "assign_params.F"
c =====================================================================
c
c     SUBROUTINE ASSIGN_PARAMS
c 
c     PURPOSE: assigns and deassigns parameters for optimization,
c                monte carlo analysis and sensitivity tests.
c              action is determined by the value of the logical
c              variable assign.
c
c     VARIABLES:
c
c     IN : assign        : logical variable specifying action
c                             <TRUE>  assign variables to paramets p
c                             <FALSE> assign parameters to variables
c                        
c     IN/OUT: 
c          gasex_fact      : value of gasexchange factor
c          sg_gasex_fact   : 1-sg uncertainty of gasexchange factor
c          D_fco2_corr     : value of correction term for fCO2 ocean
c          sg_D_fco2_corr  : 1-sg uncertainty of correction term for fCO2 ocean
c          diff_fact       : value of diffusion factor
c          sg_diff_fact    : 1-sg uncertainty of diffusion factor
c          D_dcdz          : value of correction term for dcdz
c          sg_D_dcdz       : 1-sg uncertainty of correction term for dcdz
c          ddC13_dC_bml    : value of ratio of vertical dC13 and C gradients
c          sg_ddC13_dC_bml : 1-sg uncertainty of ratio of vertical dC13 and 
c                                C gradients
c          const_lent      : logical specifyin if lent is constant or not
c          lent_const      : value of constant entrainment length
c          sg_lent_const   : 1-sg uncertainty of constant entrainment length
c          dlent_dh        : value of slope of entrainment length with h
c          sg_dlent_dh     : 1-sg uncertainty of slope of entrainment 
c                                length with h
c          D_dc13_org      : value of correction term for dC13org
c          sg_D_dc13_org   : 1-sg uncertainty  of correction term for dC13org
c          u               : value of horizontal adv velocity
c          sg_u            : 1-sg uncertainty of horizontal adv velocity
c          dc_dh           : value of horizontal C gradient
c          sg_dc_dh        : 1-sg uncertainty of horizontal C gradient
c          ddC13_dh        : value of horizontal dC13 gradient
c          sg_ddC13_dh     : 1-sg uncertainty of horizontal dC13 gradient
c         
c          p               : value of parameters
c          sg_p            : 1-sg uncertainty of parameters
c          p_init          : initial value of parameters
c          
c
c     REVISION:
c
c     date     author  remarks
c   
c     11.09.96   ng    first implementation
c
c =====================================================================
c
      subroutine assign_params(
     $     assign,
     $     gasex_fact, sg_gasex_fact,D_fco2_corr,sg_D_fco2_corr,
     $     diff_fact,sg_diff_fact,D_dcdz,sg_D_dcdz,
     $     ddC13_dC_bml,sg_ddC13_dC_bml,
     $     const_lent,lent_const,sg_lent_const,dlent_dh,sg_dlent_dh,   
     $     D_dc13_org,sg_D_dc13_org, 
     $     u,sg_u,dc_dh,sg_dc_dh,ddC13_dh,sg_ddC13_dh,   
     $     p,sg_p,p_init)          
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 73 "assign_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/gasex_params.h" 1
c===================== include file gasex_params.h =========================
c
c parameters of air-sea exchange
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 06.6.00  ng        added comp_foc2_online
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c 
c pv_relship     c  s   character indicating the relationship between
c                       piston velocity and wind-speed that is used for
c                       calculating the piston-velocity
c                           <lm> : Liss and Merlivat
c                           <wa> : Wanninkhof  
c D_fco2_corr    dp s   correction term for calculated fCO2 ocean     [uatm]
c gasex_fact     dp s   multiplication factor for air-sea exchange
c                           usually 1.0 for Wanninkhof
c                           usually 1.7447 for Liss and Merlivat
c
c ws_coeff       c  s   character specifying wind speed coefficients
c                           <ih> : Isemer and Hasse, 1985
c                           <ae> : AEROCE, 1989-1991
c
c sg_D_fco2_corr dp a   uncertainty of D_fco2_corr
c sg_gasex_fact  dp a   uncertainty of gasex_fact
c
c mean_air_press dp s   mean air pressure [atm] (from St. Davids head)
c mean_rel_humid dp s   mean relative humidity [] (from St. Davids head)
c 
c comp_fco2_online l s  logical indicating whether fco2 should be
c                         computed on or offline
c
c===========================================================================
c
      character pv_relship*2,ws_coeff*2
      double precision D_fco2_corr,gasex_fact
      double precision sg_D_fco2_corr, sg_gasex_fact
c
      double precision mean_air_press,mean_rel_humid




      parameter (mean_air_press = 1.017,mean_rel_humid = 0.87)

c
      logical comp_fco2_online
# 74 "assign_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 75 "assign_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 76 "assign_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncp_params.h" 1
c===================== include file ncp_params.h =========================
c
c parameters of net community production
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c D_dC13_org      dp s   correction term for dC13 value of organic matter
c dc13_org        dp s   dc13 value of organic matter
c                         [per mil]
c sg_D_dc13_org   dp s   1 sigma uncertainty of D_dc13_org (for OP and MC)
c 
c=============================================================================
c
      double precision D_dc13_org
      double precision sg_D_dc13_org
      double precision dc13_org
# 77 "assign_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/conj_grad.h" 1
c===================== include file conj_grad.h =========================
c
c variables for finding minimum using conjugate gradient technique
c
c REVISIONS:
c
c date     author    remarks
c
c 12.8.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c     
c assign         l  s   logical for subroutine assign_parameters
c                        true : assign values to parameters
c                        false: assign parameters to values   
c p             dp  a   array of parameters
c p_opt         dp  a   array of optimum parameters
c sg_p          dp  a   sigma of parameters
c p_init        dp  a   array of initial parameters
c nparams        i  s   dimension of parameters
c npmax          i  s   maximum dimension of p
c iter           i  s   number of iterations
c fret          dp  s   value of function at minimum
c hessian       dp  a   hessian matrix
c covm          dp  a   inverse of hessian matrix, covariance matrix
c
c sg_c          dp  s   1-sigma uncertainty of C [umol kg-1]
c sg_dcdt       sp  s   1-sigma uncertainty of dcdt [umol kg-1 day-1]
c                          (estimated from figure)
c
c===========================================================================
c
      logical assign
      double precision ftol,fret
      integer nruns
      integer nparams,iter


      parameter(nparams = 10)










      double precision p(nparams),p_opt(nparams),p_init(nparams)
      double precision sg_p(nparams)
      double precision hessian(nparams,nparams),covm(nparams,nparams)
c
      
# 78 "assign_params.F" 2
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
c      
c =====================================================================
c     begin of executable code
c =====================================================================
c
      if (assign) then
c
         write(*,*) '--ASSIGN_PARAMS: assigning parameters...'
c
c --------------------------------------------------------------------
c     assign variables to parameters
c       normalize them with
c       the formula p' = (p - p_init)/sigma
c --------------------------------------------------------------------
c     

         p(1) = gasex_fact
         p(2) = D_fco2_corr
         p(3) = diff_fact
         p(4) = D_dcdz  
         p(5) = ddC13_dC_bml
         if (const_lent) then
            p(6) = lent_const
         else
            p(6) = dlent_dh
         endif
         p(7) = D_dc13_org
         p(8) = u

         p(9) = dc_dh
         p(10) = ddC13_dh

         sg_p(1) = sg_gasex_fact
         sg_p(2) = sg_D_fco2_corr
         sg_p(3) = sg_diff_fact
         sg_p(4) = sg_D_dcdz
         sg_p(5) = sg_ddC13_dC_bml
         if (const_lent) then
            sg_p(6) = sg_lent_const
         else
            sg_p(6) = sg_dlent_dh
         endif
         sg_p(7) = sg_D_dc13_org
         sg_p(8) = sg_u

         sg_p(9) = sg_dc_dh
         sg_p(10) = sg_ddC13_dh

c
c
# 161 "assign_params.F"

c
c --------------------------------------------------------------------
c     assign parameters to variables
c --------------------------------------------------------------------
c     
      else
         write(*,*) '--ASSIGN_PARAMS: deassigning parameters...'

         gasex_fact   =  sg_p(1)*p(1) + p_init(1)
         D_fco2_corr  =  sg_p(2)*p(2) + p_init(2)
         diff_fact    =  sg_p(3)*p(3) + p_init(3)
         D_dcdz       =  sg_p(4)*p(4) + p_init(4)
         ddC13_dC_bml =  sg_p(5)*p(5) + p_init(5)
         if (const_lent) then
            lent_const   =  sg_p(6)*p(6) + p_init(6)
         else
            dlent_dh     =  sg_p(6)*p(6) + p_init(6)
         endif
         D_dc13_org   =  sg_p(7)*p(7) + p_init(7)
         u            =  sg_p(8)*p(8) + p_init(8)

         dC_dh        =  sg_p(9)*p(9) + p_init(9)
         ddC13_dh     =  sg_p(10)*p(10) + p_init(10)

# 198 "assign_params.F"

      endif
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

