# 1 "calc_int_val.F"
c =====================================================================
c
c     SUBROUTINE CALC_INT_VAL
c 
c     PURPOSE: this routine calculates the integrated rates of change
c              and fluxes over the different periods
c
c     VARIABLES:
c
c     IN : D_c        : rates of change of C
c          D_c13      : rates of change of C13
c          fluxes     : fluxes of C
c          tstart     : start time of integration
c          tend       : end time of integration
c          ts         : time step
c          nstep      : number of steps
c 
c     OUT: Int_Fluxes : two dim array holding the integrated Fluxes of
c                          the different processes during the
c                          different periods
c          Int_Rates  : two dim array holding the integrated Rates of
c                          change of the different processes during the
c                          different periods
c          nyears     : number of analysis years
c
c     REVISION:
c
c     date     author  remarks
c   
c      3.08.96   ng    first implementation
c     17.10.99   ng    adapting for interannual var. runs, changed time
c                        time from days to years.
cc
c =====================================================================
c
      subroutine calc_int_val(D_c,D_c13,fluxes,tstart,tend,ts,nstep,
     $     int_fluxes,int_rates,nyears)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 46 "calc_int_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 47 "calc_int_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 48 "calc_int_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 49 "calc_int_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 50 "calc_int_val.F" 2
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      integer ny,i,k,iyr

      double precision rho,sec_day,day_year
      parameter (rho = 1026.2d0,sec_day = 24.d0 * 3600.d0)
      parameter (day_year = 365.d0)
c
      integer nstep_yr(nyearmax)
c
      double precision eps
      parameter(eps = 1.d-8)

c =====================================================================
c     begin of executable code
c =====================================================================
c
c      write(*,*) '--CALC_INT_VAL : calculating integrated values...'
c
c --------------------------------------------------------------------
c     make sure that all integrated values are set to zero
c      at the beginning
c --------------------------------------------------------------------
c        
      do ny = 1,nyearmax
         do i = 1,nproc_fluxes
            int_fluxes(ny,i) = 0.0d0
         enddo
         do i = 1,nproc_rates
            int_rates(ny,i) = 0.0d0
         enddo
      enddo
c
c --------------------------------------------------------------------
c     determine the number of analysis years 
c --------------------------------------------------------------------
c        
      nyears = dint(tend - tstart)
c
c --------------------------------------------------------------------
c     set the numbers of time steps in an analysis year to zero
c --------------------------------------------------------------------
c        
      do ny = 1,nyearmax
         nstep_yr(ny) = 0
      enddo
c
c --------------------------------------------------------------------
c     loop over all timesteps
c --------------------------------------------------------------------
c        
      time = tstart
c
      do k = 1,nstep
c
c --------------------------------------------------------------------
c     determine analysis year
c      add a little eps (small number) because of inexact addition
c      operation
c      keep track of how many time steps there are in an analysis year
c --------------------------------------------------------------------
c        
         iyr = dint(time + eps - tstart - year_start) + 1
         nstep_yr(iyr) = nstep_yr(iyr) + 1
c         if (abs(time - nint(time)) .le. 0.0025) then
c            write(*,*) '--CALC_INT_VAL, time = ',time
c            write(*,*) '  iyr,nstep_yr(iyr) = ',iyr,nstep_yr(iyr)
c         endif
c
c --------------------------------------------------------------------
c     calculate integrated rates of change (no unit conversion yet)
c       here (umol/kg)
c     no need to multiply with ts, because D_C denotes just Delta_C
c       and not Delta_C/Delta_t
c --------------------------------------------------------------------
c        
         do i = 1,nproc_rates
            int_rates(iyr,i) = int_rates(iyr,i) + D_C(i,k)
         enddo
c
c --------------------------------------------------------------------
c     calculate integrated fluxes
c     here ts must be included to get integral, because fluxes
c      are in mol m-2 s-1
c --------------------------------------------------------------------
c        
         do i = 1,nproc_fluxes
            int_fluxes(iyr,i) = int_fluxes(iyr,i) 
     $           + fluxes(i,k) * ts * sec_day * day_year
         enddo
c
c --------------------------------------------------------------------
c     increase time
c --------------------------------------------------------------------
c        
         time = time + ts
c
c --------------------------------------------------------------------
c     end of loop over all timesteps
c --------------------------------------------------------------------
c        
      enddo
c
c --------------------------------------------------------------------
c     give info
c --------------------------------------------------------------------
c        
c      write(*,*)
c      write(*,*) '--CALC_INT_VAL: number of analysis years : ',nyears
c      write(*,*) '        number of steps in each of these years: '
c      do ny = 1,nyears
c         write(*,*) '            year = ',ny, '  # steps = ',
c     $        nstep_yr(ny)
c      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

