# 1 "calc_mc_statistics.F"
c =====================================================================
c
c     SUBROUTINE CALC_MC_STATISTICS
c 
c     PURPOSE: this routine calculates the final statistics of the
c                monte carlo simulations
c
c     VARIABLES:
c
c     IN : nrun            : number of Monte Carlo runs
c          int_rates_std   : integrated rates of standard run
c          int_fluxes_std  : integrated fluxes of standard run
c          nyears          : number of analysis years
c          costfn_std      : costfn of standard run
c          var_int_rates   : variance of int_rates
c          var_int_fluxes  : variance of int_fluxes
c          wvar_int_rates  : weighted variance of int_rates
c          wvar_int_fluxes : weighted variance of int_fluxes
c          sum_costfn      : sum of cost function
c          mc_d_c          : resampled d_c results of mc runs
c          mc_fluxes       : resampled fluxes results of mc runs
c          mc_c_sim        : resampled c_sim results of mc runs
c          mc_weight       : weight of mc run i
c          nstep2          : number of samples in mc* arrays
c                          
c     OUT: sg_int_rates    : 1-sigma uncertainty of int_rates
c          sg_int_fluxes   : 1-sigma uncertainty of int_fluxes
c          wsg_int_rates   : weighted 1-sigma uncertainty of int_rates
c          wsg_int_fluxes  : weighted 1-sigma uncertainty of int_fluxes
c          mean_costfn     : mean costfunction
c          mean_d_c        : mean d_c of mc runs
c          mean_fluxes     : mean fluxes of mc runs
c          mean_c_sim      : mean c_sim of mc runs
c          wmean_d_c       : weighted mean d_c of mc runs
c          wmean_fluxes    : weighted mean fluxes of mc runs
c          wmean_c_sim     : weighted mean c_sim of mc runs
c          sg_d_c          : 1-sg uncertainty of d_c
c          sg_fluxes       : 1-sg uncertainty of fluxes
c          sg_c_sim        : 1-sg uncertainty of c_sim
c          wsg_d_c         : weighted 1-sg uncertainty of d_c
c          wsg_fluxes      : weighted 1-sg uncertainty of fluxes
c          wsg_c_sim       : weighted 1-sg uncertainty of c_sim
c
c     REVISION:
c
c     date     author  remarks
c   
c     16.08.96   ng    first implementation
c     20.08.96   ng    included weighted and unweighted means and sigmas
c     18.10.99   ng    adapted for interannual variability runs
c
c =====================================================================
c
      subroutine calc_mc_statistics(nrun,     
     $     int_rates_std,int_fluxes_std,nyears,costfn_std,
     $     var_int_rates,var_int_fluxes,
     $     wvar_int_rates,wvar_int_fluxes,
     $     sum_costfn,
     $     mc_D_c,mc_fluxes,mc_c_sim,mc_weight,nstep2,
     $     sg_int_rates,sg_int_fluxes,
     $     wsg_int_rates,wsg_int_fluxes,
     $     mean_costfn,
     $     mean_d_c,mean_fluxes,mean_c_sim,
     $     wmean_d_c,wmean_fluxes,wmean_c_sim,
     $     sg_d_c,sg_fluxes,sg_c_sim,
     $     wsg_d_c,wsg_fluxes,wsg_c_sim)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 75 "calc_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 76 "calc_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 77 "calc_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 78 "calc_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/statistics.h" 1
c==================== include file statistics.h ==============================
c
c variables for the run statistics
c
c REVISIONS:
c
c date     author    remarks
c
c 08.8.96  ng        first implementation
c 05.9.96  ng        included c_min,c_max,c_min_obs,c_max_obs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c chisq         dp s   chi**2 between simulated and observed rate of change
c rsq           dp s   r**2 of fit between simulated and observed rates
c closure       dp s   annual lack of closure
c amplitude     dp s   simulated annual amplitude
c amplitude_obs dp s   observed annual amplitude
c c_min         dp s   simulated minimum C
c c_max         dp s   simulated maximum C
c c_min_obs     dp s   observed minimum C
c c_max_obs     dp s   observed maximum C
c par_sum       dp s   value of parameter misfit
c costfn        dp s   value of cost function
c chisq_term    dp s   value of chi**2 term in cost function
c clos_term     dp s   value of closure term in cost function
c ampl_term     dp s   value of amplitude term in cost function
c par_term      dp s   value of parameter term in cost function
c
c-------------------------------------------------------------------------
c
      double precision chisq,rsq,closure,costfn,amplitude
      double precision amplitude_obs,par_sum
      double precision c_min,c_max,c_min_obs,c_max_obs
      double precision chisq_term,clos_term,ampl_term,par_term



# 79 "calc_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/monte_carlo.h" 1
c===================== include file monte_carlo.h =========================
c
c general variables for monte carlo simulations
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c  
c nrunmax       i  s   maximal number of mc runs             
c nrun          i  s   number of mc runs
c
c *_r          dp  s   parameters with a random component added. size of
c                        random component is proportional to sg of this
c                        parameter. For the parameter definitions see
c                        the *_params.h files 
c 
c
c===========================================================================
c
      integer nrunmax,nrun
      parameter(nrunmax = 2000)
      
      double precision gasex_fact_r,D_fco2_corr_r
      double precision diff_fact_r,D_dcdz_r,ddC13_dC_bml_r,lent_const_r
      double precision dlent_dh_r
      double precision D_dc13_org_r
      double precision u_r,dc_dh_r,ddc13_dh_r
c
# 80 "calc_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_statistics.h" 1
c================== include file mc_statistics.h =========================
c
c variables of statistics of monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c  
c int_rates_std   dp a   array holding standard integrated rates
c int_fluxes_std  dp a   array holding standard integrated fluxes
c costfn_std      dp s   value of cost function for standard run
c rsq_std         dp s   r**2 value for standard run
c chisq_std       dp s   chi**2 value for standard run
c amplitude_std   dp s   amplitude of standard run
c c_min_std       dp s   minimum C of standard run
c c_max_std       dp s   maximum C of standard run
c
c var_int_rates   dp a   array holding variance of integrated rates 
c                            (over monte carlo runs)
c var_int_fluxes  dp a   array holding variance of integrated fluxes
c wvar_int_rates  dp a   array holding weighted variance of integrated rates 
c                                 (over monte carlo runs)
c wvar_int_fluxes dp a   array holding weighted variance of integrated fluxes
c sum_costfn      dp s   sum of cost function
c mean_costfn     dp s   mean of cost function
c costfn_min      dp s   minimum of cost function
c costfn_max      dp s   maximum of cost function
c 
c sg_int_rates    dp s   1-sigma uncertainty of int_rates
c sg_int_fluxes   dp s   1-sigma uncertainty of int_fluxes
c wsg_int_rates   dp s   1-sigma weighted uncertainty of int_rates
c wsg_int_fluxes  dp s   1-sigma weighted uncertainty of int_fluxes
c 
c===========================================================================
c
      double precision int_rates_std(nyearmax,nproc_rates)
      double precision int_fluxes_std(nyearmax,nproc_fluxes)
      double precision costfn_std
      double precision closure_std,rsq_std,chisq_std,amplitude_std
      double precision c_min_std,c_max_std
c
      double precision var_int_rates(nyearmax,nproc_rates)
      double precision var_int_fluxes(nyearmax,nproc_fluxes)
      double precision wvar_int_rates(nyearmax,nproc_rates)
      double precision wvar_int_fluxes(nyearmax,nproc_fluxes)
c   
      double precision sg_int_rates(nyearmax,nproc_rates)
      double precision sg_int_fluxes(nyearmax,nproc_fluxes)
      double precision wsg_int_rates(nyearmax,nproc_rates)
      double precision wsg_int_fluxes(nyearmax,nproc_fluxes)
c
      double precision sum_costfn,mean_costfn
      double precision costfn_min,costfn_max
c

# 81 "calc_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_plot_slabs.h" 1
c================== include file mc_plot_slabs.h =========================
c
c variables that contain plot information for monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c
c variables:
c
c name                type   description
c---------------------------------------------------------------------------
c  		      
c nstepmax2           i  s   maximum number of values on time axis
c nstep               i  s   number of resampled values
c rsmpl_step          i  s   every i'th sample is resampled
c mc_D_c              dp a   array of resampled D_C array for mc analysis
c mc_fluxes           dp a   array of resampled fluxes array for mc analysis
c mc_c_sim            dp a   array of resampled c_sim array for mc analysis
c mc_u_var            dp a   array of resampled inverse calc u
c mc_ddc13_dh_var     dp a   array of resampled inverse calc ddC13_dh
c mean_D_c            dp a   mean D_C of mc runs
c mean_fluxes         dp a   mean fluxes of mc runs
c mean_c_sim          dp a   mean c_sim of mc runs
c mean_u_var          dp a   mean u_var
c mean_ddc13_dh_var   dp a   mean ddc13_dh_var
c wmean_D_c           dp a   weighted mean D_C of mc runs
c wmean_fluxes        dp a   weighted mean fluxes of mc runs
c wmean_c_sim         dp a   weighted mean c_sim of mc runs
c wmean_u_var         dp a   weighted mean u_var
c wmean_ddc13_dh_var  dp a   weighted mean ddc13_dh_var
c sg_D_c              dp a   1-sg uncertainty of D_C
c sg_fluxes           dp a   1-sg uncertainty of fluxes
c sg_c_sim            dp a   1-sg uncertainty of c_sim
c sg_u_var            dp a   1-sg uncertainty of u_var
c sg_ddc13_dh_var     dp a   1-sg uncertainty of ddc13_dh_var
c wsg_D_c             dp a   weighted 1-sg uncertainty of D_C
c wsg_fluxes          dp a   weighted 1-sg uncertainty of fluxes
c wsg_c_sim           dp a   weighted 1-sg uncertainty of c_sim
c wsg_u_var           dp a   weighted 1-sg uncertainty of u_var
c wsg_ddc13_dh_var    dp a   weighted 1-sg uncertainty of ddc13_dh_var
c c_sim_std           dp a   array holding c_sim of standard simulation
c fluxes_std          dp a   array holding fluxes of standard simulation
c d_c_std             dp a   array holding d_c of standard simulation
c u_var_std           dp a   array holding inv. calc. u of std simulation
c ddc13_dh_std        dp a   array holding inv. calc. ddc13_dh of std sim.
c
c                                 to the different proc.                mol C/m2/s
c D_C_std_runavg    dp a   one year running standard Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_std_runavg dp a   one year running standard Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
cc 
c===========================================================================
c
      integer nstepmax2,nstep2,rsmpl_step
      parameter(nstepmax2 = 200)
c
      double precision mc_D_c(nrunmax,nproc_rates,nstepmax2)
      double precision mc_fluxes(nrunmax,nproc_fluxes,nstepmax2)
      double precision mc_c_sim(nrunmax,nstepmax2)
      double precision mean_D_c(nproc_rates,nstepmax2)
      double precision mean_fluxes(nproc_fluxes,nstepmax2)
      double precision mean_c_sim(nstepmax2)
      double precision wmean_D_c(nproc_rates,nstepmax2)
      double precision wmean_fluxes(nproc_fluxes,nstepmax2)
      double precision wmean_c_sim(nstepmax2)
      double precision sg_D_c(nproc_rates,nstepmax2)
      double precision sg_fluxes(nproc_fluxes,nstepmax2)
      double precision sg_c_sim(nstepmax2)
      double precision wsg_D_c(nproc_rates,nstepmax2)
      double precision wsg_fluxes(nproc_fluxes,nstepmax2)
      double precision wsg_c_sim(nstepmax2)
      double precision mc_weight(nrunmax)
      double precision c_sim_std(nstepmax)
      double precision d_c_std(nproc_rates,nstepmax)
      double precision fluxes_std(nproc_fluxes,nstepmax)
c
      double precision mc_u_var(nrunmax,nstepmax2)
      double precision mc_ddc13_dh_var(nrunmax,nstepmax2)
      double precision mean_u_var(nstepmax2)
      double precision mean_ddc13_dh_var(nstepmax2)
      double precision wmean_u_var(nstepmax2)
      double precision wmean_ddc13_dh_var(nstepmax2)
      double precision sg_u_var(nstepmax2)
      double precision sg_ddc13_dh_var(nstepmax2)
      double precision wsg_u_var(nstepmax2)
      double precision wsg_ddc13_dh_var(nstepmax2)
      double precision u_var_std(nstepmax)
      double precision ddc13_dh_var_std(nstepmax)
c
      double precision fluxes_std_runavg(nproc_fluxes,nstepmax), 
     $     D_C_std_runavg(nproc_rates,nstepmax)
      double precision mean_d_c_runavg(nproc_rates,nstepmax2),
     $        sg_D_c_runavg(nproc_rates,nstepmax2),       
     $        mean_fluxes_runavg(nproc_fluxes,nstepmax2),
     $        sg_fluxes_runavg(nproc_fluxes,nstepmax2)   

# 82 "calc_mc_statistics.F" 2

c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      integer i,j,k,nr
      double precision sum,wsum,ws
c      
c =====================================================================
c     begin of executable code
c =====================================================================
c
c      write(*,*) '--CALC_MC_STATISTICS: calculating monte carlo',
c     $     ' statistics...'
c
c --------------------------------------------------------------------
c     calculate standard deviation, first calculate variance
c --------------------------------------------------------------------
c
      if (nrun .gt. 1) then
         do i = 1,nyears
            do j = 1,nproc_rates
               var_int_rates(i,j) = var_int_rates(i,j)/
     $              float(nrun-1)
               sg_int_rates(i,j) = dsqrt(var_int_rates(i,j))
               wvar_int_rates(i,j) = wvar_int_rates(i,j)/
     $              float(nrun-1)
               wsg_int_rates(i,j) = dsqrt(wvar_int_rates(i,j))
            enddo
            do j = 1,nproc_fluxes
               var_int_fluxes(i,j) = var_int_fluxes(i,j)/
     $              float(nrun-1)
               sg_int_fluxes(i,j) = dsqrt(var_int_fluxes(i,j))
               wvar_int_fluxes(i,j) = wvar_int_fluxes(i,j)/
     $              float(nrun-1)
               wsg_int_fluxes(i,j) = dsqrt(wvar_int_fluxes(i,j))
            enddo
         enddo
      else
         sg_int_rates(i,j)   = -99.99
         wsg_int_rates(i,j)  = -99.99
         sg_int_fluxes(j,i)  = -99.99
         wsg_int_fluxes(j,i) = -99.99
      endif
c
c ---------------------------------------------------------------------
c     for debugging
c ---------------------------------------------------------------------
c
      do i=1,nyears
         write(*,*) (sg_int_fluxes(i,j),j=1,nproc_fluxes)
      enddo
c
c --------------------------------------------------------------------
c     calculate mean cost function
c --------------------------------------------------------------------
c      
      mean_costfn = sum_costfn / float(nrun)
c
c ---------------------------------------------------------------------
c     calculate plot averages of runs
c ---------------------------------------------------------------------
c
c      write(*,*) 'rates...'
      do i=1,nproc_rates
         do k = 1,nstep2
            sum = 0.d0
            wsum = 0.d0
            ws = 0.d0
            do nr = 1,nrun
               sum = sum + mc_d_c(nr,i,k)
               wsum = wsum + mc_d_c(nr,i,k)*mc_weight(nr)
               ws = ws + mc_weight(nr)
            enddo
c
            mean_d_c(i,k) = sum/float(nrun)
            wmean_d_c(i,k) = wsum/ws
         enddo
      enddo
c
c      write(*,*) 'fluxes...'
      do i=1,nproc_fluxes
         do k = 1,nstep2
            sum = 0.d0
            wsum = 0.d0
            ws = 0.d0
            do nr = 1,nrun
               sum = sum + mc_fluxes(nr,i,k)
               wsum = wsum + mc_fluxes(nr,i,k)*mc_weight(nr)
               ws = ws + mc_weight(nr)
            enddo
c
            mean_fluxes(i,k) = sum/float(nrun)
            wmean_fluxes(i,k) = wsum/ws
         enddo
      enddo
c      
c      write(*,*) 'c sim...'
      do k = 1,nstep2
         sum = 0.d0
         wsum = 0.d0
         ws = 0.d0
         do nr = 1,nrun
            sum = sum + mc_c_sim(nr,k)
            wsum = wsum + mc_c_sim(nr,k)*mc_weight(nr)
            ws = ws + mc_weight(nr)
         enddo
c
         mean_c_sim(k) = sum/float(nrun)
         wmean_c_sim(k) = wsum/ws
      enddo
c
c --------------------------------------------------------------------
c     for debugging
c --------------------------------------------------------------------
c 
c      do nr = 1,nrun
c         write(*,*) '--CALC_MC_STATISTICS : mc run # ',nr
c         write(*,*) '   mc_c_sim(nr,k=1,10) : ',
c     $        (mc_c_sim(nr,k),k=1,10)
c      enddo
c      write(*,*) 'mean_c_sim(k=1,10) : ',(mean_c_sim(k),k=1,10)
c      write(*,*) 'wmean_c_sim(k=1,10) : ',(wmean_c_sim(k),k=1,10)
c
c
c ---------------------------------------------------------------------
c     calculate standard deviations
c ---------------------------------------------------------------------
c
c      write(*,*) 'rates...'
      do i=1,nproc_rates
         do k = 1,nstep2
            sum = 0.d0
            wsum = 0.d0
            ws = 0.d0
            do nr = 1,nrun
               sum = sum +
     $              (mc_d_c(nr,i,k)-mean_d_c(i,k))**2
               wsum = wsum + 
     $              ((mc_d_c(nr,i,k)-mean_d_c(i,k))*mc_weight(nr))**2
            enddo
            sg_d_c(i,k) = dsqrt(sum/float(nrun-1))
            wsg_d_c(i,k) = dsqrt(wsum/float(nrun-1))
         enddo
      enddo
c
c      write(*,*) 'fluxes...'
      do i=1,nproc_fluxes
         do k = 1,nstep2
            sum = 0.d0
            wsum = 0.d0
            ws = 0.d0
            do nr = 1,nrun
               sum = sum +
     $              (mc_fluxes(nr,i,k)-mean_fluxes(i,k))**2
               wsum = wsum + 
     $              ((mc_fluxes(nr,i,k)-mean_fluxes(i,k))
     $              *mc_weight(nr))**2
            enddo
            sg_fluxes(i,k) = dsqrt(sum/float(nrun-1))
            wsg_fluxes(i,k) = dsqrt(wsum/float(nrun-1))
         enddo
      enddo
c
c      write(*,*) 'c_sim...'
      do k = 1,nstep2
         sum = 0.d0
         wsum = 0.d0
         ws = 0.d0
         do nr = 1,nrun
            sum = sum +
     $           (mc_c_sim(nr,k)-mean_c_sim(k))**2
            wsum = wsum + 
     $           ((mc_c_sim(nr,k)-mean_c_sim(k))*mc_weight(nr))**2
         enddo
         sg_c_sim(k) = dsqrt(sum/float(nrun-1))
         wsg_c_sim(k) = dsqrt(wsum/float(nrun-1))
      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

