# 1 "calc_run_stat.F"
c =====================================================================
c
c     SUBROUTINE CALC_RUN_STAT
c 
c     PURPOSE: this routine calculates the chi**2 and other statitical
c                variables that describe the behaviour of the model
c                run
c
c     VARIABLES:
c
c     IN : D_c           : rates of change of C
c          c_sim         : simulated seasonal cycle of C
c          c_obs         : observed seasonal cycle of C
c          tstart        : start time
c          tend          : end time
c          ts            : time step
c          nstep         : number of steps
c          sol_scheme    : solution scheme
c          sum_dc13_prc  : sum of dc13 values of processes
c          nsum_dc13_prc : number of values used for summing sum_dc13_prc
c          sum_fract     : sum for calc of avg fractionation factor
c          sum_kex       : sum for calc of avg kex
c                        
c     OUT: dc13_prc      : dc13 values of processes
c          chisq         : chi**2 of rate of change
c          rsq           : r**2 of rate of change
c          closure       : difference between end and beginning of year
c          amplitude     : calculated amplitude between min and max
c          amplitude_obs : observed amplitude between min and max
c          c_min         : value of minimum C
c          c_max         : value of maximum C
c          c_min_obs     : value of observed minimum C
c          c_max_obs     : value of observed maximum C
c          costfn        : value of cost function
c
c     REVISION:
c
c     date     author  remarks
c   
c      3.08.96   ng    first implementation
c     14.08.96   ng    included costfn, amplitude, amplitude_obs
c      5.09.96   ng    adapted to new version of cost function
c     16.12.96   ng    included avg_kex
c     10.06.97   ng    included preprocessor option reviewer_costfn,
c                        (calculates chisq as deviations from C rather
c                         than D_C)
c     17.10.99   ng    adapting for interannual variability runs
c
c
c =====================================================================
c
      subroutine calc_run_stat(D_C,c_sim,c_obs,tstart,tend,ts,nstep,
     $     sol_scheme,
     $     sum_dc13_prc,nsum_dc13_prc,sum_fract,sum_kex,
     $     dc13_prc,avg_fract,avg_kex,
     $     chisq,rsq,closure,amplitude,amplitude_obs,
     $     c_min,c_max,c_min_obs,c_max_obs,
     $     costfn)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 67 "calc_run_stat.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 68 "calc_run_stat.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 69 "calc_run_stat.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 70 "calc_run_stat.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/statistics.h" 1
c==================== include file statistics.h ==============================
c
c variables for the run statistics
c
c REVISIONS:
c
c date     author    remarks
c
c 08.8.96  ng        first implementation
c 05.9.96  ng        included c_min,c_max,c_min_obs,c_max_obs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c chisq         dp s   chi**2 between simulated and observed rate of change
c rsq           dp s   r**2 of fit between simulated and observed rates
c closure       dp s   annual lack of closure
c amplitude     dp s   simulated annual amplitude
c amplitude_obs dp s   observed annual amplitude
c c_min         dp s   simulated minimum C
c c_max         dp s   simulated maximum C
c c_min_obs     dp s   observed minimum C
c c_max_obs     dp s   observed maximum C
c par_sum       dp s   value of parameter misfit
c costfn        dp s   value of cost function
c chisq_term    dp s   value of chi**2 term in cost function
c clos_term     dp s   value of closure term in cost function
c ampl_term     dp s   value of amplitude term in cost function
c par_term      dp s   value of parameter term in cost function
c
c-------------------------------------------------------------------------
c
      double precision chisq,rsq,closure,costfn,amplitude
      double precision amplitude_obs,par_sum
      double precision c_min,c_max,c_min_obs,c_max_obs
      double precision chisq_term,clos_term,ampl_term,par_term



# 71 "calc_run_stat.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/sg_params.h" 1
c===================== include file sg_params.h =========================
c
c variables defining special uncertainties
c
c REVISIONS:
c
c date     author    remarks
c
c 13.8.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c sg_c          dp  s   1-sigma uncertainty of C [umol kg-1]
c sg_dcdt       sp  s   1-sigma uncertainty of dcdt [umol kg-1 day-1]
c                          (estimated from figure)
c
c===========================================================================
c
      double precision sg_c,sg_dcdt
      parameter(sg_c = 2.d0, sg_dcdt = 0.02d0)
      
# 72 "calc_run_stat.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 73 "calc_run_stat.F" 2
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      double precision sum,var,mean
      double precision obs_min,obs_max,sim_min,sim_max
      integer k,i
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
      double precision cost_function
c      
c =====================================================================
c     begin of executable code
c =====================================================================
c
c      write(*,*) '--CALC_RUN_STAT : calculating run statistics...'
c
c --------------------------------------------------------------------
c     calculate mean dc13_prc
c --------------------------------------------------------------------
c        
      do i = 1,4
         if (nsum_dc13_prc(i) .ne. 0) then
            dc13_prc(i) = sum_dc13_prc(i) / 
     $           dble(float(nsum_dc13_prc(i)))
         else
            dc13_prc(i) = -99.99
         endif
      enddo
c
c --------------------------------------------------------------------
c     calculate mean fract_fact
c --------------------------------------------------------------------
c        
      avg_fract = sum_fract / dble(float(nstep))
c
c --------------------------------------------------------------------
c     calculate mean kex
c --------------------------------------------------------------------
c        
      avg_kex = sum_kex / dble(float(nstep))
c
c --------------------------------------------------------------------
c     do detailed analysis for fit in case of standard solution scheme
c --------------------------------------------------------------------
c  
      if (sol_scheme .eq. 'std') then
c
c --------------------------------------------------------------------
c     initialize start values
c --------------------------------------------------------------------
c        
         chisq = 0.d0
         sum = 0.d0
         var = 0.d0
c
c --------------------------------------------------------------------
c     loop over all timesteps, calculate chi**2 and sum for mean
c --------------------------------------------------------------------
c
         do k = 1,nstep




            chisq = chisq + (D_C(6,k)-D_C(7,k))**2
            sum = sum + D_C(7,k)

         enddo
c
c --------------------------------------------------------------------
c     calculate mean D_C(7,k): should be zero over 365 days
c --------------------------------------------------------------------
c        
         mean = sum/dble(float(nstep))
c
c --------------------------------------------------------------------
c     calculate variance
c --------------------------------------------------------------------
c        
        do k = 1,nstep



            var = var + ((C_sim(k) - mean))**2

        enddo
c
c --------------------------------------------------------------------
c     calculate r2; r2 = (1 - chi2/var), where
c        var = sum(yi-y_mean)**2 ; variance
c --------------------------------------------------------------------
c
        if (var .ne. 0.0) then
           rsq = 1. - chisq/var
        else
           rsq = 1.
        endif
c
c --------------------------------------------------------------------
c     calculate annual closure [umol/kg]
c --------------------------------------------------------------------
c 
        if ((tend - tstart) .ge. 365.d0) then  ! doesn't work with ia
           k = int(365.d0/ts)
           closure = C_sim(k) - C_sim(1)
        else
           closure = -99.99
        endif
c
c --------------------------------------------------------------------
c     calculate amplitude
c --------------------------------------------------------------------
c 
         sim_max = -9.99e30
         sim_min =  9.99e30
         obs_max = -9.99e30
         obs_min =  9.99e30
c     
         do k = 1,nstep
            if (c_sim(k) .gt. sim_max) then
               sim_max = c_sim(k)
            endif
            if (c_sim(k) .lt. sim_min) then
               sim_min = c_sim(k)
            endif
            if (c_obs(k) .gt. obs_max) then
               obs_max = c_obs(k)
            endif
            if (c_obs(k) .lt. obs_min) then
               obs_min = c_obs(k)
            endif
         enddo
c     
         amplitude = sim_max - sim_min
         amplitude_obs = obs_max - obs_min
         c_min = sim_min
         c_max = sim_max
         c_min_obs = obs_min
         c_max_obs = obs_max
c
c      write(*,*) 'amplitude,amplitude_obs : ',amplitude,amplitude_obs
c
c --------------------------------------------------------------------
c     calculate cost function (without parameter terms)
c --------------------------------------------------------------------
c 
         par_sum = 0.d0
c     
         costfn = cost_function(chisq,closure,par_sum,0,
     $         amplitude,amplitude_obs,
     $         c_min,c_max,c_min_obs,c_max_obs,
     $         chisq_term,clos_term,par_term,ampl_term)
c     
c --------------------------------------------------------------------
c     end of detailed analysis for 'std' solution scheme
c --------------------------------------------------------------------
c     
      endif
c     
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c   
      return
      end

