# 1 "compute_anomalies.F"
c =====================================================================
c
c     SUBROUTINE compute_anomalies
c
c     PURPOSE: computes the anomalies of the rates and fluxes
c     
c
c     VARIABLES:
c 
c     IN:  tstart          : start time of integration
c          tend            : end time of integration
c          ts              : time step
c          nstep           : number of steps
c          D_C             : rates of change
c          fluxes          : fluxes
c
c
c
c     OUT: D_C_avg         : average timeseries of dC/dt
c          D_C_anom        : anomaly timeseries of dC/dt
c          fluxes_avg      : average timeseries of fluxes
c          fluxes_anom     : anomaly timeseries of fluxes
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     08.06.00   ng     first implementation
c 
c =====================================================================
c
      subroutine compute_anomalies(tstart,tend,ts,nstep,
     $        D_C,fluxes,
     $        D_C_avg,D_C_anom,fluxes_avg,fluxes_anom)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 42 "compute_anomalies.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 43 "compute_anomalies.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 44 "compute_anomalies.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 45 "compute_anomalies.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/anomalies.h" 1
c======================= include file averages.h ==============================
c
c variables that store anomalies
c
c REVISIONS:
c
c date     author    remarks
c
c 08.06.00 ng        first implementation
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c 
c D_C_avg         dp a   average Delta C due to the different proc.       muM/kg/ts
c D_C_anom        dp a   anomalies of Delta C                             muM/kg/ts   
c fluxes_avg      dp a   average Flux of DIC due to the different proc.   mol C/m2/s
c fluxes_anom     dp a   anomalies of Delta C                             mol C/m2/s
c D_C_a_runavg    dp a   365 days running anomalies of Delta C            muM/kg/ts   
c fluxes_a_runavg dp a   365 days running anomalies of fluxes             mol C/m2/s 
c
c-------------------------------------------------------------------------
c
      double precision D_C_avg(nproc_rates,nstepmax)
      double precision D_C_anom(nproc_rates,nstepmax)
      double precision fluxes_avg(nproc_fluxes,nstepmax)
      double precision fluxes_anom(nproc_fluxes,nstepmax)
      double precision D_C_a_runavg(nproc_rates,nstepmax)
      double precision fluxes_a_runavg(nproc_fluxes,nstepmax)
# 46 "compute_anomalies.F" 2
c
      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer k,i,k2
      integer nstep_per_year
      integer nsum(nstepmax)
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c --------------------------------------------------------------------
c     determine the number of timesteps per year
c --------------------------------------------------------------------
c     
      nstep_per_year = int(1.d0/ts)
c
      write(*,*) '--COMPUTE_ANOMALIES: number of ts per year : ',
     $     nstep_per_year
c
c --------------------------------------------------------------------
c     intitialize all averages to zero
c --------------------------------------------------------------------
c     
      do k = 1,nstep
         do i = 1,nproc_rates
            D_C_avg(i,k) = 0.0d0
         enddo
c
         do i = 1,nproc_fluxes
            fluxes_avg(i,k) = 0.0d0
         enddo
c
         nsum(k) = 0
      enddo
c
c --------------------------------------------------------------------
c     sum values, store them in the first year,
c       keep track of number of samples
c --------------------------------------------------------------------
c     
      do k = 1,nstep
         k2 = mod(k-1,nstep_per_year)+1
         nsum(k2) = nsum(k2) + 1
c
         do i = 1,nproc_rates
            D_C_avg(i,k2) = D_C_avg(i,k2) + D_C(i,k)
         enddo
         do i = 1,nproc_fluxes
            fluxes_avg(i,k2) = fluxes_avg(i,k2) + fluxes(i,k)
         enddo
      enddo
c
c --------------------------------------------------------------------
c     compute averages
c --------------------------------------------------------------------
c
      do k = 1,nstep
         k2 = mod(k-1,nstep_per_year)+1
c
         if (k .eq. k2) then
            do i = 1,nproc_rates
               D_C_avg(i,k) = D_C_avg(i,k2)/nsum(k2)
            enddo
c     
            do i = 1,nproc_fluxes
               fluxes_avg(i,k) = fluxes_avg(i,k2)/nsum(k2)
            enddo
         else
            do i = 1,nproc_rates
               D_C_avg(i,k) = D_C_avg(i,k2)
            enddo
c     
            do i = 1,nproc_fluxes
               fluxes_avg(i,k) = fluxes_avg(i,k2)
            enddo
c            
         endif
      enddo
c
c --------------------------------------------------------------------
c     compute anomalies
c --------------------------------------------------------------------
c
      do k = 1,nstep
         do i = 1,nproc_rates
            D_C_anom(i,k) = D_C(i,k) - D_C_avg(i,k)
         enddo
         do i = 1,nproc_fluxes
            fluxes_anom(i,k) = fluxes(i,k) - fluxes_avg(i,k)
         enddo
      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c
      write(*,*) '--COMPUTE_ANOMALIES: terminated.'
c    
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--COMPUTE_ANOMALIES: ',
     $     'an error occurred while writing...'
      error = .true.
c
      return

      end











