# 1 "compute_mc_runavg.F"
c =====================================================================
c
c     SUBROUTINE compute_mc_runavg
c
c     PURPOSE: computes the one year running averages of 
c                               the rates and fluxes from MC simulations
c     
c
c     VARIABLES:
c 
c     IN:  tstart          : start time of integration
c          tend            : end time of integration
c          ts              : time step
c          nstep           : number of steps
c          nstep2          : number of samples in sg* arrays
c          rsmpl_step      : resampling time step of sg* arrays
c          fluxes_std      : fluxes of the different processes
c          mean_fluxes     : mean fluxes of mc runs
c          sg_fluxes       : 1-sg uncertainty of fluxes
c          D_c_std         : rates of change of the different processes
c          mean_d_c        : mean d_c of mc runs
c          sg_d_c          : 1-sg uncertainty of d_c
c
c
c     OUT: D_C_std_runavg    : running avg of D_C standard
c          mean_d_c_runavg   : running avg of mean_D_C
c          sg_D_c_runavg     : running avg of sg_D_c
c          fluxes_std_runavg : running avg of fluxes_std
c          mean_fluxes_runavg: running avg of mean_fluxes
c          sg_fluxes_runavg  : running avg of sg_fluxes
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     08.06.02   ng     first implementation, on the basis of 
c                             compute_runavg.F
c 
c =====================================================================
c
      subroutine compute_mc_runavg(
     $     tstart,tend,ts,nstep, nstep2,
     $     rsmpl_step, D_c_std, mean_d_c,sg_D_c, fluxes_std,
     $     mean_fluxes,sg_fluxes, 
     $     D_C_std_runavg, mean_d_c_runavg,
     $     sg_D_c_runavg, fluxes_std_runavg, mean_fluxes_runavg,
     $     sg_fluxes_runavg,error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 55 "compute_mc_runavg.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 56 "compute_mc_runavg.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 57 "compute_mc_runavg.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 58 "compute_mc_runavg.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/monte_carlo.h" 1
c===================== include file monte_carlo.h =========================
c
c general variables for monte carlo simulations
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c  
c nrunmax       i  s   maximal number of mc runs             
c nrun          i  s   number of mc runs
c
c *_r          dp  s   parameters with a random component added. size of
c                        random component is proportional to sg of this
c                        parameter. For the parameter definitions see
c                        the *_params.h files 
c 
c
c===========================================================================
c
      integer nrunmax,nrun
      parameter(nrunmax = 2000)
      
      double precision gasex_fact_r,D_fco2_corr_r
      double precision diff_fact_r,D_dcdz_r,ddC13_dC_bml_r,lent_const_r
      double precision dlent_dh_r
      double precision D_dc13_org_r
      double precision u_r,dc_dh_r,ddc13_dh_r
c
# 59 "compute_mc_runavg.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_statistics.h" 1
c================== include file mc_statistics.h =========================
c
c variables of statistics of monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c  
c int_rates_std   dp a   array holding standard integrated rates
c int_fluxes_std  dp a   array holding standard integrated fluxes
c costfn_std      dp s   value of cost function for standard run
c rsq_std         dp s   r**2 value for standard run
c chisq_std       dp s   chi**2 value for standard run
c amplitude_std   dp s   amplitude of standard run
c c_min_std       dp s   minimum C of standard run
c c_max_std       dp s   maximum C of standard run
c
c var_int_rates   dp a   array holding variance of integrated rates 
c                            (over monte carlo runs)
c var_int_fluxes  dp a   array holding variance of integrated fluxes
c wvar_int_rates  dp a   array holding weighted variance of integrated rates 
c                                 (over monte carlo runs)
c wvar_int_fluxes dp a   array holding weighted variance of integrated fluxes
c sum_costfn      dp s   sum of cost function
c mean_costfn     dp s   mean of cost function
c costfn_min      dp s   minimum of cost function
c costfn_max      dp s   maximum of cost function
c 
c sg_int_rates    dp s   1-sigma uncertainty of int_rates
c sg_int_fluxes   dp s   1-sigma uncertainty of int_fluxes
c wsg_int_rates   dp s   1-sigma weighted uncertainty of int_rates
c wsg_int_fluxes  dp s   1-sigma weighted uncertainty of int_fluxes
c 
c===========================================================================
c
      double precision int_rates_std(nyearmax,nproc_rates)
      double precision int_fluxes_std(nyearmax,nproc_fluxes)
      double precision costfn_std
      double precision closure_std,rsq_std,chisq_std,amplitude_std
      double precision c_min_std,c_max_std
c
      double precision var_int_rates(nyearmax,nproc_rates)
      double precision var_int_fluxes(nyearmax,nproc_fluxes)
      double precision wvar_int_rates(nyearmax,nproc_rates)
      double precision wvar_int_fluxes(nyearmax,nproc_fluxes)
c   
      double precision sg_int_rates(nyearmax,nproc_rates)
      double precision sg_int_fluxes(nyearmax,nproc_fluxes)
      double precision wsg_int_rates(nyearmax,nproc_rates)
      double precision wsg_int_fluxes(nyearmax,nproc_fluxes)
c
      double precision sum_costfn,mean_costfn
      double precision costfn_min,costfn_max
c

# 60 "compute_mc_runavg.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_plot_slabs.h" 1
c================== include file mc_plot_slabs.h =========================
c
c variables that contain plot information for monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c
c variables:
c
c name                type   description
c---------------------------------------------------------------------------
c  		      
c nstepmax2           i  s   maximum number of values on time axis
c nstep               i  s   number of resampled values
c rsmpl_step          i  s   every i'th sample is resampled
c mc_D_c              dp a   array of resampled D_C array for mc analysis
c mc_fluxes           dp a   array of resampled fluxes array for mc analysis
c mc_c_sim            dp a   array of resampled c_sim array for mc analysis
c mc_u_var            dp a   array of resampled inverse calc u
c mc_ddc13_dh_var     dp a   array of resampled inverse calc ddC13_dh
c mean_D_c            dp a   mean D_C of mc runs
c mean_fluxes         dp a   mean fluxes of mc runs
c mean_c_sim          dp a   mean c_sim of mc runs
c mean_u_var          dp a   mean u_var
c mean_ddc13_dh_var   dp a   mean ddc13_dh_var
c wmean_D_c           dp a   weighted mean D_C of mc runs
c wmean_fluxes        dp a   weighted mean fluxes of mc runs
c wmean_c_sim         dp a   weighted mean c_sim of mc runs
c wmean_u_var         dp a   weighted mean u_var
c wmean_ddc13_dh_var  dp a   weighted mean ddc13_dh_var
c sg_D_c              dp a   1-sg uncertainty of D_C
c sg_fluxes           dp a   1-sg uncertainty of fluxes
c sg_c_sim            dp a   1-sg uncertainty of c_sim
c sg_u_var            dp a   1-sg uncertainty of u_var
c sg_ddc13_dh_var     dp a   1-sg uncertainty of ddc13_dh_var
c wsg_D_c             dp a   weighted 1-sg uncertainty of D_C
c wsg_fluxes          dp a   weighted 1-sg uncertainty of fluxes
c wsg_c_sim           dp a   weighted 1-sg uncertainty of c_sim
c wsg_u_var           dp a   weighted 1-sg uncertainty of u_var
c wsg_ddc13_dh_var    dp a   weighted 1-sg uncertainty of ddc13_dh_var
c c_sim_std           dp a   array holding c_sim of standard simulation
c fluxes_std          dp a   array holding fluxes of standard simulation
c d_c_std             dp a   array holding d_c of standard simulation
c u_var_std           dp a   array holding inv. calc. u of std simulation
c ddc13_dh_std        dp a   array holding inv. calc. ddc13_dh of std sim.
c
c                                 to the different proc.                mol C/m2/s
c D_C_std_runavg    dp a   one year running standard Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_std_runavg dp a   one year running standard Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
cc 
c===========================================================================
c
      integer nstepmax2,nstep2,rsmpl_step
      parameter(nstepmax2 = 200)
c
      double precision mc_D_c(nrunmax,nproc_rates,nstepmax2)
      double precision mc_fluxes(nrunmax,nproc_fluxes,nstepmax2)
      double precision mc_c_sim(nrunmax,nstepmax2)
      double precision mean_D_c(nproc_rates,nstepmax2)
      double precision mean_fluxes(nproc_fluxes,nstepmax2)
      double precision mean_c_sim(nstepmax2)
      double precision wmean_D_c(nproc_rates,nstepmax2)
      double precision wmean_fluxes(nproc_fluxes,nstepmax2)
      double precision wmean_c_sim(nstepmax2)
      double precision sg_D_c(nproc_rates,nstepmax2)
      double precision sg_fluxes(nproc_fluxes,nstepmax2)
      double precision sg_c_sim(nstepmax2)
      double precision wsg_D_c(nproc_rates,nstepmax2)
      double precision wsg_fluxes(nproc_fluxes,nstepmax2)
      double precision wsg_c_sim(nstepmax2)
      double precision mc_weight(nrunmax)
      double precision c_sim_std(nstepmax)
      double precision d_c_std(nproc_rates,nstepmax)
      double precision fluxes_std(nproc_fluxes,nstepmax)
c
      double precision mc_u_var(nrunmax,nstepmax2)
      double precision mc_ddc13_dh_var(nrunmax,nstepmax2)
      double precision mean_u_var(nstepmax2)
      double precision mean_ddc13_dh_var(nstepmax2)
      double precision wmean_u_var(nstepmax2)
      double precision wmean_ddc13_dh_var(nstepmax2)
      double precision sg_u_var(nstepmax2)
      double precision sg_ddc13_dh_var(nstepmax2)
      double precision wsg_u_var(nstepmax2)
      double precision wsg_ddc13_dh_var(nstepmax2)
      double precision u_var_std(nstepmax)
      double precision ddc13_dh_var_std(nstepmax)
c
      double precision fluxes_std_runavg(nproc_fluxes,nstepmax), 
     $     D_C_std_runavg(nproc_rates,nstepmax)
      double precision mean_d_c_runavg(nproc_rates,nstepmax2),
     $        sg_D_c_runavg(nproc_rates,nstepmax2),       
     $        mean_fluxes_runavg(nproc_fluxes,nstepmax2),
     $        sg_fluxes_runavg(nproc_fluxes,nstepmax2)   

# 61 "compute_mc_runavg.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/runavg.h" 1
c======================= include file runavg.h ==============================
c
c variables that store running averages
c
c REVISIONS:
c
c date     author    remarks
c
c 08.06.00 ng        first implementation
c
c variables:
c
c name              type   description
c-----------------------------------------------------------------------------
c 
c D_C_runavg        dp a   one year running avg Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_runavg     dp a   one year running avg Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
c-------------------------------------------------------------------------
c
      double precision D_C_runavg(nproc_rates,nstepmax)
      double precision fluxes_runavg(nproc_fluxes,nstepmax)
# 62 "compute_mc_runavg.F" 2

c
      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer k,i,k2,kk
      integer nstep_per_year,nstep_per_halfyr,nstep_start,nstep_stop
      double precision sum1,sum2
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c =====================================================================
c     need to do two passes, one for the stddev and mean, which
c       has been resamples, and one for the fluxes_std and D_C_std
c       which has the original time resolution
c =====================================================================
c
c
c --------------------------------------------------------------------
c     determine the number of timesteps per year, for the resampled
c       case
c --------------------------------------------------------------------
c     
      nstep_per_year = int(1.d0/ts)/rsmpl_step
c
      write(*,*) '--COMPUTE_MC_RUNAVG: number of ts per year',
     $     ' for resampled fields : ',
     $     nstep_per_year, ' resample timestep : ',rsmpl_step
c
c --------------------------------------------------------------------
c     determine the first and last steps
c --------------------------------------------------------------------
c     
      nstep_per_halfyr = int(nstep_per_year/2)
      nstep_start = nstep_per_halfyr+1
      nstep_stop = nstep2 - nstep_per_halfyr
      if (nstep_stop .le. nstep_start) then
         write(*,*) '--COMPUTE_RUNAVG: running average not possible,',
     $        ' because record is not long enough '
         write(*,*) '     nstep_start, nstep_stop : ',nstep_start,
     $        nstep_stop
         error = .true.
         goto 9900
      endif
c
      write(*,*) '--COMPUTE_MC_RUNAVG: nstep_start,nstep_stop : ',
     $     nstep_start,nstep_stop
c
c --------------------------------------------------------------------
c     pad at the beginning
c --------------------------------------------------------------------
c     
      
      do k = 1,nstep_start-1
         do i = 1,nproc_rates
            mean_d_c_runavg(i,k) = 0.0d0
            sg_D_c_runavg(i,k) = 0.0d0
         enddo
         do i = 1,nproc_fluxes
            mean_fluxes_runavg(i,k) = 0.0d0
            sg_fluxes_runavg(i,k) = 0.0d0
         enddo
      enddo
c
c --------------------------------------------------------------------
c     do the central (the real) part
c --------------------------------------------------------------------
c     
      do k = nstep_start,nstep_stop
c         write(*,*) '  working on step : ',k
         do i = 1,nproc_rates
            sum1 = 0.d0
            sum2 = 0.d0
             do kk = k-nstep_per_halfyr,k+nstep_per_halfyr
               sum1 = sum1 + mean_D_C(i,kk)
               sum2 = sum2 + sg_D_C(i,kk)
            enddo
            mean_D_C_runavg(i,k) = sum1/(2*nstep_per_halfyr+1)
            sg_D_C_runavg(i,k) = sum2/(2*nstep_per_halfyr+1)
         enddo
         do i= 1, nproc_fluxes
            sum1 = 0.0d0
            sum2 = 0.0d0
            do kk = k-nstep_per_halfyr,k+nstep_per_halfyr
               sum1 = sum1 + mean_fluxes(i,kk)
               sum2 = sum2 + sg_fluxes(i,kk)
            enddo
            mean_fluxes_runavg(i,k) = sum1/(2*nstep_per_halfyr+1)
            sg_fluxes_runavg(i,k) = sum2/(2*nstep_per_halfyr+1)
         enddo
      enddo
c
c --------------------------------------------------------------------
c     pad at the end
c --------------------------------------------------------------------
c     
      
      do k = nstep_stop+1,nstep2
         do i = 1,nproc_rates
            mean_d_c_runavg(i,k) = 0.0d0
            sg_D_c_runavg(i,k) = 0.0d0
         enddo
         do i = 1,nproc_fluxes
            mean_fluxes_runavg(i,k) = 0.0d0
            sg_fluxes_runavg(i,k) = 0.0d0
         enddo
      enddo
             
c
c =====================================================================
c     do the second pass, required for std cases
c
c =====================================================================
c
c --------------------------------------------------------------------
c     determine the number of timesteps per year
c --------------------------------------------------------------------
c     
      nstep_per_year = int(1.d0/ts)
c
      write(*,*) '--COMPUTE_MC_RUNAVG: number of ts per year for ',
     $     ' standard case : ',
     $     nstep_per_year
c
c --------------------------------------------------------------------
c     determine the first and last steps
c --------------------------------------------------------------------
c     
      nstep_per_halfyr = int(nstep_per_year/2)
      nstep_start = nstep_per_halfyr+1
      nstep_stop = nstep - nstep_per_halfyr
      if (nstep_stop .le. nstep_start) then
         write(*,*) '--COMPUTE_RUNAVG: running average not possible,',
     $        ' because record is not long enough '
         write(*,*) '     nstep_start, nstep_stop : ',nstep_start,
     $        nstep_stop
         error = .true.
         goto 9900
      endif
c
      write(*,*) '--COMPUTE_MC_RUNAVG: nstep_start,nstep_stop : ',
     $     nstep_start,nstep_stop
c
c --------------------------------------------------------------------
c     pad at the beginning
c --------------------------------------------------------------------
c     
      
      do k = 1,nstep_start-1
         do i = 1,nproc_rates
            D_C_std_runavg(i,k) = 0.0d0
         enddo
         do i = 1,nproc_fluxes
            fluxes_std_runavg(i,k) = 0.0d0
         enddo
      enddo
             
c
c --------------------------------------------------------------------
c     do the central (the real) part
c --------------------------------------------------------------------
c     
      do k = nstep_start,nstep_stop
         do i = 1,nproc_rates
            sum1 = 0.d0
             do kk = k-nstep_per_halfyr,k+nstep_per_halfyr
               sum1 = sum1 + D_C_std(i,kk)
            enddo
            D_C_std_runavg(i,k) = sum1/(2*nstep_per_halfyr+1)
         enddo
         do i= 1, nproc_fluxes
            sum1 = 0.0d0
            do kk = k-nstep_per_halfyr,k+nstep_per_halfyr
               sum1 = sum1 + fluxes_std(i,kk)
            enddo
            fluxes_std_runavg(i,k) = sum1/(2*nstep_per_halfyr+1)
         enddo
      enddo
c
c --------------------------------------------------------------------
c     pad at the end
c --------------------------------------------------------------------
c     
      
      do k = nstep_stop+1,nstep
         do i = 1,nproc_rates
            D_C_std_runavg(i,k) = 0.0d0
         enddo
         do i = 1,nproc_fluxes
            fluxes_std_runavg(i,k) = 0.0d0
         enddo
      enddo
             
cc
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c
      write(*,*) '--COMPUTE_MC_RUNAVG: terminated.'
c    
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--COMPUTE_MC_RUNAVG: ',
     $     'an error occurred while writing...'
      error = .true.
c
      return

      end











