# 1 "gasexchange.F"
c =====================================================================
c
c     SUBROUTINE GASEXCHANGE
c 
c     PURPOSE: this routine calculates the contribution of air-sea
c                gasexchange to the mixed layer budget
c
c     VARIABLES:
c 
c     IN : k            : time loop counter
c          ts           : time step
c          pv_relship   : piston velocity relationship
c          D_fco2_corr  : correction term for fugacity
c          gasex_fact   : multiplication factor for air-sea exchange
c
c          C            : obs C in the mixed layer
c          C13          : obs C13 in the mixed layer
c          h            : obs mixed layer depth
c          temp         : obs temperature
c          sal          : obs salinity
c          fco2_o       : obs fCO2 in the mixed layer
c          pco2_a       : obs xco2 in the atmosphere
c          dC13_a       : obs dC13 in the atmosphere
c          ws           : obs wind speed
c          sum_kex      : sum of kex to calculate average
c
c     OUT: D_C          : modified array holding the rates of change for C
c          D_C13        : modified array holding the rates of change for C13
c          fluxes       : modified array holding the fluxes
c          sum_kex      : modified sum_kex 
c          fco2_a_obs   : observed atmospheric fco2 [uatm]
c          pco2_a_dry   : observed atmospheric pco2 [uatm]
c 
c     REVISION:
c
c     date     author  remarks
c   
c      1.08.96   ng    first implementation
c     22.08.96   ng    included estimates of relative humidity and
c                         total pressure from St.Davids head on
c                         the island of Bermuda
c     16.12.96   ng    found error in calculating fugacity, permit
c                         to use old,wrong formulation with a cpp 
c                         option (-Dwith_error_fugacity)
c     28.05.97   ng    found error in wanninkhof wind speed dependency of
c                         pv (**(-0.5) instead of **(0.5))
c     15.10.99   ng    adapted for interannual variability run, make
c                         sure units are compatible (now using years)
c     26.10.02   ng    added pco2_a_obs_dry
c
c =====================================================================
c
      subroutine gasexchange(k,ts,
     $     pv_relship,D_fco2_corr,gasex_fact,
     $     C,C13,h,temp,sal,fco2_o,pco2_a,dC13_a,ws,
     $     sum_kex,fco2_a_obs,pco2_a_dry,
     $     D_C,D_C13,fluxes)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 66 "gasexchange.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 67 "gasexchange.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 68 "gasexchange.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/input.h" 1
c======================== include file input.h  =============================
c
c input data for the seasonal model, stemming from the harmonic 
c      regression (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp        dp s  mixed layer temperature                       deg C
c sal         dp s  mixed layer salinity                          psu
c ws          dp s  wind-speed                                    m s-1
c fCO2_o      dp s  CO2 fugacity in the mixed layer               uatm
c pco2_a      dp s  pCO2 in the atmosphere                        ppm
c dc13_a      dp s  dC13 in the atmosphere                        per mil
c dCdz_var    dp s  vertical C gradient below the mixed layer   umol/kg/m
c kz_var      dp s  vertical diffusion coefficient                m2 s-1
c salk        dp s  salinity normalized alkalinity              umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp,sal,ws,fCO2_o,pco2_a,dc13_a
      double precision dCdz_var,kz_var,salk


# 69 "gasexchange.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/gasex_params.h" 1
c===================== include file gasex_params.h =========================
c
c parameters of air-sea exchange
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 06.6.00  ng        added comp_foc2_online
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c 
c pv_relship     c  s   character indicating the relationship between
c                       piston velocity and wind-speed that is used for
c                       calculating the piston-velocity
c                           <lm> : Liss and Merlivat
c                           <wa> : Wanninkhof  
c D_fco2_corr    dp s   correction term for calculated fCO2 ocean     [uatm]
c gasex_fact     dp s   multiplication factor for air-sea exchange
c                           usually 1.0 for Wanninkhof
c                           usually 1.7447 for Liss and Merlivat
c
c ws_coeff       c  s   character specifying wind speed coefficients
c                           <ih> : Isemer and Hasse, 1985
c                           <ae> : AEROCE, 1989-1991
c
c sg_D_fco2_corr dp a   uncertainty of D_fco2_corr
c sg_gasex_fact  dp a   uncertainty of gasex_fact
c
c mean_air_press dp s   mean air pressure [atm] (from St. Davids head)
c mean_rel_humid dp s   mean relative humidity [] (from St. Davids head)
c 
c comp_fco2_online l s  logical indicating whether fco2 should be
c                         computed on or offline
c
c===========================================================================
c
      character pv_relship*2,ws_coeff*2
      double precision D_fco2_corr,gasex_fact
      double precision sg_D_fco2_corr, sg_gasex_fact
c
      double precision mean_air_press,mean_rel_humid




      parameter (mean_air_press = 1.017,mean_rel_humid = 0.87)

c
      logical comp_fco2_online
# 70 "gasexchange.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 71 "gasexchange.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/c13_params.h" 1
cc=================== include file c13_params.h =============================
c
c parameters for C13 and dC13
c
c REVISIONS:
c
c date     author    remarks
c
c 2.08.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c r_Std          dp  s  C13/C12 ratio of PDB standard
c rstar_Std      dp  s  C13/(C12+C13) ratio of PDB standard
c
c---------------------------------------------------------------------------
c
      double precision r_std,rstar_std
      parameter (r_std = 0.0112372d0, rstar_std = 0.011112328d0)



# 72 "gasexchange.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/obs_values.h" 1
c==================== include file obs_values.h  =============================
c
c observed seasonal cycles of input data 
c    (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 08.08.96  ng       first implementation
c 07.06.00  ng       added salk_obs
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp_obs     dp a  mixed layer temperature                       deg C
c sal_obs      dp a  mixed layer salinity                          psu
c ws_obs       dp a  wind-speed                                    m s-1
c fco2_o_obs   dp a  CO2 fugacity in the mixed layer               uatm
c pco2_a_obs   dp a  xco2 in the atmosphere
c fco2_a_obs   dp a  fCO2 in the atmosphere                        uatm
c pco2_a_dry   dp a  pCO2 in the atmosphere                        
cc dc13_a_obs   dp a  dC13 in the atmosphere                        per mil
c dCdz_obs     dp a  vertical C gradient below the mixed layer     umol/kg/m
c kz_obs       dp a  vertical diffusivity                          m2 s-1
c salk_obs     dp a  salinity normalized alk                       umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp_obs(nstepmax),sal_obs(nstepmax)
      double precision ws_obs(nstepmax),fco2_o_obs(nstepmax)
      double precision pco2_a_obs(nstepmax),fco2_a_obs(nstepmax)
      double precision pco2_a_dry(nstepmax)
      double precision dc13_a_obs(nstepmax)
      double precision dCdz_obs(nstepmax),kz_obs(nstepmax)
      double precision salk_obs(nstepmax)


# 73 "gasexchange.F" 2
      integer k
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
      double precision fluxes_to_rates,delta_to_ratio ! functions
      double precision solco2m3, schmidt_number, vp_seawater ! functions
      double precision c13_to_delta,fco2 ! function
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      double precision sc,sc_old,scnfact,sol,pv, tk,kex,vp_sw
      double precision pco2_a_vp,fco2_a,fco2_a2
      double precision alpha_eq,alpha_am
      double precision flux_C13_ex
      double precision dc13_o
      double precision dc13_ex,rstar,p_dry
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      tk = temp+273.15d0
c
c --------------------------------------------------------------------
c     calculate Schmidt-number (using Wanninkhof, 1992)
c         no units
c     sc_old is the old relationship from Heimann, pers. comm.
c
c --------------------------------------------------------------------
c




      sc = schmidt_number('CO2',temp)
      ScnFact = sc/660.d0

c
c      write(*,*) 'sc (norm to 660) and sc_old (norm to 600) : ',
c     $     sc/660.d0,sc_old/600.d0
c
c --------------------------------------------------------------------
c     calculate CO2 solubility (using Weiss, 1974)
c       units are mol/(m3*atm) then change directly to units of
c       mol m-3 uatm-1
c --------------------------------------------------------------------
c        
      sol = solco2m3(temp,sal)
      sol = sol * 1.d-6
c
c --------------------------------------------------------------------
c     calculate gas transfer velocity (also called piston velocity) pv
c        for Wanninkhof use formula for long term average winds
c        his formula (1)
c     the relationships are given for wind-speed in m s-1 and
c        resulting pv in cm hr-1
c --------------------------------------------------------------------
c        
      if (pv_relship .eq. 'lm') then
c
         pv = 0.17d0*(ScnFact)**(-2.0d0/3.0d0) * ws + 
     $        2.68d0*(ws-3.6d0)*(ScNFact)**(-0.5d0) ! cm hr-1
c
      elseif (pv_relship .eq. 'wa') then
c
         pv = 0.39d0 * ws**2.d0 / dsqrt(ScnFact) ! cm hr-1
c
      endif
c
      pv = pv / (100.d0 * 3600.d0) ! convert to m s-1
c
c
c --------------------------------------------------------------------
c     calculate gas transfer coefficient in units of 
c         mol m-2 s-1 uatm-1
c     include directly also the air-sea gasexchange factor
c --------------------------------------------------------------------
c        
      kex = gasex_fact * pv * Sol
c
      Sum_kex = Sum_kex + kex
c
c      write(*,*) 'sol, pv, kex : ',sol,pv,kex
c
c --------------------------------------------------------------------
c     calculate atmospheric fugacity
c        calculate first water vapour pressure at the temperature
c        of the water and assuming 100% saturation
c        then calculate pco2_a_vp which includes effect of 
c        vapor pressure of seawater, assume 1.03 atm total pressure
c --------------------------------------------------------------------
c




      vp_sw = vp_seawater(temp,sal) ! units [kPa]
      vp_sw = vp_sw / 101.325d0 ! units [atm]
c
      p_dry = mean_air_press - mean_rel_humid*vp_sw
c
c      write(*,*) 'k, p_dry : ',k,p_dry
c
      fco2_a = fco2(temp,p_dry,pco2_a) ! units [uatm]
      pco2_a_dry(k) = pco2_a*p_dry
      fco2_a_obs(k) = fco2_a

c
c --------------------------------------------------------------------
c     old stuff
c --------------------------------------------------------------------
c  
c
c#  ifdef with_error_fugacity
c      pco2_a_vp = pco2_a * p_dry ! units [ppm*atm = uatm]
c      fco2_a = fco2(temp,1.d0,pco2_a_vp) ! units [uatm]
c#  else
c
c      fco2_a = fco2(temp,p_dry,pco2_a) ! units [uatm]
c#  endif
c
c      write(*,*) 'pco2_a,pco2_a_vp,fco2_a,fco2_a2 : ',
c     $     pco2_a,pco2_a_vp,fco2_a,fco2_a2

c
c --------------------------------------------------------------------
c     apply correction for fCO2_o
c --------------------------------------------------------------------
c  
      fCO2_o = fCO2_o + D_fco2_corr
c
c --------------------------------------------------------------------
c     calculate finally the flux of CO2 and rate of change
c --------------------------------------------------------------------
c        
      fluxes(1,k) = kex * (fCO2_a - fCO2_o) ! units [mol/m2/s]
c
      D_C(1,k) = fluxes_to_rates(fluxes(1,k), ts, h) ! units [umol/kg]
c
c --------------------------------------------------------------------
c     for debugging purposes
c --------------------------------------------------------------------
c        
c      write(*,*) 'k : ',k
c      write(*,*) 'kex, fCO2_a, fCO2_o : ',kex,fco2_a,fco2_o
c      write(*,*) 'flux, D_C : ',fluxes(1,k),D_C(1,k)
c
c --------------------------------------------------------------------
c     calculate the equilibrium fractionation factor for dC13
c       from Heimann and Keeling, 1989
c     define also the kinetic fractionation factor alpha_am
c       also from Heimann and Keeling, 1989
c --------------------------------------------------------------------
c        
      Alpha_eq = 1.02389d0 - 9.483d0/TK
      Alpha_am = 0.99820d0
c
c --------------------------------------------------------------------
c     calculate the air-sea exchange flux for C13
c       units are [mol 13C m-2 s-1] and the rate of change
c --------------------------------------------------------------------
c   
      dc13_o = c13_to_delta(c13,c) ! calculate the dC13 value in the ocean
c
      flux_c13_ex = 
     $     kex * alpha_am *(rstar_std/r_std) 
     $     * (fCO2_a * delta_to_ratio(dC13_a)
     $     - fCO2_o * delta_to_ratio(dc13_o) * alpha_eq) ! units [mol/m2/s]
c
      D_c13(1,k) = fluxes_to_rates(flux_c13_ex, ts, h) ! units [umol/kg]
c
c --------------------------------------------------------------------
c     for debugging purposes
c --------------------------------------------------------------------
c
# 270 "gasexchange.F"

c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

