# 1 "keep_mc_statistics.F"
c =====================================================================
c
c     SUBROUTINE KEEP_MC_STATISTICS
c 
c     PURPOSE: this routine updates the statistics of the monte
c                  carlo runs (calculates variance)
c
c     VARIABLES:
c
c     IN : nr              : actual monte carlo run
c          nstep           : number of steps
c          D_c             : array of rates of change
c          fluxes          : array of fluxes
c          c_sim           : array of simulated C
c          int_rates       : array of integrated rates
c          int_fluxes      : array of integrated fluxes
c          nyears          : number of analysis years
c          int_rates_std   : array of integrated rates of standard run
c          int_fluxes_std  : array of integrated fluxes of standard run
c          costfn_std      : standard cost function
c          var_int_rates   : previous variance of int_rates
c          var_int_fluxes  : previous variance of int_fluxes
c          wvar_int_rates  : previous weighted variance of int_rates
c          wvar_int_fluxes : previous weighted variance of int_fluxes
c          chisq           : chi**2 of run
c          closure         : lack of closure of run
c          amplitude       : simulated amplitude
c          amplitude_obs   : observed amplitude    
c          costfn          : costfunction of this run
c          p               : parameters
c          p_init          : initial parameters
c          sg_p            : sigma of parameters   
c          sum_costfn      : previous sum of cost function
c          costfn_min      : previous minimum of cost function
c          costfn_max      : previous maximum of cost function
c                          
c     OUT: mc_D_c          : modified array holding resampled history of D_C
c          mc_fluxes       : modified array holding resampled history of fluxes
c          mc_c_sim        : modified array holding resampled history of c_sim
c          mc_weight       : weight of each run
c          nstep2          : number of samples in mc arrays
c          var_int_rates   : new variance of int_rates
c          var_int_fluxes  : new variance of int_fluxes
c          var_inv_costfn  : new variance of inverse of cost function(weights)
c          wvar_int_rates  : new weighted variance of int_rates
c          wvar_int_fluxes : new weighted variance of int_fluxes
c          sum_costfn      : nev sum of costfn
c          costfn_min      : new minimum of cost function
c          costfn_max      : new maximum of cost function
c
c     REVISION:
c
c     date     author  remarks
c   
c     16.08.96   ng    first implementation
c      2.09.96   ng    changed definition of weight and calc of costfunction
c     18.10.99   ng    adapted for interannual variability runs
c
c =====================================================================
c
      subroutine keep_mc_statistics(
     $     nr,nstep,
     $     D_c,fluxes,c_sim,
     $     int_rates,int_fluxes,nyears,
     $     int_rates_std,int_fluxes_std,costfn_std,
     $     chisq,closure,amplitude,amplitude_obs,costfn,
     $     p,sg_p,p_init,
     $     mc_D_c,mc_fluxes,mc_c_sim,mc_weight,
     $     nstep2,rsmpl_step,
     $     var_int_rates,var_int_fluxes,
     $     wvar_int_rates,wvar_int_fluxes,
     $     sum_costfn,costfn_min,costfn_max)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 81 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 82 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 83 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 84 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 85 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/conj_grad.h" 1
c===================== include file conj_grad.h =========================
c
c variables for finding minimum using conjugate gradient technique
c
c REVISIONS:
c
c date     author    remarks
c
c 12.8.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c     
c assign         l  s   logical for subroutine assign_parameters
c                        true : assign values to parameters
c                        false: assign parameters to values   
c p             dp  a   array of parameters
c p_opt         dp  a   array of optimum parameters
c sg_p          dp  a   sigma of parameters
c p_init        dp  a   array of initial parameters
c nparams        i  s   dimension of parameters
c npmax          i  s   maximum dimension of p
c iter           i  s   number of iterations
c fret          dp  s   value of function at minimum
c hessian       dp  a   hessian matrix
c covm          dp  a   inverse of hessian matrix, covariance matrix
c
c sg_c          dp  s   1-sigma uncertainty of C [umol kg-1]
c sg_dcdt       sp  s   1-sigma uncertainty of dcdt [umol kg-1 day-1]
c                          (estimated from figure)
c
c===========================================================================
c
      logical assign
      double precision ftol,fret
      integer nruns
      integer nparams,iter


      parameter(nparams = 10)










      double precision p(nparams),p_opt(nparams),p_init(nparams)
      double precision sg_p(nparams)
      double precision hessian(nparams,nparams),covm(nparams,nparams)
c
      
# 86 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/statistics.h" 1
c==================== include file statistics.h ==============================
c
c variables for the run statistics
c
c REVISIONS:
c
c date     author    remarks
c
c 08.8.96  ng        first implementation
c 05.9.96  ng        included c_min,c_max,c_min_obs,c_max_obs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c chisq         dp s   chi**2 between simulated and observed rate of change
c rsq           dp s   r**2 of fit between simulated and observed rates
c closure       dp s   annual lack of closure
c amplitude     dp s   simulated annual amplitude
c amplitude_obs dp s   observed annual amplitude
c c_min         dp s   simulated minimum C
c c_max         dp s   simulated maximum C
c c_min_obs     dp s   observed minimum C
c c_max_obs     dp s   observed maximum C
c par_sum       dp s   value of parameter misfit
c costfn        dp s   value of cost function
c chisq_term    dp s   value of chi**2 term in cost function
c clos_term     dp s   value of closure term in cost function
c ampl_term     dp s   value of amplitude term in cost function
c par_term      dp s   value of parameter term in cost function
c
c-------------------------------------------------------------------------
c
      double precision chisq,rsq,closure,costfn,amplitude
      double precision amplitude_obs,par_sum
      double precision c_min,c_max,c_min_obs,c_max_obs
      double precision chisq_term,clos_term,ampl_term,par_term



# 87 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/monte_carlo.h" 1
c===================== include file monte_carlo.h =========================
c
c general variables for monte carlo simulations
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c  
c nrunmax       i  s   maximal number of mc runs             
c nrun          i  s   number of mc runs
c
c *_r          dp  s   parameters with a random component added. size of
c                        random component is proportional to sg of this
c                        parameter. For the parameter definitions see
c                        the *_params.h files 
c 
c
c===========================================================================
c
      integer nrunmax,nrun
      parameter(nrunmax = 2000)
      
      double precision gasex_fact_r,D_fco2_corr_r
      double precision diff_fact_r,D_dcdz_r,ddC13_dC_bml_r,lent_const_r
      double precision dlent_dh_r
      double precision D_dc13_org_r
      double precision u_r,dc_dh_r,ddc13_dh_r
c
# 88 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_statistics.h" 1
c================== include file mc_statistics.h =========================
c
c variables of statistics of monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c  
c int_rates_std   dp a   array holding standard integrated rates
c int_fluxes_std  dp a   array holding standard integrated fluxes
c costfn_std      dp s   value of cost function for standard run
c rsq_std         dp s   r**2 value for standard run
c chisq_std       dp s   chi**2 value for standard run
c amplitude_std   dp s   amplitude of standard run
c c_min_std       dp s   minimum C of standard run
c c_max_std       dp s   maximum C of standard run
c
c var_int_rates   dp a   array holding variance of integrated rates 
c                            (over monte carlo runs)
c var_int_fluxes  dp a   array holding variance of integrated fluxes
c wvar_int_rates  dp a   array holding weighted variance of integrated rates 
c                                 (over monte carlo runs)
c wvar_int_fluxes dp a   array holding weighted variance of integrated fluxes
c sum_costfn      dp s   sum of cost function
c mean_costfn     dp s   mean of cost function
c costfn_min      dp s   minimum of cost function
c costfn_max      dp s   maximum of cost function
c 
c sg_int_rates    dp s   1-sigma uncertainty of int_rates
c sg_int_fluxes   dp s   1-sigma uncertainty of int_fluxes
c wsg_int_rates   dp s   1-sigma weighted uncertainty of int_rates
c wsg_int_fluxes  dp s   1-sigma weighted uncertainty of int_fluxes
c 
c===========================================================================
c
      double precision int_rates_std(nyearmax,nproc_rates)
      double precision int_fluxes_std(nyearmax,nproc_fluxes)
      double precision costfn_std
      double precision closure_std,rsq_std,chisq_std,amplitude_std
      double precision c_min_std,c_max_std
c
      double precision var_int_rates(nyearmax,nproc_rates)
      double precision var_int_fluxes(nyearmax,nproc_fluxes)
      double precision wvar_int_rates(nyearmax,nproc_rates)
      double precision wvar_int_fluxes(nyearmax,nproc_fluxes)
c   
      double precision sg_int_rates(nyearmax,nproc_rates)
      double precision sg_int_fluxes(nyearmax,nproc_fluxes)
      double precision wsg_int_rates(nyearmax,nproc_rates)
      double precision wsg_int_fluxes(nyearmax,nproc_fluxes)
c
      double precision sum_costfn,mean_costfn
      double precision costfn_min,costfn_max
c

# 89 "keep_mc_statistics.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_plot_slabs.h" 1
c================== include file mc_plot_slabs.h =========================
c
c variables that contain plot information for monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c
c variables:
c
c name                type   description
c---------------------------------------------------------------------------
c  		      
c nstepmax2           i  s   maximum number of values on time axis
c nstep               i  s   number of resampled values
c rsmpl_step          i  s   every i'th sample is resampled
c mc_D_c              dp a   array of resampled D_C array for mc analysis
c mc_fluxes           dp a   array of resampled fluxes array for mc analysis
c mc_c_sim            dp a   array of resampled c_sim array for mc analysis
c mc_u_var            dp a   array of resampled inverse calc u
c mc_ddc13_dh_var     dp a   array of resampled inverse calc ddC13_dh
c mean_D_c            dp a   mean D_C of mc runs
c mean_fluxes         dp a   mean fluxes of mc runs
c mean_c_sim          dp a   mean c_sim of mc runs
c mean_u_var          dp a   mean u_var
c mean_ddc13_dh_var   dp a   mean ddc13_dh_var
c wmean_D_c           dp a   weighted mean D_C of mc runs
c wmean_fluxes        dp a   weighted mean fluxes of mc runs
c wmean_c_sim         dp a   weighted mean c_sim of mc runs
c wmean_u_var         dp a   weighted mean u_var
c wmean_ddc13_dh_var  dp a   weighted mean ddc13_dh_var
c sg_D_c              dp a   1-sg uncertainty of D_C
c sg_fluxes           dp a   1-sg uncertainty of fluxes
c sg_c_sim            dp a   1-sg uncertainty of c_sim
c sg_u_var            dp a   1-sg uncertainty of u_var
c sg_ddc13_dh_var     dp a   1-sg uncertainty of ddc13_dh_var
c wsg_D_c             dp a   weighted 1-sg uncertainty of D_C
c wsg_fluxes          dp a   weighted 1-sg uncertainty of fluxes
c wsg_c_sim           dp a   weighted 1-sg uncertainty of c_sim
c wsg_u_var           dp a   weighted 1-sg uncertainty of u_var
c wsg_ddc13_dh_var    dp a   weighted 1-sg uncertainty of ddc13_dh_var
c c_sim_std           dp a   array holding c_sim of standard simulation
c fluxes_std          dp a   array holding fluxes of standard simulation
c d_c_std             dp a   array holding d_c of standard simulation
c u_var_std           dp a   array holding inv. calc. u of std simulation
c ddc13_dh_std        dp a   array holding inv. calc. ddc13_dh of std sim.
c
c                                 to the different proc.                mol C/m2/s
c D_C_std_runavg    dp a   one year running standard Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_std_runavg dp a   one year running standard Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
cc 
c===========================================================================
c
      integer nstepmax2,nstep2,rsmpl_step
      parameter(nstepmax2 = 200)
c
      double precision mc_D_c(nrunmax,nproc_rates,nstepmax2)
      double precision mc_fluxes(nrunmax,nproc_fluxes,nstepmax2)
      double precision mc_c_sim(nrunmax,nstepmax2)
      double precision mean_D_c(nproc_rates,nstepmax2)
      double precision mean_fluxes(nproc_fluxes,nstepmax2)
      double precision mean_c_sim(nstepmax2)
      double precision wmean_D_c(nproc_rates,nstepmax2)
      double precision wmean_fluxes(nproc_fluxes,nstepmax2)
      double precision wmean_c_sim(nstepmax2)
      double precision sg_D_c(nproc_rates,nstepmax2)
      double precision sg_fluxes(nproc_fluxes,nstepmax2)
      double precision sg_c_sim(nstepmax2)
      double precision wsg_D_c(nproc_rates,nstepmax2)
      double precision wsg_fluxes(nproc_fluxes,nstepmax2)
      double precision wsg_c_sim(nstepmax2)
      double precision mc_weight(nrunmax)
      double precision c_sim_std(nstepmax)
      double precision d_c_std(nproc_rates,nstepmax)
      double precision fluxes_std(nproc_fluxes,nstepmax)
c
      double precision mc_u_var(nrunmax,nstepmax2)
      double precision mc_ddc13_dh_var(nrunmax,nstepmax2)
      double precision mean_u_var(nstepmax2)
      double precision mean_ddc13_dh_var(nstepmax2)
      double precision wmean_u_var(nstepmax2)
      double precision wmean_ddc13_dh_var(nstepmax2)
      double precision sg_u_var(nstepmax2)
      double precision sg_ddc13_dh_var(nstepmax2)
      double precision wsg_u_var(nstepmax2)
      double precision wsg_ddc13_dh_var(nstepmax2)
      double precision u_var_std(nstepmax)
      double precision ddc13_dh_var_std(nstepmax)
c
      double precision fluxes_std_runavg(nproc_fluxes,nstepmax), 
     $     D_C_std_runavg(nproc_rates,nstepmax)
      double precision mean_d_c_runavg(nproc_rates,nstepmax2),
     $        sg_D_c_runavg(nproc_rates,nstepmax2),       
     $        mean_fluxes_runavg(nproc_fluxes,nstepmax2),
     $        sg_fluxes_runavg(nproc_fluxes,nstepmax2)   

# 90 "keep_mc_statistics.F" 2
c
      integer nr
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      integer i,j,np,k
      logical first
      data first /.true./
      double precision weight
      integer nsmpl
c
c ---------------------------------------------------------------------
c     save first between calls
c ---------------------------------------------------------------------
c
      save first
c
c ---------------------------------------------------------------------
c     external function
c ---------------------------------------------------------------------
c
      double precision cost_function
c      
c =====================================================================
c     begin of executable code
c =====================================================================
c
c      write(*,*) '--KEEP_MC_STATISTICS: summing run statistics...'
c
c --------------------------------------------------------------------
c     initialize start values at the first time this subroutine is
c       called
c --------------------------------------------------------------------
c       
      if (first) then
         do i = 1,nyearmax
            do j = 1,nproc_rates
               var_int_rates(i,j) = 0.d0
            enddo
            do j = 1,nproc_fluxes
               var_int_fluxes(i,j) = 0.0d0
            enddo
         enddo
c
         sum_costfn = 0.d0
         costfn_min = 9.99d30
         costfn_max = -9.99d30
c
         first = .false.
c
         rsmpl_step = 40
         if ((nstep / rsmpl_step) .gt. nstepmax2) then
            rsmpl_step = nstep / nstepmax2 + 1
         endif
c
      endif
c
c --------------------------------------------------------------------
c     calculate cost function : changed 2.9.96 ; only cost function
c       without parameter term is calculated
c -------------------------------------------------------------------- 
c
cc
cc --------------------------------------------------------------------
cc     calculate cost function : part of parameter deviation
cc -------------------------------------------------------------------- 
cc
c      par_sum = 0.d0
c      do np = 1,nparams
cc     par_sum = par_sum + p(np)**2
c         par_sum = par_sum + ((p(np) - p_init(np))/sg_p(np))**2
c      enddo
cc     
cc --------------------------------------------------------------------
cc     calculate total cost function
cc --------------------------------------------------------------------
cc 
c      costfn = cost_function(chisq,closure,par_sum,nparams,
c     $     amplitude,amplitude_obs,
c     $     c_min,c_max,c_min_obs,c_max_obs,
c     $     chisq_term,clos_term,par_term,ampl_term)
cc     
      sum_costfn = sum_costfn + costfn
c
c --------------------------------------------------------------------
c     keep minimum and maximum of costfunction
c --------------------------------------------------------------------
c       
      if (costfn .lt. costfn_min) then
         costfn_min = costfn
      endif
      if (costfn .gt. costfn_max) then
         costfn_max = costfn
      endif
c
c --------------------------------------------------------------------
c     add the new values to the old variances
c     for weighted variances : weight each new value
c     use quotient of cost function to cost_function of standard 
c     run as weight
c --------------------------------------------------------------------
c
c      weight = costfn_std/costfn
c      weight = dexp((-costfn/costfn_std + 1.d0))
c      weight = dexp((-costfn/costfn_std + 1.d0)*0.116d0)



      weight = dexp(-((costfn-costfn_std)**2)/(0.04d0**2.d0))

c
      do i = 1,nyears
         do j = 1,nproc_rates
            var_int_rates(i,j) = var_int_rates(i,j) + 
     $           (int_rates(i,j)-int_rates_std(i,j))**2
            wvar_int_rates(i,j) = wvar_int_rates(i,j) +
     $           ((int_rates(i,j)-int_rates_std(i,j))*weight)**2
         enddo
         do j = 1,nproc_fluxes
            var_int_fluxes(i,j) = var_int_fluxes(i,j) + 
     $           (int_fluxes(i,j)-int_fluxes_std(i,j))**2
            wvar_int_fluxes(i,j) = wvar_int_fluxes(i,j) +
     $           ((int_fluxes(i,j)-int_fluxes_std(i,j))*weight)**2
         enddo
      enddo
c
c --------------------------------------------------------------------
c     resample D_C,fluxes and C_sim
c --------------------------------------------------------------------
c 
      nsmpl = 0
c
      do k = 1,nstep
         if (mod(k,rsmpl_step) .eq. 1) then
            nsmpl = nsmpl + 1
            do i = 1,nproc_rates
               mc_d_c(nr,i,nsmpl) = d_c(i,k)
            enddo
            do i = 1,nproc_fluxes
               mc_fluxes(nr,i,nsmpl) = fluxes(i,k)
            enddo
            mc_c_sim(nr,nsmpl) = c_sim(k)
         endif
      enddo
c
      nstep2 = nsmpl
      mc_weight(nr) = weight
c
c --------------------------------------------------------------------
c     for debugging
c --------------------------------------------------------------------
c 
c      write(*,*) '--KEEP_MC_STATISTICS : mc run # ',nr
c      write(*,*) '   c_sim(k=1,10) : ',(c_sim(k),k=1,10)
c      write(*,*) '   mc_c_sim(nr,k=1,10) : ',(mc_c_sim(nr,k),k=1,10)
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

