# 1 "matear_ent.F"
c =====================================================================
c
c     SUBROUTINE MATEAR_ENT
c 
c     PURPOSE: this routine calculates the contribution of entrainment
c                  on the mixed layer budget. This routine is the
c                  version where the same entrainment scheme of
c                  Matear (1995) is used 
c                  
c
c     VARIABLES:
c 
c     IN : k              : time loop counter
c          time           : actual time
c          ts             : time step
c          const_vertgrad : logical indicating use of constant vert grad
c          dCdz_const     : value of constant vertical C gradient
c          dCdz_var       : value of variable vertical C gradient
c          D_dCdz         : correction term for dC/dz
c          ddC13_dC_bml   : ratio of dd13C/dz to dC/dz below mixed layer
c          const_lent     : logical indicating use of const. or var. ent_length
c          lent_const     : constant entrainment length
c          dlent_dh       : ratio of lent to mixed layer depth []
c          ent_fact       : entrainment multiplication factor
c
c          h_new          : mixed layer depth at timestep t+ts
c          h_old          : mixed layer depth at tiemstep t
c
c          C              : obs C in the mixed layer
c          C13            : obs C13 in the mixed layer
c          h              : obs mixed layer depth
c
c     OUT: D_C            : modified array holding the rates of change for C
c          D_C13          : modified array holding the rates of change for C13
c          fluxes         : modified array holding the fluxes
c 
c     REVISION:
c
c     date     author  remarks
c   
c      8.08.96   ng    first implementation
c      9.09.96   ng    included const_lent,dlent_dh
c      9.09.96   ng    use accurate formula for dc13_dz
c     17.10.99   ng    adapted for interannual variability runs
c
c =====================================================================
c
      subroutine matear_ent(k,time,ts,
     $     const_vertgrad,dCdz_const,dCdz_var,D_dcdz,
     $     ddC13_dC_bml,const_lent,lent_const,dlent_dh,ent_fact,
     $     h_new,h_old,
     $     c,c13,h,
     $     D_C,D_c13,fluxes)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 62 "matear_ent.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 63 "matear_ent.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 64 "matear_ent.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/input.h" 1
c======================== include file input.h  =============================
c
c input data for the seasonal model, stemming from the harmonic 
c      regression (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp        dp s  mixed layer temperature                       deg C
c sal         dp s  mixed layer salinity                          psu
c ws          dp s  wind-speed                                    m s-1
c fCO2_o      dp s  CO2 fugacity in the mixed layer               uatm
c pco2_a      dp s  pCO2 in the atmosphere                        ppm
c dc13_a      dp s  dC13 in the atmosphere                        per mil
c dCdz_var    dp s  vertical C gradient below the mixed layer   umol/kg/m
c kz_var      dp s  vertical diffusion coefficient                m2 s-1
c salk        dp s  salinity normalized alkalinity              umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp,sal,ws,fCO2_o,pco2_a,dc13_a
      double precision dCdz_var,kz_var,salk


# 65 "matear_ent.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 66 "matear_ent.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/c13_params.h" 1
cc=================== include file c13_params.h =============================
c
c parameters for C13 and dC13
c
c REVISIONS:
c
c date     author    remarks
c
c 2.08.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c r_Std          dp  s  C13/C12 ratio of PDB standard
c rstar_Std      dp  s  C13/(C12+C13) ratio of PDB standard
c
c---------------------------------------------------------------------------
c
      double precision r_std,rstar_std
      parameter (r_std = 0.0112372d0, rstar_std = 0.011112328d0)



# 67 "matear_ent.F" 2
      integer k
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
      double precision rates_to_fluxes,c13_to_delta ! functions
c
c --------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      double precision dc13_o,ddc13dz,dcdz,dc13dz
      double precision c_bml,c13_bml,ent_length
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c --------------------------------------------------------------------
c     determine vertical C gradient
c --------------------------------------------------------------------
c
      if (const_vertgrad) then
         dCdz = dCdz_const
      else
         dCdz = dCdz_var + D_dcdz
      endif
c
c --------------------------------------------------------------------
c     calulate the vertical C13 gradient from the vertical
c       dC13 gradient (approximate formula)
c       units [umol kg-1 m-1]
c     changed to accurate formula
c --------------------------------------------------------------------
c    
      dC13_o = c13_to_delta(c13,c)
      ddC13dz = dCdz * ddC13_dC_bml ! unit [per mil m-1]
c      dc13dz = r_std/(1+r_std) * 
c     $     (c * ddC13dz*1.d-3 + dcdz*(dc13_o*1.d-3 + 1.d0))
      dc13dz = r_std/(1+r_std*dc13_o*1.d-3+r_std) * 
     $     ((dc13_o*1.d-3 + 1.d0)*dcdz +
     $      c / (1+r_std*dc13_o*1.d-3+r_std) * ddc13dz * 1.d-3)
c
c --------------------------------------------------------------------
c     calculate contribution only during depeening of the 
c       mixed layer
c --------------------------------------------------------------------
c  

      if (h_new .ge. h_old) then



c
c --------------------------------------------------------------------
c     determine the entrainment length
c --------------------------------------------------------------------
c
         if (const_lent) then
            ent_length = lent_const
         else
c            ent_length = 3.86d0 + 0.076d0 * h
c            ent_length = 0.39d0 + 0.153d0 * h
c
             ent_length = 2.00d0 + dlent_dh * h

            if (ent_length .lt. 10.d0) then
               ent_length = 10.d0
            endif
         endif
c
c --------------------------------------------------------------------
c     determine the different contributions to entrainment
c --------------------------------------------------------------------
c
         c_bml = c + ent_length * dcdz
         c13_bml = c13 + ent_length * dc13dz
c

         D_c(3,k) = ent_fact * 1.d0/h * (h_new - h_old) * (c_bml - c)
         D_c13(3,k) = ent_fact * 1.d0/h * (h_new - h_old) * 
     $        (c13_bml - c13)






         fluxes(3,k) = rates_to_fluxes(D_C(3,k),ts,h)
c
c --------------------------------------------------------------------
c     shoaling period
c --------------------------------------------------------------------
c
      else
         D_c(3,k) = 0.d0
         fluxes(3,k) = 0.d0
         D_c13(3,k) = 0.d0
      endif
c
c --------------------------------------------------------------------
c     for debugging purposes
c --------------------------------------------------------------------
c
c
# 191 "matear_ent.F"

c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

