# 1 "net_comm_prod.F"
c =====================================================================
c
c     SUBROUTINE NET_COMM_PROD
c 
c     PURPOSE: this routine calculates the contribution of the
c                  net community production. This contribution
c                  is calculated from the difference between
c                  the observed rate of change of C13 and the
c                  sum of the rate of changes from the other
c                  processes (air-sea exchange, vertical diffusion,
c                             entrainment and advection)
c              the calculation scheme has been drastically changed from
c                  the original version.
c                  
c
c     VARIABLES:
c 
c     IN : k              : time loop counter
c          ts             : time step
c          D_dc13_org     : correction term for dC13 of organic matter
c          C13_old        : obs C13 in the mixed layer at timestep t
c          C13_new        : obs C13 in the mixed layer at timestep t+ts
c          c13            : obs C13 in the mixed layer at timestep t+0.5*ts
c          c_old          : obs C in the mixed layer at timestep t
c          c_new          : obs C in the mixed layer at timestep t+ts
c          c              : obs C in the mixed layer at timestep t+0.5*ts
c          h              : obs mixed layer depth
c          temp           : obs mixed layer temp
c          sal            : obs mixed layer sal
c          fco2_o         : obs mixed layer fco2
c
c     OUT: D_C            : modified array holding the rates of change for C
c          D_C13          : modified array holding the rates of change for C13
c          fluxes         : modified array holding the fluxes
c          dc13_org       : dc13 value of organic matter
c          sum_fract      : the sum of the fractionation factor for avg
c 
c     REVISION:
c
c     date     author  remarks
c   
c      2.08.96   ng    first implementation
c      5.09.96   ng    included possibility to do backwards integration
c      9.09.96   ng    calculate ncp using the more exact equation given
c                         in the paper
c     17.10.99   ng    included sol_scheme, now solving for u, rather
c                          than for dC/dt, adapting for interannual var.
c                          runs
c
c =====================================================================
c
      subroutine net_comm_prod(k,ts,sol_scheme,
     $     D_dc13_org,
     $     c13_old,c13_new,c_old,c_new,
     $     c,c13,h,temp,sal,fco2_o,dc13_dh,dc_dh,
     $     D_C,D_c13,fluxes,dc13_org,sum_fract)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 65 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 66 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 67 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 68 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/input.h" 1
c======================== include file input.h  =============================
c
c input data for the seasonal model, stemming from the harmonic 
c      regression (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp        dp s  mixed layer temperature                       deg C
c sal         dp s  mixed layer salinity                          psu
c ws          dp s  wind-speed                                    m s-1
c fCO2_o      dp s  CO2 fugacity in the mixed layer               uatm
c pco2_a      dp s  pCO2 in the atmosphere                        ppm
c dc13_a      dp s  dC13 in the atmosphere                        per mil
c dCdz_var    dp s  vertical C gradient below the mixed layer   umol/kg/m
c kz_var      dp s  vertical diffusion coefficient                m2 s-1
c salk        dp s  salinity normalized alkalinity              umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp,sal,ws,fCO2_o,pco2_a,dc13_a
      double precision dCdz_var,kz_var,salk


# 69 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncp_params.h" 1
c===================== include file ncp_params.h =========================
c
c parameters of net community production
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c D_dC13_org      dp s   correction term for dC13 value of organic matter
c dc13_org        dp s   dc13 value of organic matter
c                         [per mil]
c sg_D_dc13_org   dp s   1 sigma uncertainty of D_dc13_org (for OP and MC)
c 
c=============================================================================
c
      double precision D_dc13_org
      double precision sg_D_dc13_org
      double precision dc13_org
# 70 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/c13_params.h" 1
cc=================== include file c13_params.h =============================
c
c parameters for C13 and dC13
c
c REVISIONS:
c
c date     author    remarks
c
c 2.08.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c r_Std          dp  s  C13/C12 ratio of PDB standard
c rstar_Std      dp  s  C13/(C12+C13) ratio of PDB standard
c
c---------------------------------------------------------------------------
c
      double precision r_std,rstar_std
      parameter (r_std = 0.0112372d0, rstar_std = 0.011112328d0)



# 71 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 72 "net_comm_prod.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 73 "net_comm_prod.F" 2
      integer k
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
      double precision rates_to_fluxes,solco2kg ! functions
      double precision c13_to_delta,delta_to_ratio ! function
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      double precision sol
      integer i
      double precision dc13_old,dc13_new,dc13
      double precision fract_tmp
      double precision term1,term2,term3,sum_c,sum_c13
      double precision r_new,r_old,r_org,r_oc
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c --------------------------------------------------------------------
c     calculate the solubility of CO2 using Weiss, 1974
c       mol C kg-1 atm-1, this is directly numerically
c       equivalent ot umol C kg-1 uatm-1
c --------------------------------------------------------------------
c        
      sol = solco2kg(temp,sal)  ! units [mol C kg-1 atm-1 = umol kg-1 uatm-1]
c
c --------------------------------------------------------------------
c     calculate the dC13 of organic matter following
c       the relationship given by Rau et al, 1989
c     include also directly the correction
c --------------------------------------------------------------------
c   
      dc13_org = -0.8d0 * (sol * fCO2_o) - 12.6d0 ! units [per mil]
c
      dc13_org = 1.d-3 * (dc13_org + D_dc13_org) ! no units
      r_org = delta_to_ratio(dc13_org*1.d3)
c
c      write(*,*) k,dc13_org
c
c --------------------------------------------------------------------
c     calculate dc13 at time t+0.5*ts, t and t+ts
c --------------------------------------------------------------------   
c
      dc13 = c13_to_delta(c13,c)
      dC13_old = c13_to_delta(c13_old,c_old)
      dc13_new = c13_to_delta(c13_new,c_new)
c
c --------------------------------------------------------------------
c     calculate average fractionation factor
c --------------------------------------------------------------------   
c
      fract_tmp = 1.d3 * dc13_org - dc13
      sum_fract = sum_fract + fract_tmp
c
c =====================================================================
c     this is the part as calculated in the old model
c     standard solution scheme
c =====================================================================
c
      if (sol_scheme .eq. 'std') then
c
c ---------------------------------------------------------------------
c     calculate the sums of all processes except net community production
c ---------------------------------------------------------------------
c
        sum_c = 0.d0 
        sum_c13 = 0.d0
        do i = 1,4
           sum_c = sum_c + D_C(i,k)
           sum_c13 = sum_c13 + D_C13(i,k)
        enddo
c
c ---------------------------------------------------------------------
c     calculate the three different terms; accurate version
c ---------------------------------------------------------------------
c
        r_oc = delta_to_ratio(dc13)
        r_new = delta_to_ratio(dc13_new)
        r_old = delta_to_ratio(dc13_old)
c     
        term1 = (r_org*(1.d0+r_oc)/(r_org-r_oc)) * sum_c
        term2 = (1.d0+r_org)/((1.d0+r_oc)*(r_org-r_oc)) * c *
     $        (r_new - r_old)
        term3 = - ((1.d0+r_oc)*(1+r_org))/(r_org-r_oc) * sum_c13


        D_C(6,k) = term1 + term2 + term3
        fluxes(6,k) = rates_to_fluxes(D_C(6,k),ts,h)
c
c ---------------------------------------------------------------------
c     calculate the rate of change of net community production
c      and the flux
c ---------------------------------------------------------------------
c
        D_C(5,k) = D_C(6,k) - sum_c
        fluxes(5,k) = rates_to_fluxes(D_C(5,k),ts,h)

c =====================================================================
c     this is solution scheme for adv
c =====================================================================
c
      elseif (sol_scheme .eq. 'adv') then         
c      
c --------------------------------------------------------------------
c     sum up contributions by gasex, diff and entrainment
c --------------------------------------------------------------------
c         
         sum_c = 0.d0
         sum_c13 = 0.d0
          do i = 1,3
            sum_c = sum_c + D_C(i,k)
            sum_c13 = sum_c13 + D_C13(i,k)
         enddo
c      
c --------------------------------------------------------------------
c     solve for net community production
c --------------------------------------------------------------------
c          
         D_C(5,k) = (dc13_dh*(D_C(7,k)-sum_c) 
     $         - dc_dh*(D_c13(7,k)-sum_c13)) /
     $         (dc13_dh - dc_dh*(r_org/(1+r_org)))
         
         fluxes(5,k) = rates_to_fluxes(D_C(5,k),ts,h)
c
         D_C13(5,k) = r_org / (1.d0 + r_org) * D_C(5,k)
      endif
c      
c --------------------------------------------------------------------
c     for debugging purposes
c --------------------------------------------------------------------
c
# 251 "net_comm_prod.F"

c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

