# 1 "run_simulation.F"
c =====================================================================
c
c     SUBROUTINE RUN_SIMULATION
c 
c     PURPOSE: This is the main routine for doing the diagnostic
c                seasonal calculations in the mixed layer
c
c     VARIABLES:
c 
c     IN : sol_scheme      : solution scheme to be used
c          tstart          : start time of integration
c          tend            : end time of integration
c          ts              : time step
c          nstep           : number of steps
c          dc13_coeff      : character specifying which dC13 coefficients
c                              are used                         
c          pv_relship      : character indicating the relationship
c                               that is used for calculating the
c                               piston-velocity
c                              <lm> : Liss and Merlivat
c                              <wa> : Wanninkhof
c          D_fco2_corr     : correction term for mixed layer fco2
c          gasex_fact      : air-sea exchange multiplication factor
c                              (for lm usually 1.7447)
c          ws_coeff        : character specifying wind speed coefficient
c          comp_foc2_online: logical indicating computation of pCO2
c          ent_scheme      : character indicating entrainment scheme
c                              to be used
c                              <in> : integrated vertical gradient scheme
c                              <mc> : mass conservation scheme
c                              <ep> : episodic event scheme
c          h_coeff         : character specifying which h coeff are taken
c          h_th            : depth at which thermocline values for 
c                                 mc entrainment are taken
c          c_th            : C concentration at h_th [umol kg-1]
c          dC13_th         : dC13 concentration at h_th [per mil]
c          dt_ent_re       : recurrence time for entrainment
c          const_lent      : logical indicating use of ent_length
c          lent_const      : const entrainment length scale (for ma scheme)
c          dlent_dh        : ratio of lent to mixed layer depth []
c          ent_fact        : entrainment factor
c          const_Kz        : logical indicating if constant Kz or
c                              seasonally varying Kz is used
c          Kz_const        : value of constant Kz 
c          const_vertgrad  : logical indicating if constant or variable
c                              vertical gradient is used
c          dCdz_const      : constant vertical C gradient 
c          D_dcdz          : correction term for dc/dz
c          ddC13_dC_bml    : ratio of ddC13/dz to dC/dz below mixed layer
c          diff_fact       : vertical diffusion mulitplication factor
c          incl_adv        : logical indicating if effect of advection
c                              is included
c          dC_dh           : horizontal gradient of C
c          ddC13_dh        : horizontal gradient of dC13
c          u               : horizontal velocity
c          D_dc13_org      : change in dC13 value of organic matter
c                          
c     OUT: D_c             : rates of change of the different processes
c          fluxes          : fluxes of the different processes
c          D_c13           : rates of change of C13 of the different proc 
c          u_var           : calculated velocity
c          c_obs           : observed seasonal cycle of C
c          dc13_obs        : observed seasonal cycle of dC13
c          h_obs           : observed seasonal cycle of h
c          temp_obs        : observed seasonal cycle of temp
c          sal_obs         : observed seasonal cycle of sal
c          salk_obs        : observed seasonal cycle of salk
c          fco2_o_obs      : observed seasonal cycle of oceanic fco2
c          pco2_a_obs      : observed seasonal cycle of atmospheric pco2
c          pco2_a_dry      : observed seasonal cycle of atmospheric pco2
c          fco2_a_obs      : observed seasonal cycle of atmospheric fco2
c          dc13_a_obs      : observed seasonal cycle of atmospheric dc13
c          ws_obs          : observed seasonal cycle of windspeed
c          dcdz_obs        : observed seasonal cycle of dcdz
c          kz_obs          : observed seasonal cycle of Kz
c
c          c_sim           : simulated seasonal cycle of c
c          int_rates       : integrated rates of change
c          int_fluxes      : integrated fluxes
c          nyears          : number of analysis years
c
c          chisq           : chi**2 between simulated and obs rates
c          rsq             : r**2 between simulated and obs rates
c          closure         : annual lack of closure
c          amplitude       : simulated amplitude
c          amplitude_obs   : observed amplitude
c          c_min           : value of minimum C
c          c_max           : value of maximum C
c          c_min_obs       : value of observed minimum C
c          c_max_obs       : value of observed maximum C
c          costfn          : cost function (without parameter terms)
c          avg_fract       : average fractionation factor
c          dc13_prc        : dc13 value of processes
c          avg_kex         : average kex
c
c     REVISION:
c
c     date     author  remarks
c   
c     31.07.96   ng    first implementation
c     08.08.96   ng    included matear entrainment, and more seasonal
c                         observations
c     14.08.96   ng    included more statistics
c      5.09.96   ng    included even more statistics
c                ng    included possibility to do backward simulation
c     15.10.99   ng    adapted for interannual variability run, ATTENTION
c                        time units have changed from d-1 to yr-1
c     07.06.00   ng    added salk_obs
c
c =====================================================================
c
      subroutine run_simulation(sol_scheme,
     $     tstart,tend,ts,nstep,
     $     dc13_coeff,
     $     pv_relship,D_fco2_corr,gasex_fact,ws_coeff,
     $     comp_fco2_online, 
     $     ent_scheme,h_coeff,h_th,c_th,dc13_th,
     $     dt_ent_re,const_lent,lent_const,dlent_dh,ent_fact,
     $     const_Kz,kz_const,
     $     const_vertgrad,dCdz_const,D_dcdz,
     $     ddC13_dC_bml,diff_fact,
     $     incl_adv,dC_dh,ddC13_dh,u,u_var,
     $     D_dc13_org,
     $     D_c,D_c13,fluxes,
     $     c_obs,dc13_obs,h_obs,
     $     temp_obs,sal_obs,salk_obs,
     $     fco2_o_obs,pco2_a_obs,fco2_a_obs,pco2_a_dry,
     $     dc13_a_obs,ws_obs,dcdz_obs,kz_obs,
     $     c_sim,
     $     int_rates,int_fluxes,nyears,
     $     chisq,rsq,closure,amplitude,amplitude_obs,
     $     c_min,c_max,c_min_obs,c_max_obs,costfn,
     $     avg_fract,dc13_prc,avg_kex,
     $     error)
c
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 143 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 144 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 145 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 146 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 147 "run_simulation.F" 2
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/gasex_params.h" 1
c===================== include file gasex_params.h =========================
c
c parameters of air-sea exchange
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 06.6.00  ng        added comp_foc2_online
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c 
c pv_relship     c  s   character indicating the relationship between
c                       piston velocity and wind-speed that is used for
c                       calculating the piston-velocity
c                           <lm> : Liss and Merlivat
c                           <wa> : Wanninkhof  
c D_fco2_corr    dp s   correction term for calculated fCO2 ocean     [uatm]
c gasex_fact     dp s   multiplication factor for air-sea exchange
c                           usually 1.0 for Wanninkhof
c                           usually 1.7447 for Liss and Merlivat
c
c ws_coeff       c  s   character specifying wind speed coefficients
c                           <ih> : Isemer and Hasse, 1985
c                           <ae> : AEROCE, 1989-1991
c
c sg_D_fco2_corr dp a   uncertainty of D_fco2_corr
c sg_gasex_fact  dp a   uncertainty of gasex_fact
c
c mean_air_press dp s   mean air pressure [atm] (from St. Davids head)
c mean_rel_humid dp s   mean relative humidity [] (from St. Davids head)
c 
c comp_fco2_online l s  logical indicating whether fco2 should be
c                         computed on or offline
c
c===========================================================================
c
      character pv_relship*2,ws_coeff*2
      double precision D_fco2_corr,gasex_fact
      double precision sg_D_fco2_corr, sg_gasex_fact
c
      double precision mean_air_press,mean_rel_humid




      parameter (mean_air_press = 1.017,mean_rel_humid = 0.87)

c
      logical comp_fco2_online
# 149 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 150 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 151 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncp_params.h" 1
c===================== include file ncp_params.h =========================
c
c parameters of net community production
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c D_dC13_org      dp s   correction term for dC13 value of organic matter
c dc13_org        dp s   dc13 value of organic matter
c                         [per mil]
c sg_D_dc13_org   dp s   1 sigma uncertainty of D_dc13_org (for OP and MC)
c 
c=============================================================================
c
      double precision D_dc13_org
      double precision sg_D_dc13_org
      double precision dc13_org
# 152 "run_simulation.F" 2
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 154 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 155 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/input.h" 1
c======================== include file input.h  =============================
c
c input data for the seasonal model, stemming from the harmonic 
c      regression (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp        dp s  mixed layer temperature                       deg C
c sal         dp s  mixed layer salinity                          psu
c ws          dp s  wind-speed                                    m s-1
c fCO2_o      dp s  CO2 fugacity in the mixed layer               uatm
c pco2_a      dp s  pCO2 in the atmosphere                        ppm
c dc13_a      dp s  dC13 in the atmosphere                        per mil
c dCdz_var    dp s  vertical C gradient below the mixed layer   umol/kg/m
c kz_var      dp s  vertical diffusion coefficient                m2 s-1
c salk        dp s  salinity normalized alkalinity              umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp,sal,ws,fCO2_o,pco2_a,dc13_a
      double precision dCdz_var,kz_var,salk


# 156 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/solution.h" 1
c================== include file solution.h =========================
c
c variables for sensitivity analysis
c
c REVISIONS:
c
c date     author    remarks
c
c 21.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c 
c u_var           dp a   inverse calculated horizontal velocity m s-1
c 
c===========================================================================
c
      double precision u_var(nstepmax)
# 157 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/obs_values.h" 1
c==================== include file obs_values.h  =============================
c
c observed seasonal cycles of input data 
c    (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 08.08.96  ng       first implementation
c 07.06.00  ng       added salk_obs
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp_obs     dp a  mixed layer temperature                       deg C
c sal_obs      dp a  mixed layer salinity                          psu
c ws_obs       dp a  wind-speed                                    m s-1
c fco2_o_obs   dp a  CO2 fugacity in the mixed layer               uatm
c pco2_a_obs   dp a  xco2 in the atmosphere
c fco2_a_obs   dp a  fCO2 in the atmosphere                        uatm
c pco2_a_dry   dp a  pCO2 in the atmosphere                        
cc dc13_a_obs   dp a  dC13 in the atmosphere                        per mil
c dCdz_obs     dp a  vertical C gradient below the mixed layer     umol/kg/m
c kz_obs       dp a  vertical diffusivity                          m2 s-1
c salk_obs     dp a  salinity normalized alk                       umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp_obs(nstepmax),sal_obs(nstepmax)
      double precision ws_obs(nstepmax),fco2_o_obs(nstepmax)
      double precision pco2_a_obs(nstepmax),fco2_a_obs(nstepmax)
      double precision pco2_a_dry(nstepmax)
      double precision dc13_a_obs(nstepmax)
      double precision dCdz_obs(nstepmax),kz_obs(nstepmax)
      double precision salk_obs(nstepmax)


# 158 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/c13_params.h" 1
cc=================== include file c13_params.h =============================
c
c parameters for C13 and dC13
c
c REVISIONS:
c
c date     author    remarks
c
c 2.08.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c r_Std          dp  s  C13/C12 ratio of PDB standard
c rstar_Std      dp  s  C13/(C12+C13) ratio of PDB standard
c
c---------------------------------------------------------------------------
c
      double precision r_std,rstar_std
      parameter (r_std = 0.0112372d0, rstar_std = 0.011112328d0)



# 159 "run_simulation.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/statistics.h" 1
c==================== include file statistics.h ==============================
c
c variables for the run statistics
c
c REVISIONS:
c
c date     author    remarks
c
c 08.8.96  ng        first implementation
c 05.9.96  ng        included c_min,c_max,c_min_obs,c_max_obs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c chisq         dp s   chi**2 between simulated and observed rate of change
c rsq           dp s   r**2 of fit between simulated and observed rates
c closure       dp s   annual lack of closure
c amplitude     dp s   simulated annual amplitude
c amplitude_obs dp s   observed annual amplitude
c c_min         dp s   simulated minimum C
c c_max         dp s   simulated maximum C
c c_min_obs     dp s   observed minimum C
c c_max_obs     dp s   observed maximum C
c par_sum       dp s   value of parameter misfit
c costfn        dp s   value of cost function
c chisq_term    dp s   value of chi**2 term in cost function
c clos_term     dp s   value of closure term in cost function
c ampl_term     dp s   value of amplitude term in cost function
c par_term      dp s   value of parameter term in cost function
c
c-------------------------------------------------------------------------
c
      double precision chisq,rsq,closure,costfn,amplitude
      double precision amplitude_obs,par_sum
      double precision c_min,c_max,c_min_obs,c_max_obs
      double precision chisq_term,clos_term,ampl_term,par_term



# 160 "run_simulation.F" 2
c
      logical error
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
      double precision rates_to_fluxes,c13_to_delta
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      double precision rho,sec_day,day_year
      parameter (rho = 1026.2d0,sec_day = 24.d0 * 3600.d0)
      parameter (day_year = 365.)
      integer k,i
      double precision rstar,dc13_i(5),D_dc13(5)
      double precision dc13_new,dc13_old,dc13
      double precision d_dc13_calc,D_c13_calc
      double precision dc13_tmp,r_prc
      double precision sum,sum_c13
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
CC 
 
      write(*,*) '--RUN_SIMULATION: starting the simulation...'

      write(*,*) '     start time of integration : ',tstart
      write(*,*) '     end time of integration   : ',tend
      write(*,*) '     time step                 : ',ts
      write(*,*) '     # of steps                : ',nstep
      write(*,*) '     ent_scheme                : ',ent_scheme

c
c --------------------------------------------------------------------
c     initialize all integrated values and sums (set them to zero) 
c         especially important for Monte Carlo simulations
c --------------------------------------------------------------------
c       
      call set_sums_to_zero(
     $     sum_fract,sum_kex,
     $     sum_dCdz, sum_ddC13dz,
     $     sum_dc13_prc,nsum_dc13_prc)
c
c ---------------------------------------------------------------------
c     calculate initial values
c ---------------------------------------------------------------------
c
      time = tstart
c
      call init_val(time,dc13_coeff,h_coeff,C_old,C13_old,h_old,
     $     C_sim,error)
      if (error) then
         write(*,*) '--RUN_SIMULATION: an error occured in init_val'
         goto 9900
      endif
c
c ---------------------------------------------------------------------
c     loop over the simulation
c ---------------------------------------------------------------------
c 
      do k=1,nstep
c
c ---------------------------------------------------------------------
c     print out time every year
c ---------------------------------------------------------------------
c
         if (mod(k,400) .eq. 1) then
            write(*,*) '--RUN_SIMULATION: k,time : ',k,time
         endif
c
c ---------------------------------------------------------------------
c     get input values
c ---------------------------------------------------------------------
c
         call input(time,ts,dc13_coeff,h_coeff,ws_coeff,
     $        comp_fco2_online,
     $        c_new,c13_new,h_new,
     $        c,c13,h,
     $        temp,sal,ws,
     $        salk,fco2_o,pco2_a,dc13_a,dcdz_var,kz_var,error)
         if (error) then
            write(*,*) '--RUN_SIMULATION: an error occured in input.'
            goto 9900
         endif
c
c -----------------------------------------------------------------------
c     for debugging purposes
c -----------------------------------------------------------------------
c
# 266 "run_simulation.F"

c     
c
c -----------------------------------------------------------------------
c     end of for debugging purposes
c -----------------------------------------------------------------------
c
c
c ---------------------------------------------------------------------
c     assign observed derivatives of c to arrays 
c ---------------------------------------------------------------------
c
         D_c(7,k) = c_new - c_old 
         fluxes(7,k) = rates_to_fluxes(D_c(7,k),ts,h)
c
c --------------------------------------------------------------------
c     calculate the observed rate of change of C13
c       this is !! NOT !! equal to C13_new - C13_old
c --------------------------------------------------------------------
c
         dC13_old = c13_to_delta(c13_old,c_old)
         dc13_new = c13_to_delta(c13_new,c_new)
         dc13 = c13_to_delta(c13,c)
c
         D_C13(7,k) = r_std / (1.d0 + r_std) * 
     $        (c * 1.d-3 * (dc13_new - dc13_old) +
     $        1.d-3 * dc13 * (c_new - c_old) +
     $        (c_new - c_old))
c     
c ---------------------------------------------------------------------
c     calculate contribution of air-sea exchange
c ---------------------------------------------------------------------
c
         call gasexchange(k,ts,
     $        pv_relship,D_fco2_corr,gasex_fact,
     $        c,c13,h,temp,sal,fco2_o,pco2_a,dc13_a,ws,
     $        sum_kex,fco2_a_obs,pco2_a_dry,
     $        D_c,D_c13,fluxes)
c
c ---------------------------------------------------------------------
c     calculate contribution of vertical diffusion
c ---------------------------------------------------------------------
c
         call vert_diff(k,ts,
     $        ent_scheme,
     $        h_th,c_th,dc13_th,
     $        const_kz,kz_const,kz_var,
     $        const_vertgrad,dcdz_const,dcdz_var,D_dcdz,
     $        ddc13_dc_bml,diff_fact,
     $        c,c13,h,
     $        D_c,D_c13,fluxes)

c ---------------------------------------------------------------------
c     calculate contribution of entrainment
c ---------------------------------------------------------------------
c
         if (ent_scheme .eq. 'in') then
c
            call intvertgrad_ent(k,time,ts,
     $           const_vertgrad,dcdz_const,dcdz_var,D_dcdz,
     $           ddc13_dc_bml,ent_fact,
     $           h_new,h_old,
     $           c,c13,h,
     $           D_c,D_c13,fluxes)
c
         elseif (ent_scheme .eq. 'mc') then
c
c            write(*,*) 'mc entrainment'
            call masscons_ent(k,ts,
     $           h_th,c_th,dc13_th,ent_fact,
     $           h_new,h_old,
     $           c,c13,h,
     $           D_c,D_c13,fluxes)
c
         elseif (ent_scheme .eq. 'ep') then
c
            call episevent_ent(k,time,ts,
     $           dc13_coeff,h_coeff,dt_ent_re,
     $           const_vertgrad,dcdz_const,dcdz_var,D_dcdz,
     $           ddc13_dc_bml,ent_fact,
     $           h_new,h_old,
     $           c,c13,h,
     $           D_c,D_c13,fluxes,error)
c
         elseif (ent_scheme .eq. 'ma') then
c
            call matear_ent(k,time,ts,
     $           const_vertgrad,dCdz_const,dCdz_var,D_dcdz,
     $           ddC13_dC_bml,const_lent,lent_const,dlent_dh,ent_fact,
     $           h_new,h_old,
     $           c,c13,h,
     $           D_C,D_c13,fluxes)
c
         endif
c
c ---------------------------------------------------------------------
c     calculate contribution of horizontal advection
c          part I
c ---------------------------------------------------------------------
c
         if (incl_adv) then
            call advection1(k,ts,sol_scheme,
     $           u,dc_dh,ddc13_dh,
     $           c,c13,h,
     $           dc13_dh,
     $           D_C,D_c13,fluxes)
         else
            D_c(4,k) = 0.0d0
            D_c13(4,k) = 0.0d0
            fluxes(4,k) = 0.0d0
         endif
c
c ---------------------------------------------------------------------
c     calculate contribution of Net community production
c ---------------------------------------------------------------------
c
         call net_comm_prod(k,ts,sol_scheme,
     $        D_dc13_org,
     $        c13_old,c13_new,c_old,c_new,
     $        c,c13,h,temp,sal,fco2_o,dc13_dh,dc_dh,
     $        D_C,D_c13,fluxes,dc13_org,sum_fract)
c
c ---------------------------------------------------------------------
c     calculate contribution of horizontal advection
c          part II (only for sol_scheme 'adv')
c ---------------------------------------------------------------------
c
         if (sol_scheme .eq. 'adv') then
            call advection2(k,ts,sol_scheme,
     $           dc_dh,dc13_dh,
     $           c,c13,h,
     $           u_var,D_C,D_c13,fluxes)
         endif
c     
c ---------------------------------------------------------------------
c     assign observed values to arrays
c       fco2_a_obs is already done in subroutine gasexchange
c       for fco2_o_obs it is necessary to subtract correction term
c ---------------------------------------------------------------------
c
         c_obs(k) = c_old
         dc13_obs(k) = c13_to_delta(c13_old,c_old)
         h_obs(k) = h_old
c
         temp_obs(k) = temp
         sal_obs(k) = sal
         ws_obs(k) = ws
         fco2_o_obs(k) = fco2_o - D_fco2_corr
         pco2_a_obs(k) = pco2_a
c         write(*,*) 'pco2_a,fco2_a : ',k,pco2_a_obs(k),fco2_a_obs(k)
         dc13_a_obs(k) = dc13_a
         salk_obs(k) = salk
         dCdz_obs(k) = dcdz_var
         kz_obs(k) = kz_var
c
c ---------------------------------------------------------------------
c     calculate the remaining components, depending on solution scheme
c        sol. scheme 'adv'
c ---------------------------------------------------------------------
c
         if (sol_scheme .eq. 'adv') then
            sum = 0.d0
            sum_c13 = 0.d0
            do i = 1,5
               sum = sum + D_C(i,k)
               sum_c13 = sum_c13 + D_C13(i,k)
            enddo
            D_C(6,k) = sum
            D_c13(6,k) = sum_c13
            fluxes(6,k) = rates_to_fluxes(D_C(6,k),ts,h)
            c_sim(k+1) = C_new
c
c ---------------------------------------------------------------------
c     standard solution scheme
c ---------------------------------------------------------------------
c
         elseif (sol_scheme .eq. 'std') then
            c_sim(k+1) = c_sim(k) + D_c(6,k)
         endif         
c
c ---------------------------------------------------------------------
c     calculate remaining fluxes : depth component, total calc and
c         total observed
c ---------------------------------------------------------------------
c
         fluxes(8,k) = c
     $        * (h_new-h_old)/(ts*sec_day*day_year)*rho*1.d-6 
         fluxes(9,k) = fluxes(6,k) + fluxes(8,k) ! total calc
         fluxes(10,k) = fluxes(7,k) + fluxes(8,k) ! total obs


c ---------------------------------------------------------------------
c     calculate dC13 values of the five processes
c ---------------------------------------------------------------------
c
         do i = 1,4
            if ((D_C(i,k) .ne. 0.d0) .and. 
     $           (D_C13(i,k)/D_C(i,k) .ne. 1.d0)) then
               nsum_dc13_prc(i) = nsum_dc13_prc(i) + 1
               r_prc = (D_C13(i,k)/D_C(i,k)) / 
     $              (1-(D_C13(i,k)/D_C(i,k)))
               dc13_tmp = (r_prc/r_std - 1.d0) * 1.d3
               sum_dc13_prc(i) = sum_dc13_prc(i) + dc13_tmp
            endif
         enddo
c
c ---------------------------------------------------------------------
c     for debugging purposes
c ---------------------------------------------------------------------
c
# 575 "run_simulation.F"

c
c ---------------------------------------------------------------------
c     set new values to old values
c ---------------------------------------------------------------------
c
         c_old = c_new
         c13_old = c13_new
         h_old = h_new
c
c ---------------------------------------------------------------------
c     update time
c ---------------------------------------------------------------------
c
         time = time + ts
c
c ---------------------------------------------------------------------
c     end of loop over k
c ---------------------------------------------------------------------
c
      enddo
c
c ---------------------------------------------------------------------
c     calculate integrated values
c ---------------------------------------------------------------------
c
      call calc_int_val(D_c,D_c13,fluxes,tstart,tend,ts,nstep,
     $     int_fluxes,int_rates,nyears)
c
c ---------------------------------------------------------------------
c     calculate run statistic and averages
c ---------------------------------------------------------------------
c
      call calc_run_stat(D_C,c_sim,c_obs,tstart,tend,ts,nstep,
     $     sol_scheme,
     $     sum_dc13_prc,nsum_dc13_prc,sum_fract,sum_kex,
     $     dc13_prc,avg_fract,avg_kex,
     $     chisq,rsq,closure,amplitude,amplitude_obs,
     $     c_min,c_max,c_min_obs,c_max_obs,
     $     costfn)
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c        
 9900 write(*,9920) 
 9920 format(/'--RUN_SIMULATION: an error occured.')
      error = .true.
      return
      end

