# 1 "write_mc_output.F"
c =====================================================================
c
c     SUBROUTINE WRITE_MC_OUTPUT
c
c     PURPOSE: writes the parameters and the integrated values of
c               the standard run to file or screen, depending
c               on value of unit
c     
c
c     VARIABLES:
c 
c     IN:  unit            : unit number to write to
c          notes           : additional notes for run
c          tstart          : start time of integration
c          tend            : end time of integration
c          ts              : time step
c          nstep           : number of steps
c          sol_scheme      : solution scheme
c          dc13_coeff      : character specifying which dC13 coefficients
c                              are used       
c                            <o1> : original data with 1st order fit   
c                            <o2> : original data with 2nd order fit   
c                            <a2> : artficial data with 2nd order fit   
c                            <n1> : adjusted data with 1st order fit
c                            <n2> : adjusted data with 2nd order fit   
c                            <m2> : adj. manip. data with 2nd o. fit  
c          pv_relship      : character indicating the relationship
c                               that is used for calculating the
c                               piston-velocity
c                              <lm> : Liss and Merlivat
c                              <wa> : Wanninkhof
c          D_fco2_corr     : correction term for mixed layer fco2
c          gasex_fact      : air-sea exchange multiplication factor
c                              (for lm usually 1.7447)
c          ws_coeff        : character specifying wind speed coefficient
c                              <ih> : Isemer and Hasse, 1985
c                              <ae> : AEROCE
c          ent_scheme      : character indicating entrainment scheme
c                              to be used
c                              <in> : integrated vertical gradient scheme
c                              <mc> : mass conservation scheme
c                              <ep> : episodic event scheme
c          h_coeff         : character specifying which h coeff are taken
c          h_th            : depth at which thermocline values for 
c                                 mc entrainment are taken
c          c_th            : C concentration at h_th [umol kg-1]
c          dC13_th         : dC13 concentration at h_th [per mil]
c          dt_ent_re       : recurrence time for entrainment
c          const_lent      : logical indicating use of lent_const
c          lent_const      : entrainment length scale for matear ent. [m]
c          dlent_dh        : ratio of lent to mixed layer depth []
c          ent_fact        : entrainment multiplication factor
c          const_Kz        : logical indicating if constant Kz or
c                              seasonally varying Kz is used
c          Kz_const        : value of constant Kz 
c          const_vertgrad  : logical indicating if constant or variable
c                              vertical gradient is used
c          dCdz_const      : constant vertical C gradient 
c          ddC13_dC_bml    : ratio of ddC13/dz to dC/dz below mixed layer
c          diff_fact       : vertical diffusion mulitplication factor
c          incl_adv        : logical indicating if effect of advection
c                              is included
c          dC_dh           : horizontal gradient of C
c          ddC13_dh        : horizontal gradient of dC13
c          u               : horizontal velocity
c          D_dc13_org      : change in dC13 value of organic matter
c                          
c          nrun            : number of runs
c          p_init          : inital parameter
c          p_opt           : optimum parameters
c          sg_p            : uncertainty of parameters
c          int_rates_std   : integrated rates of change of standard run
c          int_fluxes_std  : integrated fluxes of standard run
c          nyears          : number of analysis years
c          sg_int_rates    : 1-sigma uncertainty of int_rates
c          wsg_int_rates   : weighted 1-sigma uncertainty of int_rates
c          sg_int_fluxes   : 1-sigma uncertainty of int_fluxes
c          wsg_int_fluxes  : weighted 1-sigma uncertainty of int_fluxes
c          chisq_std       : chi**2 between simulated and obs rates of std run
c          rsq_std         : r**2 between simulated and obs rates of std run
c          closure_std     : annual lack of closure of std run
c          costfn_std      : value of cost function of std run
c          mean_costfn     : mean cost function of all runs
c          costfn_min      : minimum of cost function
c          costfn_max      : maximum of cost function
c
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     19.08.96   ng     first implementation
c     18.10.99   ng     adapted for interannual variability
c     20.10.99   ng     added  some improvement
c 
c =====================================================================
c
      subroutine write_mc_output(unit,
     $     notes,exp_name,
     $     tstart,tend,ts,sol_scheme,
     $     dc13_coeff,
     $     pv_relship,D_fco2_corr,gasex_fact,ws_coeff,    
     $     ent_scheme,h_coeff,h_th,c_th,dc13_th,
     $     dt_ent_re,const_lent,lent_const,dlent_dh,ent_fact,
     $     const_Kz,Kz_const,
     $     const_vertgrad,dCdz_const,
     $     ddC13_dC_bml,diff_fact,
     $     incl_adv,dC_dh,ddC13_dh,u,
     $     D_dc13_org,
c
     $     nrun,
     $     p_init,p_opt,sg_p,
c
     $     int_rates_std,int_fluxes_std,nyears,
     $     sg_int_rates,sg_int_fluxes,
     $     wsg_int_rates,wsg_int_fluxes,
     $     chisq_std,rsq_std,closure_std,
     $     costfn_std,mean_costfn,costfn_min,costfn_max,
     $     error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 129 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 130 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 131 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 132 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 133 "write_mc_output.F" 2
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/gasex_params.h" 1
c===================== include file gasex_params.h =========================
c
c parameters of air-sea exchange
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 06.6.00  ng        added comp_foc2_online
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c 
c pv_relship     c  s   character indicating the relationship between
c                       piston velocity and wind-speed that is used for
c                       calculating the piston-velocity
c                           <lm> : Liss and Merlivat
c                           <wa> : Wanninkhof  
c D_fco2_corr    dp s   correction term for calculated fCO2 ocean     [uatm]
c gasex_fact     dp s   multiplication factor for air-sea exchange
c                           usually 1.0 for Wanninkhof
c                           usually 1.7447 for Liss and Merlivat
c
c ws_coeff       c  s   character specifying wind speed coefficients
c                           <ih> : Isemer and Hasse, 1985
c                           <ae> : AEROCE, 1989-1991
c
c sg_D_fco2_corr dp a   uncertainty of D_fco2_corr
c sg_gasex_fact  dp a   uncertainty of gasex_fact
c
c mean_air_press dp s   mean air pressure [atm] (from St. Davids head)
c mean_rel_humid dp s   mean relative humidity [] (from St. Davids head)
c 
c comp_fco2_online l s  logical indicating whether fco2 should be
c                         computed on or offline
c
c===========================================================================
c
      character pv_relship*2,ws_coeff*2
      double precision D_fco2_corr,gasex_fact
      double precision sg_D_fco2_corr, sg_gasex_fact
c
      double precision mean_air_press,mean_rel_humid




      parameter (mean_air_press = 1.017,mean_rel_humid = 0.87)

c
      logical comp_fco2_online
# 135 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 136 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 137 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncp_params.h" 1
c===================== include file ncp_params.h =========================
c
c parameters of net community production
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c D_dC13_org      dp s   correction term for dC13 value of organic matter
c dc13_org        dp s   dc13 value of organic matter
c                         [per mil]
c sg_D_dc13_org   dp s   1 sigma uncertainty of D_dc13_org (for OP and MC)
c 
c=============================================================================
c
      double precision D_dc13_org
      double precision sg_D_dc13_org
      double precision dc13_org
# 138 "write_mc_output.F" 2
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 140 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/conj_grad.h" 1
c===================== include file conj_grad.h =========================
c
c variables for finding minimum using conjugate gradient technique
c
c REVISIONS:
c
c date     author    remarks
c
c 12.8.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c     
c assign         l  s   logical for subroutine assign_parameters
c                        true : assign values to parameters
c                        false: assign parameters to values   
c p             dp  a   array of parameters
c p_opt         dp  a   array of optimum parameters
c sg_p          dp  a   sigma of parameters
c p_init        dp  a   array of initial parameters
c nparams        i  s   dimension of parameters
c npmax          i  s   maximum dimension of p
c iter           i  s   number of iterations
c fret          dp  s   value of function at minimum
c hessian       dp  a   hessian matrix
c covm          dp  a   inverse of hessian matrix, covariance matrix
c
c sg_c          dp  s   1-sigma uncertainty of C [umol kg-1]
c sg_dcdt       sp  s   1-sigma uncertainty of dcdt [umol kg-1 day-1]
c                          (estimated from figure)
c
c===========================================================================
c
      logical assign
      double precision ftol,fret
      integer nruns
      integer nparams,iter


      parameter(nparams = 10)










      double precision p(nparams),p_opt(nparams),p_init(nparams)
      double precision sg_p(nparams)
      double precision hessian(nparams,nparams),covm(nparams,nparams)
c
      
# 141 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 142 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/monte_carlo.h" 1
c===================== include file monte_carlo.h =========================
c
c general variables for monte carlo simulations
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c  
c nrunmax       i  s   maximal number of mc runs             
c nrun          i  s   number of mc runs
c
c *_r          dp  s   parameters with a random component added. size of
c                        random component is proportional to sg of this
c                        parameter. For the parameter definitions see
c                        the *_params.h files 
c 
c
c===========================================================================
c
      integer nrunmax,nrun
      parameter(nrunmax = 2000)
      
      double precision gasex_fact_r,D_fco2_corr_r
      double precision diff_fact_r,D_dcdz_r,ddC13_dC_bml_r,lent_const_r
      double precision dlent_dh_r
      double precision D_dc13_org_r
      double precision u_r,dc_dh_r,ddc13_dh_r
c
# 143 "write_mc_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_statistics.h" 1
c================== include file mc_statistics.h =========================
c
c variables of statistics of monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c  
c int_rates_std   dp a   array holding standard integrated rates
c int_fluxes_std  dp a   array holding standard integrated fluxes
c costfn_std      dp s   value of cost function for standard run
c rsq_std         dp s   r**2 value for standard run
c chisq_std       dp s   chi**2 value for standard run
c amplitude_std   dp s   amplitude of standard run
c c_min_std       dp s   minimum C of standard run
c c_max_std       dp s   maximum C of standard run
c
c var_int_rates   dp a   array holding variance of integrated rates 
c                            (over monte carlo runs)
c var_int_fluxes  dp a   array holding variance of integrated fluxes
c wvar_int_rates  dp a   array holding weighted variance of integrated rates 
c                                 (over monte carlo runs)
c wvar_int_fluxes dp a   array holding weighted variance of integrated fluxes
c sum_costfn      dp s   sum of cost function
c mean_costfn     dp s   mean of cost function
c costfn_min      dp s   minimum of cost function
c costfn_max      dp s   maximum of cost function
c 
c sg_int_rates    dp s   1-sigma uncertainty of int_rates
c sg_int_fluxes   dp s   1-sigma uncertainty of int_fluxes
c wsg_int_rates   dp s   1-sigma weighted uncertainty of int_rates
c wsg_int_fluxes  dp s   1-sigma weighted uncertainty of int_fluxes
c 
c===========================================================================
c
      double precision int_rates_std(nyearmax,nproc_rates)
      double precision int_fluxes_std(nyearmax,nproc_fluxes)
      double precision costfn_std
      double precision closure_std,rsq_std,chisq_std,amplitude_std
      double precision c_min_std,c_max_std
c
      double precision var_int_rates(nyearmax,nproc_rates)
      double precision var_int_fluxes(nyearmax,nproc_fluxes)
      double precision wvar_int_rates(nyearmax,nproc_rates)
      double precision wvar_int_fluxes(nyearmax,nproc_fluxes)
c   
      double precision sg_int_rates(nyearmax,nproc_rates)
      double precision sg_int_fluxes(nyearmax,nproc_fluxes)
      double precision wsg_int_rates(nyearmax,nproc_rates)
      double precision wsg_int_fluxes(nyearmax,nproc_fluxes)
c
      double precision sum_costfn,mean_costfn
      double precision costfn_min,costfn_max
c

# 144 "write_mc_output.F" 2

      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer i,ny,colons,i1,i2,ii,jmax
      integer n
      character date*17
cBX      character*15 tmp(nyearmax)
      character*17 tmp(nyearmax)
      character*30 tmp2(nproc_fluxes)
      real avg_int_fluxes(nproc_fluxes),
     $     avg_sg_int_fluxes(nproc_fluxes)
      real avg_int_rates(nproc_rates),
     $     avg_sg_int_rates(nproc_rates)
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      error = .false.
c
c ---------------------------------------------------------------------
c     write general information 
c ---------------------------------------------------------------------
c
      if (unit .ne. 6) then
         write(unit,9000) 
 9000    format(//'------------------------------------------',
     $            '---------',/
     $            ' Results of monte carlo simulations of the ',/
     $            '    diagnostic box model',/
     $            '    of the seasonal carbon cycle at ',/





     $            '    Station HOT (HAWI data) ',//





     $            '    written by Nicolas Gruber, 1996-2001 ',/
     $            '    this is version 4.2 ',//
     $            '    based on the program model.F developed',/
     $            '    during 1989 to 1992',/
     $            '------------------------------------------',
     $            '--------'/)
c
      endif
c
c ---------------------------------------------------------------------
c     get date
c ---------------------------------------------------------------------
c
      call getdate(date)
c
c ---------------------------------------------------------------------
c     write general specification of this run
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A)')' general specifications for this model run :'
      write(unit,'(2A)')    '   date               : ',date
      write(unit,'(2A)')    '   name of experiment : ',exp_name 
      write(unit,'(A,F7.1)')'   start time         : ',tstart
      write(unit,'(A,F7.1)')'   end time           : ',tend
      write(unit,'(A,F7.5)')'   time step (years)  : ',ts
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' specifications for location :'





      write(unit,'(A)')     '   Station HOT (HAWI data) '






c
c ---------------------------------------------------------------------
c     write specification for solution scheme
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)')' specifications for solution scheme :'
c
      if (sol_scheme .eq. 'std') then
         write(unit,'(2A)') '   Standard (original) solution scheme ',
     $        'used, i.e. dC/dt is solved for'
      elseif (sol_scheme .eq. 'adv') then
         write(unit,'(2A)') '   Advection solution scheme used, ',
     $        'i.e. u is solved for'
      endif
c
c ---------------------------------------------------------------------
c     write specification for air-sea gasexchange
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)')' specifications for air-sea gasexchange :'
c
      if (pv_relship .eq. 'wa') then
         write(unit,'(2A)') '   Wanninkhof (1992) quadratic ',
     $        'piston velocity relationship used'
      elseif (pv_relship .eq. 'lm') then
         write(unit,'(2A)') '   Liss and Merlivat (1987) linear ',
     $        'piston velocity relationship used'
      endif
c         
      write(unit,'(A,F8.2)')'   correction term for fCO2 oc [uatm]) :', 
     $     D_fCO2_corr
      write(unit,'(2A,F7.4)')'   multiplication factor for air-sea ', 
     $     'gasexchange : ',gasex_fact
c
      if (ws_coeff .eq. 'ih') then
         write(unit,'(2A)')  '   wind-speed coefficients of Isemer',
     $        ' and Hasse'
      elseif (ws_coeff .eq. 'ae') then
         write(unit,'(A)')  '   wind-speed coefficients of AEROCE'
      endif
         
c
c ---------------------------------------------------------------------
c     write specification for vertical processes
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' specifications for vertical diffusion',
     $     ' and entrainment :'
c
c
      if (ent_scheme .eq.  'mc') then
c
         write(unit,'(A)') 
     $    '     mass conservation entrainment scheme '
         write(unit,'(A,F6.1)') 
     $        '     depth where thermocline values are taken : ',h_th
         write(unit,'(A,F6.1)')
     $        '     C concentration at this depth : ',c_th
         write(unit,'(A,F6.2)')
     $        '     dC13 value at this depth      : ',dc13_th
c
      elseif (ent_scheme .eq. 'ep') then
         write(unit,'(A)')
     $        '     episodic event entrainment scheme '
         write(unit,'(A,F6.1)')   
     $        '     entrainment recurrence period : ', dt_ent_re
c     
      elseif (ent_scheme .eq. 'in') then
         write(unit,'(A)')
     $        '     integrated vertical gradient scheme '
      elseif (ent_scheme .eq. 'ma') then
         write(unit,'(A)')
     $        '     Matear (1995) entrainment scheme '
         if (const_lent) then
            write(unit,'(A,F6.1)')
     $           '     constant entrainment length : ',lent_const
         else
            write(unit,'(A/,2A,F6.4)')
     $           '     variable entrainment length ',
     $           '     ratio of entrainment length to ',
     $           'mixed layer depth : ',dlent_dh
         endif
      endif
c
      if (h_coeff .eq. 's') then
         write(unit,'(A)') 
     $        '     h coefficients from station S (1981-89)'
      elseif (h_coeff .eq. 'b') then
         write(unit,'(A)')
     $        '     h coefficients from BATS (1991-94)'
      elseif (h_coeff .eq. 'c') then
         write(unit,'(A)')
     $        '     h coefficients from BATS CTD (1989-93)'
      elseif (h_coeff .eq. 'a') then
         write(unit,'(A)')
     $        '     h coefficients from avg BATS CTD (1989-93)'
      endif
c
      write(unit,'(A,F5.2)')
     $    '     multiplication factor for entrainment : ',ent_fact
c
      if (const_kz) then
         write(unit,'(A,e10.3)') 
     $    '     seasonally constant Kz : ',kz_const
      else
         write(unit,'(A)')
     $    '     seasonally varying Kz '
      endif
c
      if (ent_scheme .ne. 'mc') then
c
         if (const_vertgrad) then
            write(unit,'(A,f7.3)') 
     $           '     seasonally constant dC/dz [umol kg-1 m-1 : ',
     $           dCdz_const
         else
            write(unit,'(A)')
     $           '     seasonally varying dC/dz'
         endif
c
         write(unit,'(A,/A,f10.5)')
     $        '     ratio of vertical dC13 and C gradients ',
     $        '     below the mixed layer [per mil kg umol-1] : ',
     $        ddC13_dC_bml
c
      endif
c
      write(unit,'(A,F5.2)')
     $    '     multiplication factor for vertical diffusion : ',
     $     diff_fact
c
c ---------------------------------------------------------------------
c     write specification for advection
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' specifications for horizontal advection :'
c
      if (incl_adv) then
         if (sol_scheme .eq. 'std') then
            write(unit,'(A,F6.2)')
     $           '     horizontal velocity [m s-1]            : ',u
         endif
c
         write(unit,'(A,E10.4)')
     $        '     horizontal C gradient [umol kg-1 m-1]  : ',
     $        dC_dh
c
         write(unit,'(A,E10.4)')
     $        '     horizontal dC13 gradient [per mil m-1] : ',
     $        ddC13_dh
      else
         write(unit,'(A)')
     $        '     horizontal advection not included : '
      endif
c
c ---------------------------------------------------------------------
c     write specification for net community production
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)')' specification for ',
     $     'net community production :'
      write(unit,'(A,F6.2)')
     $    '     change in dC13 of organic matter : ',D_dc13_org
c
c ---------------------------------------------------------------------
c     write additional comments
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' Additional comments : ',notes
c
c ---------------------------------------------------------------------
c     write parameters
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' monte carlo parameters : '
c
      write(unit,'(4(a9,x)/)') 
     $     'parameter',
     $     'initial  ',
     $     '1-sg     ',
     $     'optimum  '
       
      do n = 1,nparams
         write(unit,'(5x,i2,3x,f7.4,3x,f7.4,3x,f7.4)') 
     $        n,p_init(n),sg_p(n),p_opt(n)
      enddo
c
c ---------------------------------------------------------------------
c     write statistics of standard run
c ---------------------------------------------------------------------
c
      if (sol_scheme .eq. 'std') then
         write(unit,9800)
c     
c     







         write(unit,'(/A/)') ' run statistics : '
         write(unit,'(A,F8.4)') '    chi**2 (rates)         : ',
     $        chisq_std
         write(unit,'(A,F6.4)') '    r**2 (rates)           : ',
     $        rsq_std

         write(unit,'(A,F6.2)') '    annual lack of closure : ',
     $        closure_std
         write(unit,'(A,F10.8)') '    cost function (w/o par): ',
     $        costfn_std
      endif
c
c ---------------------------------------------------------------------
c     write statistics of monte carlo
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' monte carlo statistics : '
      write(unit,'(a,i4)')    '    number of mc runs      : ',
     $     nrun
      write(unit,'(A,f10.6)') '    mean cost function     : ',
     $     mean_costfn
      write(unit,'(A,f10.6)') '    minimal cost function  : ',
     $     costfn_min
      write(unit,'(A,f10.6)') '    maximal cost function  : ',
     $     costfn_max

c
c ---------------------------------------------------------------------
c     write integrated fluxes with unweighted uncertainties
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' Integrated fluxes with ',
     $     'uncertainties [mol m-2]'

      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)


         do i=1,nproc_fluxes
            do ny = i1,i2
cBX               write(tmp(ny),'(2x,F7.2,x,F5.2)') 
               write(tmp(ny),'(2x,F7.2,x,F7.2)') 
     $              int_fluxes_std(ny,i),sg_int_fluxes(ny,i)
            enddo
            write(unit,9200) proc_fluxes_name(i),
     $        (tmp(ny), ny=i1,i2)
         enddo
c
         write(unit,'(//)')
      enddo
      
cc
cc ---------------------------------------------------------------------
cc     write integrated fluxes with weighted uncertainties
cc ---------------------------------------------------------------------
cc
c      write(unit,9800)
cc
c      write(unit,'(/2A/)') ' Integrated fluxes with weighted ',
c     $     'uncertainties [mol m-2]'
c
c      colons = 5
c      jmax = (nyears-1)/colons + 1
c      do ii=1,nyears,colons
c         i1 = ii
c         i2 = min((ii+colons-1),nyears)
cc         
c         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
c
c
c         do i=1,nproc_fluxes
c            do ny = i1,i2
c               write(tmp(ny),'(2x,F7.2,x,F5.2)') 
c     $              int_fluxes_std(ny,i),wsg_int_fluxes(ny,i)
c            enddo
c            write(unit,9200) proc_fluxes_name(i),
c     $        (tmp(ny), ny=i1,i2)
c         enddo
cc
c         write(unit,'(//)')
c      enddo
cc
c ---------------------------------------------------------------------
c     compute and write average fluxes and uncertainty
c ---------------------------------------------------------------------
c
      do i = 1,nproc_fluxes
         avg_int_fluxes(i) = 0.d0
         avg_sg_int_fluxes(i) = 0.d0
      enddo

      do ny = 1,nyears
         do i = 1,nproc_fluxes
            avg_int_fluxes(i) = avg_int_fluxes(i)+int_fluxes_std(ny,i)
            avg_sg_int_fluxes(i) = avg_sg_int_fluxes(i)
     $           +sg_int_fluxes(ny,i)
         enddo
      enddo
c
      do i = 1,nproc_fluxes
         avg_int_fluxes(i) = avg_int_fluxes(i)/nyears
         avg_sg_int_fluxes(i) = avg_sg_int_fluxes(i)/nyears
      enddo
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' Average Integrated fluxes with ',
     $     'uncertainties[mol m-2]'
c
      write(unit,'(A)') '         Average  1-sg Uncertainty'
      do i=1,nproc_fluxes
cBX         write(unit,'(2x,a4,2x,f7.2,x,f5.2)') 
         write(unit,'(2x,a4,2x,f7.2,x,f7.2)') 
     $        proc_fluxes_name(i),avg_int_fluxes(i),
     $         avg_sg_int_fluxes(i)
      enddo
c

c
c ---------------------------------------------------------------------
c     compute and write anomaly fluxes
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' Anomalies of Integrated Fluxes with ',
     $     'uncertainties [mol m-2]'

      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
         do i=1,nproc_fluxes
            do ny = i1,i2
cBX               write(tmp(ny),'(2x,F7.2,x,F5.2)') 
               write(tmp(ny),'(2x,F7.2,x,F7.2)') 
     $           (int_fluxes_std(ny,i)-avg_int_fluxes(i)),
     $           sg_int_fluxes(ny,i)
            enddo
            write(unit,9300) proc_fluxes_name(i),
     $        (tmp(ny), ny=i1,i2)
         enddo
         write(unit,'(//)')
      enddo
      
      write(unit,9800)
c
c ---------------------------------------------------------------------
c     write integrated rates with unweighted uncertainties
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' Integrated rates with ',
     $     'uncertainties [umol kg-1]'

      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)


         do i=1,nproc_rates
            do ny = i1,i2
cBX               write(tmp(ny),'(2x,F7.1,x,F5.1)') 
               write(tmp(ny),'(2x,F7.1,x,F7.1)') 
     $              int_rates_std(ny,i),sg_int_rates(ny,i)
            enddo
            write(unit,9300) proc_fluxes_name(i),
     $        (tmp(ny), ny=i1,i2)
         enddo
c
         write(unit,'(//)')
      enddo
cc
cc ---------------------------------------------------------------------
cc     write integrated rates with weighted uncertainties
cc ---------------------------------------------------------------------
cc
c      write(unit,9800)
cc
c      write(unit,'(/2A/)') ' Integrated rates with weighted ',
c     $     'uncertainties [umol kg-1]'
c      colons = 5
c      jmax = (nyears-1)/colons + 1
c      do ii=1,nyears,colons
c         i1 = ii
c         i2 = min((ii+colons-1),nyears)
cc         
c         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
c
c
c         do i=1,nproc_rates
c            do ny = i1,i2
c               write(tmp(ny),'(2x,F7.1,x,F5.1)') 
c     $              int_rates_std(ny,i),wsg_int_rates(ny,i)
c            enddo
c            write(unit,9300) proc_rates_name(i),
c     $        (tmp(ny), ny=i1,i2)
c         enddo
cc
c         write(unit,'(//)')
c      enddo
c
c      write(unit,9800)
cc
c ---------------------------------------------------------------------
c     compute and write average rates and uncertainty
c ---------------------------------------------------------------------
c
      do i = 1,nproc_rates
         avg_int_rates(i) = 0.d0
         avg_sg_int_rates(i) = 0.d0
      enddo

      do ny = 1,nyears
         do i = 1,nproc_rates
            avg_int_rates(i) = avg_int_rates(i)+int_rates_std(ny,i)
            avg_sg_int_rates(i) = avg_sg_int_rates(i)
     $           +sg_int_rates(ny,i)
         enddo
      enddo
c
      do i = 1,nproc_rates
         avg_int_rates(i) = avg_int_rates(i)/nyears
         avg_sg_int_rates(i) = avg_sg_int_rates(i)/nyears
      enddo
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' Average Integrated rates with ',
     $     'uncertainties[mol m-2]'
c
      write(unit,'(A)') '         Average  1-sg Uncertainty'
      do i=1,nproc_rates
cBX         write(unit,'(2x,a4,2x,f7.2,x,f5.2)') 
         write(unit,'(2x,a4,2x,f7.2,x,f7.2)') 
     $        proc_rates_name(i),avg_int_rates(i),
     $         avg_sg_int_rates(i)
      enddo
c

c
c ---------------------------------------------------------------------
c     compute and write anomaly rates
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' Anomalies of Integrated Rates with ',
     $     'uncertainties [mol m-2]'

      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
         do i=1,nproc_rates
            do ny = i1,i2
cBX               write(tmp(ny),'(2x,F7.2,x,F5.2)') 
               write(tmp(ny),'(2x,F7.2,x,F7.2)') 
     $           (int_rates_std(ny,i)-avg_int_rates(i)),
     $           sg_int_rates(ny,i)
            enddo
            write(unit,9300) proc_rates_name(i),
     $        (tmp(ny), ny=i1,i2)
         enddo

         write(unit,'(//)')
      enddo
      
      write(unit,9800)
cc
c ---------------------------------------------------------------------
c     output to files for plotting
c       changed output to be centered at 0.5
c ---------------------------------------------------------------------
c
      open(30,file="int_rate_mc_anomalies.set")
      do ny = 1,nyears
         do i = 1,nproc_rates
            write(tmp2(i),'(2x,F8.3,x,F8.3,x,F8.3)') 
     $           int_rates_std(ny,i)-avg_int_rates(i),
     $           int_rates_std(ny,i)-avg_int_rates(i)
     $           +sg_int_rates(ny,i),
     $           int_rates_std(ny,i)-avg_int_rates(i)
     $           -sg_int_rates(ny,i)           
         enddo
         write(30,9500) 
     $        int(tstart)+ny-0.5,
     $        (tmp2(i),i=1,nproc_rates)
      enddo
      close(30)
c
      open(32,file="int_flux_mc_anomalies.set")
      do ny = 1,nyears
         do i = 1,nproc_fluxes
            write(tmp2(i),'(2x,F8.3,x,F8.3,x,F8.3)') 
     $           int_fluxes_std(ny,i)-avg_int_fluxes(i),
     $           int_fluxes_std(ny,i)-avg_int_fluxes(i)
     $           +sg_int_fluxes(ny,i),
     $           int_fluxes_std(ny,i)-avg_int_fluxes(i)
     $           -sg_int_fluxes(ny,i)         
         enddo
 
         write(32,9500) 
     $        int(tstart)+ny-0.5,
     $        (tmp2(i),i=1,nproc_fluxes)
      enddo
      close(32)
 9500 format(1x,f9.2,10(a30))
c
c ---------------------------------------------------------------------
c     format statements
c ---------------------------------------------------------------------
c
 9800 format(/'-------------------------------------------------')
c
cBX 9100 format(2x,5(9x,i4,2x))
cBX 9200 format(2x,a4,5(a15))
cBX 9300 format(2x,a4,5(a15))
 9100 format(2x,5(9x,i4,4x))
 9200 format(2x,a4,5(a17))
 9300 format(2x,a4,5(a17))
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--WRITE_MC_OUTPUT: an error occurred ',
     $     'while writing..'
      error = .true.
c
      return

      end











