# 1 "write_std_output.F"
c =====================================================================
c
c     SUBROUTINE WRITE_STD_OUTPUT
c
c     PURPOSE: writes the parameters and the integrated values of
c               the standard run to file or screen, depending
c               on value of unit
c     
c
c     VARIABLES:
c 
c     IN:  unit            : unit number to write to
c          notes           : additional notes for run
c          exp_name        : name of experiment
c          tstart          : start time of integration
c          tend            : end time of integration
c          ts              : time step
c          nstep           : number of steps
c          sol_scheme      : solution scheme
c          dc13_coeff      : character specifying which dC13 coefficients
c                              are used       
c                            <o1> : original data with 1st order fit   
c                            <o2> : original data with 2nd order fit   
c                            <a2> : artficial data with 2nd order fit   
c                            <n1> : adjusted data with 1st order fit
c                            <n2> : adjusted data with 2nd order fit 
c                            <m2> : adj. manip. data with 2nd o. fit  
c          pv_relship      : character indicating the relationship
c                               that is used for calculating the
c                               piston-velocity
c                              <lm> : Liss and Merlivat
c                              <wa> : Wanninkhof
c          D_fco2_corr     : correction term for mixed layer fco2
c          gasex_fact      : air-sea exchange multiplication factor
c                              (for lm usually 1.7447)
c          ws_coeff        : character specifying wind speed coefficient
c                              <ih> : Isemer and Hasse, 1985
c                              <ae> : AEROCE
c          comp_fco2_online: logical indicating computation of fCO2
c          ent_scheme      : character indicating entrainment scheme
c                              to be used
c                              <in> : integrated vertical gradient scheme
c                              <mc> : mass conservation scheme
c                              <ep> : episodic event scheme
c          h_coeff         : character specifying which h coeff are taken
c          h_th            : depth at which thermocline values for 
c                                 mc entrainment are taken
c          c_th            : C concentration at h_th [umol kg-1]
c          dC13_th         : dC13 concentration at h_th [per mil]
c          dt_ent_re       : recurrence time for entrainment
c          const_lent      : logical indicating use of lent_const
c          lent_const      : entrainment length scale for matear ent. [m]
c          dlent_dh        : ratio of lent to mixed layer depth []
c          ent_fact        : entrainment multiplication factor
c          const_Kz        : logical indicating if constant Kz or
c                              seasonally varying Kz is used
c          Kz_const        : value of constant Kz 
c          const_vertgrad  : logical indicating if constant or variable
c                              vertical gradient is used
c          dCdz_const      : constant vertical C gradient 
c          ddC13_dC_bml    : ratio of ddC13/dz to dC/dz below mixed layer
c          diff_fact       : vertical diffusion mulitplication factor
c          incl_adv        : logical indicating if effect of advection
c                              is included
c          dC_dh           : horizontal gradient of C
c          ddC13_dh        : horizontal gradient of dC13
c          u               : horizontal velocity
c          D_dc13_org      : change in dC13 value of organic matter
c                          
c          int_rates       : integrated rates of change
c          int_fluxes      : integrated fluxes
c          nyears          : number of analysis years
c
c          chisq           : chi**2 between simulated and obs rates
c          rsq             : r**2 between simulated and obs rates
c          closure         : annual lack of closure
c          costfn          : value of cost function (without parameter
c                               terms)
c          avg_fract       : average fractionation factor
c          dc13_prc        : dc13 value of processes
c          avg_kex         : average kex
c
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     03.08.96   ng     first implementation
c     08.08.96   ng     included statistics and updated on entrainment
c     09.09.96   ng     adapted for lent_const
c     16.12.96   ng     included avg_kex
c     17.10.99   ng      adapted for interannual variability run, ATTENTION
c                        time units have changed from d-1 to yr-1
c     06.06.00   ng     added comp_fco2_online
cc 
c =====================================================================
c
      subroutine write_std_output(unit,
     $     notes,exp_name,
     $     tstart,tend,ts, 
     $     sol_scheme,
     $     dc13_coeff,
     $     pv_relship,D_fco2_corr,gasex_fact,ws_coeff,
     $     comp_fco2_online,
     $     ent_scheme,h_coeff,h_th,c_th,dc13_th,
     $     dt_ent_re,const_lent,lent_const,dlent_dh,ent_fact,
     $     const_Kz,Kz_const,
     $     const_vertgrad,dCdz_const,
     $     ddC13_dC_bml,diff_fact,
     $     incl_adv,dC_dh,ddC13_dh,u,
     $     D_dc13_org,
     $     int_rates,int_fluxes,nyears,
     $     chisq,rsq,closure,costfn,avg_fract,dc13_prc,avg_kex,
     $     error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 124 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 125 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 126 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 127 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 128 "write_std_output.F" 2
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/gasex_params.h" 1
c===================== include file gasex_params.h =========================
c
c parameters of air-sea exchange
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 06.6.00  ng        added comp_foc2_online
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c 
c pv_relship     c  s   character indicating the relationship between
c                       piston velocity and wind-speed that is used for
c                       calculating the piston-velocity
c                           <lm> : Liss and Merlivat
c                           <wa> : Wanninkhof  
c D_fco2_corr    dp s   correction term for calculated fCO2 ocean     [uatm]
c gasex_fact     dp s   multiplication factor for air-sea exchange
c                           usually 1.0 for Wanninkhof
c                           usually 1.7447 for Liss and Merlivat
c
c ws_coeff       c  s   character specifying wind speed coefficients
c                           <ih> : Isemer and Hasse, 1985
c                           <ae> : AEROCE, 1989-1991
c
c sg_D_fco2_corr dp a   uncertainty of D_fco2_corr
c sg_gasex_fact  dp a   uncertainty of gasex_fact
c
c mean_air_press dp s   mean air pressure [atm] (from St. Davids head)
c mean_rel_humid dp s   mean relative humidity [] (from St. Davids head)
c 
c comp_fco2_online l s  logical indicating whether fco2 should be
c                         computed on or offline
c
c===========================================================================
c
      character pv_relship*2,ws_coeff*2
      double precision D_fco2_corr,gasex_fact
      double precision sg_D_fco2_corr, sg_gasex_fact
c
      double precision mean_air_press,mean_rel_humid




      parameter (mean_air_press = 1.017,mean_rel_humid = 0.87)

c
      logical comp_fco2_online
# 130 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 131 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 132 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncp_params.h" 1
c===================== include file ncp_params.h =========================
c
c parameters of net community production
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c D_dC13_org      dp s   correction term for dC13 value of organic matter
c dc13_org        dp s   dc13 value of organic matter
c                         [per mil]
c sg_D_dc13_org   dp s   1 sigma uncertainty of D_dc13_org (for OP and MC)
c 
c=============================================================================
c
      double precision D_dc13_org
      double precision sg_D_dc13_org
      double precision dc13_org
# 133 "write_std_output.F" 2
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 135 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 136 "write_std_output.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/statistics.h" 1
c==================== include file statistics.h ==============================
c
c variables for the run statistics
c
c REVISIONS:
c
c date     author    remarks
c
c 08.8.96  ng        first implementation
c 05.9.96  ng        included c_min,c_max,c_min_obs,c_max_obs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c chisq         dp s   chi**2 between simulated and observed rate of change
c rsq           dp s   r**2 of fit between simulated and observed rates
c closure       dp s   annual lack of closure
c amplitude     dp s   simulated annual amplitude
c amplitude_obs dp s   observed annual amplitude
c c_min         dp s   simulated minimum C
c c_max         dp s   simulated maximum C
c c_min_obs     dp s   observed minimum C
c c_max_obs     dp s   observed maximum C
c par_sum       dp s   value of parameter misfit
c costfn        dp s   value of cost function
c chisq_term    dp s   value of chi**2 term in cost function
c clos_term     dp s   value of closure term in cost function
c ampl_term     dp s   value of amplitude term in cost function
c par_term      dp s   value of parameter term in cost function
c
c-------------------------------------------------------------------------
c
      double precision chisq,rsq,closure,costfn,amplitude
      double precision amplitude_obs,par_sum
      double precision c_min,c_max,c_min_obs,c_max_obs
      double precision chisq_term,clos_term,ampl_term,par_term



# 137 "write_std_output.F" 2

      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer i,ny,colons,i1,i2,ii,jmax
      character date*17
      real avg_int_fluxes(nproc_fluxes)
      real avg_int_rates(nproc_rates)
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      error = .false.
c
c ---------------------------------------------------------------------
c     write general information 
c ---------------------------------------------------------------------
c
      if (unit .ne. 6) then
         write(unit,9000) 
 9000    format(//'------------------------------------------',
     $            '---------',/
     $            ' Results of diagnostic box model',/
     $            '    of the interannual carbon cycle at ',/





     $            '    Station HOT (HAWI data) ',//



     $            '    written by Nicolas Gruber, Oct. 1999 ',/
     $            '    this is version 4.0 ',//
     $            '------------------------------------------',
     $            '--------'/)
c
      endif
c
c ---------------------------------------------------------------------
c     get date
c ---------------------------------------------------------------------
c
      call getdate(date)
c
c ---------------------------------------------------------------------
c     write general specification of this run
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A)')' general specifications for this model run :'
      write(unit,'(2A)')    '   date               : ',date
      write(unit,'(2A)')    '   name of experiment : ',exp_name 
      write(unit,'(A,F7.2)')'   start time         : ',tstart
      write(unit,'(A,F7.2)')'   end time           : ',tend
      write(unit,'(A,F7.4)')'   time step (years)  : ',ts
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' specifications for location :'





      write(unit,'(A)')     '   Station HOT (HAWI data) '



c
c ---------------------------------------------------------------------
c     write specification for solution scheme
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)')' specifications for solution scheme :'
c
      if (sol_scheme .eq. 'std') then
         write(unit,'(2A)') '   Standard (original) solution scheme ',
     $        'used, i.e. dC/dt is solved for'
      elseif (sol_scheme .eq. 'adv') then
         write(unit,'(2A)') '   Advection solution scheme used, ',
     $        'i.e. u is solved for'
      endif
c
c ---------------------------------------------------------------------
c     write specification for air-sea gasexchange
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)')' specifications for air-sea gasexchange :'
c
      if (pv_relship .eq. 'wa') then
         write(unit,'(2A)') '   Wanninkhof (1992) quadratic ',
     $        'piston velocity relationship used'
      elseif (pv_relship .eq. 'lm') then
         write(unit,'(2A)') '   Liss and Merlivat (1987) linear ',
     $        'piston velocity relationship used'
      endif
c         
      write(unit,'(A,F8.2)')'   correction term for fCO2 oc [uatm]) :', 
     $     D_fCO2_corr
      write(unit,'(2A,F7.4)')'   multiplication factor for air-sea ', 
     $     'gasexchange : ',gasex_fact
c
      if (ws_coeff .eq. 'ih') then
         write(unit,'(2A)')  '   wind-speed coefficients of Isemer',
     $        ' and Hasse'
      elseif (ws_coeff .eq. 'ae') then
         write(unit,'(A)')  '   wind-speed coefficients of AEROCE'
      endif
c
      if (comp_fco2_online) then
         write(unit,'(2A)')  '   fCO2 has been computed on-line ',
     $        'on the basis of T, S, DIC and Alk'
      else
         write(unit,'(A)')   '   fCO2 has been given as an input' 
      endif
         
c
c ---------------------------------------------------------------------
c     write specification for vertical processes
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' specifications for vertical diffusion',
     $     ' and entrainment :'
c
c
      if (ent_scheme .eq.  'mc') then
c
         write(unit,'(A)') 
     $    '     mass conservation entrainment scheme '
         write(unit,'(A,F6.1)') 
     $        '     depth where thermocline values are taken : ',h_th
         write(unit,'(A,F6.1)')
     $        '     C concentration at this depth : ',c_th
         write(unit,'(A,F6.2)')
     $        '     dC13 value at this depth      : ',dc13_th
c
      elseif (ent_scheme .eq. 'ep') then
         write(unit,'(A)')
     $        '     episodic event entrainment scheme '
         write(unit,'(A,F6.1)')   
     $        '     entrainment recurrence period : ', dt_ent_re
c     
      elseif (ent_scheme .eq. 'in') then
         write(unit,'(A)')
     $        '     integrated vertical gradient scheme '
      elseif (ent_scheme .eq. 'ma') then
         write(unit,'(A)')
     $        '     Matear (1995) entrainment scheme '
         if (const_lent) then
            write(unit,'(A,F6.1)')
     $           '     constant entrainment length : ',lent_const
         else
            write(unit,'(A/,2A,F6.4)')
     $           '     variable entrainment length ',
     $           '     ratio of entrainment length to ',
     $           'mixed layer depth : ',dlent_dh
         endif
      endif
c
      if (h_coeff .eq. 's') then
         write(unit,'(A)') 
     $        '     h coefficients from station S (1981-89)'
      elseif (h_coeff .eq. 'b') then
         write(unit,'(A)')
     $        '     h coefficients from BATS (1991-94)'
      elseif (h_coeff .eq. 'c') then
         write(unit,'(A)')
     $        '     h coefficients from BATS CTD (1989-93)'
      elseif (h_coeff .eq. 'a') then
         write(unit,'(A)')
     $        '     h coefficients from avg BATS CTD (1989-93)'
      endif
c
      write(unit,'(A,F5.2)')
     $    '     multiplication factor for entrainment : ',ent_fact
c
      if (const_kz) then
         write(unit,'(A,e10.3)') 
     $    '     seasonally constant Kz : ',kz_const
      else
         write(unit,'(A)')
     $    '     seasonally varying Kz '
      endif
c
      if (ent_scheme .ne. 'mc') then
c
         if (const_vertgrad) then
            write(unit,'(A,f7.3)') 
     $           '     seasonally constant dC/dz [umol kg-1 m-1 : ',
     $           dCdz_const
         else
            write(unit,'(A)')
     $           '     seasonally varying dC/dz'
         endif
c
         write(unit,'(A,/A,f10.5)')
     $        '     ratio of vertical dC13 and C gradients ',
     $        '     below the mixed layer [per mil kg umol-1] : ',
     $        ddC13_dC_bml
c
      endif
c
      write(unit,'(A,F5.2)')
     $    '     multiplication factor for vertical diffusion : ',
     $     diff_fact
c
c ---------------------------------------------------------------------
c     write specification for advection
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' specifications for horizontal advection :'
c
      if (incl_adv) then
         if (sol_scheme .eq. 'std') then
            write(unit,'(A,F6.2)')
     $           '     horizontal velocity [m s-1]            : ',u
         endif
c
         write(unit,'(A,E10.4)')
     $        '     horizontal C gradient [umol kg-1 m-1]  : ',
     $        dC_dh
c
         write(unit,'(A,E10.4)')
     $        '     horizontal dC13 gradient [per mil m-1] : ',
     $        ddC13_dh
      else
         write(unit,'(A)')
     $        '     horizontal advection not included : '
      endif
c
c ---------------------------------------------------------------------
c     write specification for net community production
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)')' specification for ',
     $     'net community production :'
      write(unit,'(A,F6.2)')
     $    '     change in dC13 of organic matter : ',D_dc13_org
c
c ---------------------------------------------------------------------
c     write additional comments
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A/)') ' Additional comments : ',notes
c
c ---------------------------------------------------------------------
c     write statistics
c ---------------------------------------------------------------------
c
      if (sol_scheme .eq. 'std') then
         write(unit,9800)
c     
c     







         write(unit,'(/A/)') ' run statistics : '
         write(unit,'(A,F8.4)') '    chi**2 (rates)         : ',
     $        chisq
         write(unit,'(A,F6.4)') '    r**2 (rates)           : ',
     $        rsq

         write(unit,'(A,F6.2)') '    annual lack of closure : ',
     $        closure
         write(unit,'(A,F10.8)') '    cost function (w/o par): ',
     $        costfn
      endif
c
c ---------------------------------------------------------------------
c     write dc13 values of processes
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' mean delta 13C values of processes : '
c
      do i = 1,4
         write(unit,'(A,a3,f9.2)') proc_rates_name(i),' : ',dc13_prc(i)
      enddo
      write(unit,'(A,a3,f9.2)') proc_rates_name(i),' : ',avg_fract
c
c ---------------------------------------------------------------------
c     write dc13 values of processes
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/2A,E12.5)') ' annual mean kex ',
     $     '[mol m-2 s-1 uatm-1] : ',
     $     avg_kex
c
c ---------------------------------------------------------------------
c     write integrated fluxes
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' Integrated fluxes [mol m-2]'

      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
         do i=1,nproc_fluxes
            write(unit,9200) proc_fluxes_name(i),
     $        (int_fluxes(ny,i), ny=i1,i2)
         enddo
c
         write(unit,'(//)')
      enddo
c
c ---------------------------------------------------------------------
c     compute and write average fluxes
c ---------------------------------------------------------------------
c
      do i = 1,nproc_fluxes
         avg_int_fluxes(i) = 0.d0
      enddo

      do ny = 1,nyears
         do i = 1,nproc_fluxes
            avg_int_fluxes(i) = avg_int_fluxes(i)+int_fluxes(ny,i)
         enddo
      enddo
c
      do i = 1,nproc_fluxes
         avg_int_fluxes(i) = avg_int_fluxes(i)/nyears
      enddo
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' Average Integrated fluxes [mol m-2]'
c
      write(unit,'(A)') '         Average'
      do i=1,nproc_fluxes
         write(unit,9200) proc_fluxes_name(i),avg_int_fluxes(i)
      enddo
c

c
c ---------------------------------------------------------------------
c     compute and write anomaly fluxes
c ---------------------------------------------------------------------
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' Anomalies of Integrated Fluxes [mol m-2]'

      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
         do i=1,nproc_fluxes
            write(unit,9200) proc_fluxes_name(i),
     $        ((int_fluxes(ny,i)-avg_int_fluxes(i)), ny=i1,i2)
         enddo
c
         write(unit,'(//)')
      enddo
      
      write(unit,9800)
c
c ---------------------------------------------------------------------
c     write integrated rates
c ---------------------------------------------------------------------
c

      write(unit,'(/A/)') ' Integrated rates [umol kg-1]'
c
      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
         do i=1,nproc_rates
            write(unit,9300) proc_rates_name(i),
     $        (int_rates(ny,i), ny=i1,i2)
         enddo
c
         write(unit,'(//)')
      enddo
c
c ---------------------------------------------------------------------
c     compute and write average rates
c ---------------------------------------------------------------------
c
      
      do i = 1,nproc_rates
         avg_int_rates(i) = 0.0d0
      enddo


      do ny = 1,nyears
         do i = 1,nproc_rates
            avg_int_rates(i) = avg_int_rates(i)+int_rates(ny,i)
         enddo
      enddo
c
      do i = 1,nproc_rates
         avg_int_rates(i) = avg_int_rates(i)/nyears
      enddo
c
      write(unit,9800)
c
      write(unit,'(/A/)') ' Average Integrated rates [umol/kg]'
c
      write(unit,'(A)') '         Average'
      do i=1,nproc_rates
         write(unit,9200) proc_rates_name(i),avg_int_rates(i)
      enddo
c
      write(unit,9800)
c
c ---------------------------------------------------------------------
c     write integrated rate anomalies
c ---------------------------------------------------------------------
c

      write(unit,'(/A/)') ' Anomalies of integrated rates [umol kg-1]'
c
      colons = 5
      jmax = (nyears-1)/colons + 1
      do ii=1,nyears,colons
         i1 = ii
         i2 = min((ii+colons-1),nyears)
c         
         write(unit,9100) (int(tstart)+ny-1, ny=i1,i2)
         do i=1,nproc_rates
            write(unit,9300) proc_rates_name(i),
     $        ((int_rates(ny,i)-avg_int_rates(i)), ny=i1,i2)
         enddo
c
         write(unit,'(//)')
      enddo
c
c ---------------------------------------------------------------------
c     output to files for plotting
c       changed output to be centered at 0.5
c ---------------------------------------------------------------------
c
      open(30,file="int_rate_anomalies.set")
      do ny = 1,nyears
         write(30,9500) 
     $        int(tstart)+ny-0.5,
     $        ((int_rates(ny,i)-avg_int_rates(i)), i=1,nproc_rates)
      enddo
      close(30)
      open(32,file="int_flux_anomalies.set")
      do ny = 1,nyears
         write(32,9550) 
     $        int(tstart)+ny-0.5,
     $        ((int_fluxes(ny,i)-avg_int_fluxes(i)), i=1,nproc_fluxes)
      enddo
      close(32)
 9500 format(f9.3,1x,20(f8.2,1x))
 9550 format(f9.3,1x,20(f10.4,1x))
      
c
c ---------------------------------------------------------------------
c     format statements
c ---------------------------------------------------------------------
c
 9800 format(/'-------------------------------------------------')
c
 9100 format(2x,'year',20(7x,i4))
 9200 format(2x,a4,20(1x,F10.4))
 9300 format(2x,a4,20(3x,F8.2))
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
c      write(*,*) '--WRITE_STD_OUTPUT: returning...'
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--WRITE_OUTPUT: an error occurred while writing..'
      error = .true.
c
      return

      end











