# 1 "cost_function.F"
c =====================================================================
c
c     DOUBLE PRECISION FUNCTION COST_FUNCTION
c
c     PURPOSE: this is the routine which calculates the value of
c                the cost function from the different terms
c     
c     VARIABLES:
c 
c     IN:   chisq         : value of chi**2
c           closure       : value of annual lack of closure
c           par_sum       : value of sum of parameter deviations
c           np            : number of parameters
c           amplitude     : value of simulated amplitude
c           amplitude_obs : value of observed amplitude
c           c_min         : value of minimum C
c           c_max         : value of maximum C
c           c_min_obs     : value of observed minimum C
c           c_max_obs     : value of observed maximum C
c     OUT:  cost_function : value of cost function
c           chisq_term    : value of chi**2 term
c           clos_term     : value of closure term
c           par_term      : value of parameter term
c           ampl_term     : value of amplitude term
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     14.08.96   ng     first implementation
c      5.09.96   ng     changed definition of cost function, introduced
c                        c_min,c_max,c_min_obs,c_max_obs
c     10.06.97   ng    included preprocessor option reviewer_costfn,
c                        (calculates chisq as deviations from C rather
c                         than D_C)
cc 
c =====================================================================
c
      double precision function cost_function(
     $     chisq,closure,par_sum,np,
     $     amplitude,amplitude_obs,
     $     c_min,c_max,c_min_obs,c_max_obs,
     $     chisq_term,clos_term,par_term,ampl_term)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none

# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/statistics.h" 1
c==================== include file statistics.h ==============================
c
c variables for the run statistics
c
c REVISIONS:
c
c date     author    remarks
c
c 08.8.96  ng        first implementation
c 05.9.96  ng        included c_min,c_max,c_min_obs,c_max_obs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c chisq         dp s   chi**2 between simulated and observed rate of change
c rsq           dp s   r**2 of fit between simulated and observed rates
c closure       dp s   annual lack of closure
c amplitude     dp s   simulated annual amplitude
c amplitude_obs dp s   observed annual amplitude
c c_min         dp s   simulated minimum C
c c_max         dp s   simulated maximum C
c c_min_obs     dp s   observed minimum C
c c_max_obs     dp s   observed maximum C
c par_sum       dp s   value of parameter misfit
c costfn        dp s   value of cost function
c chisq_term    dp s   value of chi**2 term in cost function
c clos_term     dp s   value of closure term in cost function
c ampl_term     dp s   value of amplitude term in cost function
c par_term      dp s   value of parameter term in cost function
c
c-------------------------------------------------------------------------
c
      double precision chisq,rsq,closure,costfn,amplitude
      double precision amplitude_obs,par_sum
      double precision c_min,c_max,c_min_obs,c_max_obs
      double precision chisq_term,clos_term,ampl_term,par_term



# 52 "cost_function.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/sg_params.h" 1
c===================== include file sg_params.h =========================
c
c variables defining special uncertainties
c
c REVISIONS:
c
c date     author    remarks
c
c 13.8.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c sg_c          dp  s   1-sigma uncertainty of C [umol kg-1]
c sg_dcdt       sp  s   1-sigma uncertainty of dcdt [umol kg-1 day-1]
c                          (estimated from figure)
c
c===========================================================================
c
      double precision sg_c,sg_dcdt
      parameter(sg_c = 2.d0, sg_dcdt = 0.02d0)
      
# 53 "cost_function.F" 2
      integer np
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c 
      double precision scale_fact



      parameter (scale_fact = 1.d-3)

c
      double precision chisq_weight,clos_weight
      double precision par_weight,ampl_weight
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c --------------------------------------------------------------------
c     determine weight of different terms
c --------------------------------------------------------------------
c 






      chisq_weight = 1.d0/365.d0
      clos_weight = 1.d0
      par_weight = 1.d0
      ampl_weight = 1.0

c
c --------------------------------------------------------------------
c     calculate different terms
c --------------------------------------------------------------------
c 



      chisq_term = scale_fact * chisq_weight * chisq/((sg_dcdt)**2)

      clos_term = scale_fact * clos_weight * (closure/sg_c)**2
      par_term = scale_fact * par_weight * par_sum
c      ampl_term = scale_fact * ampl_weight * 
c     $     ((amplitude - amplitude_obs)/sg_c)**2
      ampl_term = scale_fact * ampl_weight *
     $     ((c_min - c_min_obs)**2 + (c_max - c_max_obs)**2)/(sg_c)**2
c
c --------------------------------------------------------------------
c     calculate total cost function
c --------------------------------------------------------------------
c 
      cost_function = chisq_term + clos_term + par_term + ampl_term
c
c         write(*,*) '--COST_FUNCTION: value of cost : ',cost_function
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return

      end











