# 1 "generate_mc_ncar_plots.F"
c =====================================================================
c
c     SUBROUTINE GENERATE_MC_NCAR_PLOTS
c 
c     PURPOSE: this is the routine for creating ncar plots of the
c                 results of the monte carlo runs. 
c
c     VARIABLES:
c 
c     IN : nrun            : number of total monte carlo runs
c          tstart          : start time of integration
c          tend            : end time of integration
c          ts              : time step
c          nstep           : number of steps
c          D_c_std         : rates of change of the different processes
c          fluxes_std      : fluxes of the different processes
c          c_sim_std       : simulated seasonal cycle of c
c          c_obs           : observed seasonal cycle of C
c          exp_name        : experiment name
c          notes           : notes
c
c          mean_d_c        : mean d_c of mc runs
c          mean_fluxes     : mean fluxes of mc runs
c          mean_c_sim      : mean c_sim of mc runs
c          wmean_d_c       : weighted mean d_c of mc runs
c          wmean_fluxes    : weighted mean fluxes of mc runs
c          wmean_c_sim     : weighted mean c_sim of mc runs
c          sg_d_c          : 1-sg uncertainty of d_c
c          sg_fluxes       : 1-sg uncertainty of fluxes
c          sg_c_sim        : 1-sg uncertainty of c_sim
c          wsg_d_c         : weighted 1-sg uncertainty of d_c
c          wsg_fluxes      : weighted 1-sg uncertainty of fluxes
c          wsg_c_sim       : weighted 1-sg uncertainty of c_sim
c          nstep2          : number of samples in sg* arrays
c          rsmpl_step      : resampling time step of sg* arrays
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISION:
c
c     date     author  remarks
c   
c     19.08.96   ng    first implementation based on generate_ncar_plots
c     17.10.99   ng    adapted for interannual variability run, ATTENTION
c                        time units have changed from d-1 to yr-1
c
c =====================================================================
c
      subroutine generate_mc_ncar_plots(nrun,
     $     tstart,tend,ts,nstep,
     $     D_C_std,fluxes_std,c_sim_std,c_obs,
     $     mean_d_c,mean_fluxes,mean_c_sim,
     $     wmean_d_c,wmean_fluxes,wmean_c_sim,
     $     sg_D_c,sg_fluxes,sg_c_sim,
     $     wsg_D_c,wsg_fluxes,wsg_c_sim,
     $     nstep2,rsmpl_step,
     $     exp_name,notes)
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
      implicit none
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 66 "generate_mc_ncar_plots.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 67 "generate_mc_ncar_plots.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 68 "generate_mc_ncar_plots.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 69 "generate_mc_ncar_plots.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/monte_carlo.h" 1
c===================== include file monte_carlo.h =========================
c
c general variables for monte carlo simulations
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c  
c nrunmax       i  s   maximal number of mc runs             
c nrun          i  s   number of mc runs
c
c *_r          dp  s   parameters with a random component added. size of
c                        random component is proportional to sg of this
c                        parameter. For the parameter definitions see
c                        the *_params.h files 
c 
c
c===========================================================================
c
      integer nrunmax,nrun
      parameter(nrunmax = 2000)
      
      double precision gasex_fact_r,D_fco2_corr_r
      double precision diff_fact_r,D_dcdz_r,ddC13_dC_bml_r,lent_const_r
      double precision dlent_dh_r
      double precision D_dc13_org_r
      double precision u_r,dc_dh_r,ddc13_dh_r
c
# 70 "generate_mc_ncar_plots.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_plot_slabs.h" 1
c================== include file mc_plot_slabs.h =========================
c
c variables that contain plot information for monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c
c variables:
c
c name                type   description
c---------------------------------------------------------------------------
c  		      
c nstepmax2           i  s   maximum number of values on time axis
c nstep               i  s   number of resampled values
c rsmpl_step          i  s   every i'th sample is resampled
c mc_D_c              dp a   array of resampled D_C array for mc analysis
c mc_fluxes           dp a   array of resampled fluxes array for mc analysis
c mc_c_sim            dp a   array of resampled c_sim array for mc analysis
c mc_u_var            dp a   array of resampled inverse calc u
c mc_ddc13_dh_var     dp a   array of resampled inverse calc ddC13_dh
c mean_D_c            dp a   mean D_C of mc runs
c mean_fluxes         dp a   mean fluxes of mc runs
c mean_c_sim          dp a   mean c_sim of mc runs
c mean_u_var          dp a   mean u_var
c mean_ddc13_dh_var   dp a   mean ddc13_dh_var
c wmean_D_c           dp a   weighted mean D_C of mc runs
c wmean_fluxes        dp a   weighted mean fluxes of mc runs
c wmean_c_sim         dp a   weighted mean c_sim of mc runs
c wmean_u_var         dp a   weighted mean u_var
c wmean_ddc13_dh_var  dp a   weighted mean ddc13_dh_var
c sg_D_c              dp a   1-sg uncertainty of D_C
c sg_fluxes           dp a   1-sg uncertainty of fluxes
c sg_c_sim            dp a   1-sg uncertainty of c_sim
c sg_u_var            dp a   1-sg uncertainty of u_var
c sg_ddc13_dh_var     dp a   1-sg uncertainty of ddc13_dh_var
c wsg_D_c             dp a   weighted 1-sg uncertainty of D_C
c wsg_fluxes          dp a   weighted 1-sg uncertainty of fluxes
c wsg_c_sim           dp a   weighted 1-sg uncertainty of c_sim
c wsg_u_var           dp a   weighted 1-sg uncertainty of u_var
c wsg_ddc13_dh_var    dp a   weighted 1-sg uncertainty of ddc13_dh_var
c c_sim_std           dp a   array holding c_sim of standard simulation
c fluxes_std          dp a   array holding fluxes of standard simulation
c d_c_std             dp a   array holding d_c of standard simulation
c u_var_std           dp a   array holding inv. calc. u of std simulation
c ddc13_dh_std        dp a   array holding inv. calc. ddc13_dh of std sim.
c
c                                 to the different proc.                mol C/m2/s
c D_C_std_runavg    dp a   one year running standard Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_std_runavg dp a   one year running standard Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
cc 
c===========================================================================
c
      integer nstepmax2,nstep2,rsmpl_step
      parameter(nstepmax2 = 200)
c
      double precision mc_D_c(nrunmax,nproc_rates,nstepmax2)
      double precision mc_fluxes(nrunmax,nproc_fluxes,nstepmax2)
      double precision mc_c_sim(nrunmax,nstepmax2)
      double precision mean_D_c(nproc_rates,nstepmax2)
      double precision mean_fluxes(nproc_fluxes,nstepmax2)
      double precision mean_c_sim(nstepmax2)
      double precision wmean_D_c(nproc_rates,nstepmax2)
      double precision wmean_fluxes(nproc_fluxes,nstepmax2)
      double precision wmean_c_sim(nstepmax2)
      double precision sg_D_c(nproc_rates,nstepmax2)
      double precision sg_fluxes(nproc_fluxes,nstepmax2)
      double precision sg_c_sim(nstepmax2)
      double precision wsg_D_c(nproc_rates,nstepmax2)
      double precision wsg_fluxes(nproc_fluxes,nstepmax2)
      double precision wsg_c_sim(nstepmax2)
      double precision mc_weight(nrunmax)
      double precision c_sim_std(nstepmax)
      double precision d_c_std(nproc_rates,nstepmax)
      double precision fluxes_std(nproc_fluxes,nstepmax)
c
      double precision mc_u_var(nrunmax,nstepmax2)
      double precision mc_ddc13_dh_var(nrunmax,nstepmax2)
      double precision mean_u_var(nstepmax2)
      double precision mean_ddc13_dh_var(nstepmax2)
      double precision wmean_u_var(nstepmax2)
      double precision wmean_ddc13_dh_var(nstepmax2)
      double precision sg_u_var(nstepmax2)
      double precision sg_ddc13_dh_var(nstepmax2)
      double precision wsg_u_var(nstepmax2)
      double precision wsg_ddc13_dh_var(nstepmax2)
      double precision u_var_std(nstepmax)
      double precision ddc13_dh_var_std(nstepmax)
c
      double precision fluxes_std_runavg(nproc_fluxes,nstepmax), 
     $     D_C_std_runavg(nproc_rates,nstepmax)
      double precision mean_d_c_runavg(nproc_rates,nstepmax2),
     $        sg_D_c_runavg(nproc_rates,nstepmax2),       
     $        mean_fluxes_runavg(nproc_fluxes,nstepmax2),
     $        sg_fluxes_runavg(nproc_fluxes,nstepmax2)   

# 71 "generate_mc_ncar_plots.F" 2

# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/plot_sets.h" 1
c===================== include file plotsets.h ===========================
c
c variables containing the values for plotting
c
c REVISIONS:
c
c date     author    remarks
c
c 05.08.96  ng       first implementation
c
c variables:
c
c name           type   description
c---------------------------------------------------------------------
c
c xvalplot       r  a   two dim array holding the x-values to be 
c                        plotted (xvalplot(nsets,ntraplot))  
c yvalplot       r  a   two dim array holding the y-values to be  
c                        plotted (yvalplot(nsets,ntraplot))
c nvalplotmax    i  s   maximum number of points to plot per set
c nvalplot       i  a   one dim array holding the sizes of the sets 
c                        to be plotted
c nsetmax        i  s   maximum number of sets
c nsets          i  s   number of sets  
c
c=====================================================================
c
      integer nvalplotmax,nsetmax,nsets
      parameter(nvalplotmax = 8000,nsetmax = 15)
c
      real xvalplot(nsetmax,nvalplotmax)
      real yvalplot(nsetmax,nvalplotmax)
c
      integer nvalplot(nsetmax)

# 73 "generate_mc_ncar_plots.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncar.h" 1
c===================== include file ncar.h ===========================
c
c variables for NCAR plotting
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c
c plottype      c  s   character specifying plottype 
c                       'sa' : seasonal plot
c                       'ts' : timeseries plot
c
c xautoscale    l  s   logical specifying the use of xplot given by user
c yautoscale    l  s   logical specifying the use of yplot given by user
c yplot         r  s   extrema of y-axis to be plotted
c xplot         r  s   extrema of x-axis to be plotted
c
c colored       l  s   logical specifying if color are used
c
c nticks        i  a   two dimensional array holding the number of tick
c                        marks nticks(axis,type)
c                        dir:   1: x-axis; 2: y-axis
c                        type:  1: major ; 2: minor
c
c tickformat    c  a   array of character holding the tick formats
c
c legend        l  s   logical specifying if a legend is drawn
c legendpos     r  a   array holding the coordinates of the legend
c                        (fractional position within the viewport)
c legendlabel   c  a   array holding the legendlabels
c
c axislabel     c  a   array holding the x- and y-axis labels
c title         c  s   title of plot
c subtitle      c  s   subtitle of plot
c auto_style    l  s   logical indicating if user or automated style for
c                        color and dash pattern of lines is used
c line_color    i  a   array holding colors of lines
c line_dashpat  i  a   array holding dashpatterns
c
c=====================================================================
c
      character plottype*2
      character tickformat(2)*7
      character axislabel(2)*40
      real yplot(2),xplot(2)
c
      logical xautoscale,yautoscale,colored
c
      logical legend
      character legendlabel(nsetmax)*30
      real legendpos(2)
c
      integer nticks(2,2)
c
      character title*50,subtitle*50
c
      logical auto_style
      integer line_color(nsetmax),line_dashpat(nsetmax)
# 74 "generate_mc_ncar_plots.F" 2
c
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      character datum*17,datestring*25
c
      real vpl,vpr,vpb,vpt,wdl,wdr,wdb,wdt
c
      integer ls,i,k,k2,nr,l
c
      real xposl(1),xposr(1),ypost(1),yposb(1)
      data xposl(1),xposr(1),yposb(1),ypost(1) /0.15,0.95,0.2,0.8/
c
      real xpos,ypos
c
      double precision sec_day,day_year,g_mol
      parameter (sec_day = 24.d0 * 3600.d0, g_mol = 12.01d0)
      parameter (day_year = 365.)
c
c
c
c =================== begin of executable code ========================
c
c
c ---------------------------------------------------------------------
c     Open GKS and turn clipping off
c ---------------------------------------------------------------------
c
      call opngks
      call gsclip (0)
c
c ---------------------------------------------------------------------
c     sets up a color table (only background and first foreground color)
c ---------------------------------------------------------------------
c
      call bkgroundcolor
c
c---------------------------------------------------------------------
c     determine whether seasonal or a timeseries plots
c        should be generated
c---------------------------------------------------------------------
c
      plottype = 'ts'
      xautoscale = .true.
      tickformat(1) = '(f7.0)'
c
c ====================================================================
c     plot the rates with weighted and unweighted uncertainties
c ====================================================================
c
c      write(*,*) '--GENERATE_MC_NCAR_PLOTS: plotting rates...'
c     
c---------------------------------------------------------------------
c     set xautoscale to false for the moment
c---------------------------------------------------------------------
c
      yautoscale = .true.
c     
c---------------------------------------------------------------------
c     loop over weighted and unweighted uncertainties
c---------------------------------------------------------------------
c
      do l=1,2
c
c---------------------------------------------------------------------
c     prepare the sets for plotting of the rates of change
c        convert to single precision for plotting
c---------------------------------------------------------------------
c
         nsets = 15
         do i = 1,nsets
            nvalplot(i) = nstep2
         enddo
c     
         time = tstart
         do k = 1,nstep2
            do i = 1,5
               xvalplot(i,k) = sngl(time)
               if (l .eq. 1) then
                  yvalplot(i,k) = sngl(mean_D_C(i,k)/ts)
               elseif (l .eq. 2) then
                  yvalplot(i,k) = sngl(wmean_D_C(i,k)/ts)
               endif
            enddo
            do i = 6,10
               xvalplot(i,k) = sngl(time)
               if (l .eq. 1) then
                  yvalplot(i,k) = 
     $                 sngl((mean_D_C(i-5,k)+sg_d_c(i-5,k))/ts)
               elseif (l .eq. 2) then
                  yvalplot(i,k) = 
     $                 sngl((wmean_D_C(i-5,k)+wsg_d_c(i-5,k))/ts)
               endif                  
            enddo
            do i = 11,15
               xvalplot(i,k) = sngl(time)
               if (l .eq. 1) then
                  yvalplot(i,k) = 
     $                 sngl((mean_D_C(i-10,k)-sg_d_c(i-10,k))/ts)
               elseif (l .eq. 2) then
                  yvalplot(i,k) = 
     $                 sngl((wmean_D_C(i-10,k)-wsg_d_c(i-10,k))/ts)
               endif
            enddo
            time = time + float(rsmpl_step)*ts
         enddo
c
c---------------------------------------------------------------------
c     determine the legend
c---------------------------------------------------------------------
c
         legend = .true.
         legendpos(1) = 0.05
         legendpos(2) = 0.95
         do i = 1,5
            legendlabel(i) = proc_rates_name(i)
         enddo
         do i = 6,15
            legendlabel(i) = ''
         enddo
c
c---------------------------------------------------------------------
c     determine the line and color style
c---------------------------------------------------------------------
c
         auto_style = .false.
         line_dashpat(1) = 1
         line_dashpat(2) = 2
         line_dashpat(3) = 3
         line_dashpat(4) = 4
         line_dashpat(5) = 1
         do i=6,15
            line_dashpat(i) = 2
         enddo
         line_color(1) = 2
         line_color(2) = 3
         line_color(3) = 4
         line_color(4) = 5
         line_color(5) = 6
         do i=6,15
            line_color(i) = line_color(mod(i-1,5)+1)
         enddo
c     
c---------------------------------------------------------------------
c     set other plot parameters
c---------------------------------------------------------------------
c
         colored = .true.
         tickformat(2) = '(f7.2)'
c
c---------------------------------------------------------------------
c     define viewport
c---------------------------------------------------------------------
c
         call getset(vpl,vpr,vpb,vpt,wdl,wdr,wdb,wdt,ls)
         call set(xposl(1),xposr(1),yposb(1),ypost(1),
     $        wdl,wdr,wdb,wdt,ls)
c
c---------------------------------------------------------------------
c     call routine which does the plotting 
c---------------------------------------------------------------------
c
         call plot_results(plottype,nsets,
     $        xvalplot,yvalplot,nvalplot,
     $        xautoscale,yautoscale,xplot,yplot,
     $        nticks,tickformat,
     $        legend,legendpos,legendlabel,
     $        auto_style,line_dashpat,line_color,
     $        colored)
c
c---------------------------------------------------------------------
c     draw title and axis labels
c---------------------------------------------------------------------
c
         title = 'Interannual Diagnostic Box Model (IDBM)'

         if (l .eq. 1) then
            subtitle = 'unweighted uncertainties; Exp. : '//exp_name
         elseif (l .eq. 2) then
            subtitle = 'weighted uncertainties; Exp. : '//exp_name
         endif
            
         axislabel(2) = 'dC/dt [$G$l$R$mol kg$S$-1$N$ d$S$-1$N$]'
c     
         call pcsetc('FC','$')  ! sets function code character
         call set(0.,1.,0.,1.,0.,1.,0.,1.,1)
c     
         xpos = xposl(1)+(xposr(1)-xposl(1))/2.0
         ypos = ypost(1)+(1.0 - ypost(1))/1.5
         call plchhq(xpos,ypos, title, 0.017, 0.,0.)
         xpos = xposl(1)+0.25*(xposr(1)-xposl(1))
         ypos = ypost(1)+(1.0 - ypost(1))/2.5
         call plchhq(xpos,ypos, subtitle, 0.012, 0.,-1.)
         ypos = ypost(1)+(1.0 - ypost(1))/4.0
         call plchhq(xpos,ypos, notes, 0.012, 0.,-1.)
c     
c     ypos = yposb(1)-(0.6*yposb(1))
c     call plchhq(xpos,ypos, axislabel(1), 0.012, 0., 0.)
c     
         xpos = 0.0 + 0.2*(xposl(1))
         ypos = yposb(1) + (ypost(1)-yposb(1))/2.0
         call plchhq(xpos,ypos,axislabel(2), 0.012, 90., 0.)
c     
c---------------------------------------------------------------------
c     draw date
c---------------------------------------------------------------------
c
         call pcsetc('FC','$')  ! sets function code character
         call getdate(datum)
         datestring = '(ng) '//datum
         call plchhq(.1,.03,datestring,0.007,0.,-1.)
c
c---------------------------------------------------------------------
c     advance frame
c---------------------------------------------------------------------
c
         call frame
c
c---------------------------------------------------------------------
c     end of loop
c---------------------------------------------------------------------
c
      enddo
c
c ====================================================================
c     plot the fluxes
c ====================================================================
c
c      write(*,*) '--GENERATE_MC_NCAR_PLOTS: plotting fluxes...'
c
c---------------------------------------------------------------------
c     set yautoscale to true for the moment
c---------------------------------------------------------------------
c
      yautoscale = .true.
c     
c---------------------------------------------------------------------
c     loop over weighted and unweighted uncertainties
c---------------------------------------------------------------------
c
      do l=1,2
c
c---------------------------------------------------------------------
c     prepare the sets for plotting of the rates of change
c        convert to single precision for plotting
c---------------------------------------------------------------------
c
         nsets = 15
         do i = 1,nsets
            nvalplot(i) = nstep2
         enddo
c     
         time = tstart
         do k = 1,nstep2
            do i = 1,5
               xvalplot(i,k) = sngl(time)
               if (l .eq. 1) then
                  yvalplot(i,k) = sngl(mean_fluxes(i,k) 
     $                 * sec_day * day_year * g_mol)
               elseif (l .eq. 2) then
                  yvalplot(i,k) = sngl(wmean_fluxes(i,k) 
     $                 * sec_day * day_year * g_mol)  
               endif
            enddo
            do i = 6,10
               xvalplot(i,k) = sngl(time)
               if (l .eq. 1) then
                  yvalplot(i,k) = 
     $                 sngl((mean_fluxes(i-5,k)+sg_fluxes(i-5,k))
     $                 *sec_day* day_year * g_mol)
               elseif (l .eq. 2) then
                  yvalplot(i,k) = 
     $                 sngl((wmean_fluxes(i-5,k)+wsg_fluxes(i-5,k))
     $                 *sec_day*day_year*g_mol)
               endif
            enddo
            do i = 11,15
               xvalplot(i,k) = sngl(time)
               if (l .eq. 1) then
                  yvalplot(i,k) = 
     $                 sngl((mean_fluxes(i-10,k)-sg_fluxes(i-10,k))
     $                 *sec_day*day_year*g_mol)
               elseif (l .eq. 2) then
                  yvalplot(i,k) = 
     $                 sngl((wmean_fluxes(i-10,k)-wsg_fluxes(i-10,k))
     $                 *sec_day*day_year*g_mol)
               endif
            enddo
            time = time + float(rsmpl_step)*ts
         enddo
c
c---------------------------------------------------------------------
c     determine the legend
c---------------------------------------------------------------------
c
         legend = .true.
         legendpos(1) = 0.05
         legendpos(2) = 0.95
         do i = 1,5
            legendlabel(i) = proc_fluxes_name(i)
         enddo
         do i = 6,15
            legendlabel(i) = ''
         enddo
c
c---------------------------------------------------------------------
c     determine the line and color style
c---------------------------------------------------------------------
c
         auto_style = .false.
         line_dashpat(1) = 1
         line_dashpat(2) = 2
         line_dashpat(3) = 3
         line_dashpat(4) = 4
         line_dashpat(5) = 1
         do i=6,15
            line_dashpat(i) = 2
         enddo
         line_color(1) = 2
         line_color(2) = 3
         line_color(3) = 4
         line_color(4) = 5
         line_color(5) = 6
         do i=6,15
            line_color(i) = line_color(mod(i-1,5)+1)
         enddo
c
c---------------------------------------------------------------------
c     set other plot parameters
c---------------------------------------------------------------------
c
         colored = .true.
         tickformat(2) = '(f7.2)'
c
c---------------------------------------------------------------------
c     define viewport
c---------------------------------------------------------------------
c
         call getset(vpl,vpr,vpb,vpt,wdl,wdr,wdb,wdt,ls)
         call set(xposl(1),xposr(1),yposb(1),ypost(1),
     $        wdl,wdr,wdb,wdt,ls)
c     
c---------------------------------------------------------------------
c     call routine which does the plotting 
c---------------------------------------------------------------------
c
         call plot_results(plottype,nsets,
     $        xvalplot,yvalplot,nvalplot,
     $        xautoscale,yautoscale,xplot,yplot,
     $        nticks,tickformat,
     $        legend,legendpos,legendlabel,
     $        auto_style,line_dashpat,line_color,
     $        colored)
c
c---------------------------------------------------------------------
c     draw title and axis labels
c---------------------------------------------------------------------
c
         title = 'Seasonal Diagnostic Box Model (SDBM)'
c
         if (l .eq. 1) then
            subtitle = 'unweighted uncertainties; Exp. : '//exp_name
         elseif (l .eq. 2) then
            subtitle = 'weighted uncertainties; Exp. : '//exp_name
         endif
c
         axislabel(2) = 'fluxes [gC m$S$-2$N$ d$S$-1$N$]'
c     
         call pcsetc('FC','$')  ! sets function code character
         call set(0.,1.,0.,1.,0.,1.,0.,1.,1)
c     
         xpos = xposl(1)+(xposr(1)-xposl(1))/2.0
         ypos = ypost(1)+(1.0 - ypost(1))/1.5
         call plchhq(xpos,ypos, title, 0.017, 0.,0.)
         xpos = xposl(1)+0.25*(xposr(1)-xposl(1))
         ypos = ypost(1)+(1.0 - ypost(1))/2.5
         call plchhq(xpos,ypos, subtitle, 0.012, 0.,-1.)
         ypos = ypost(1)+(1.0 - ypost(1))/4.0
         call plchhq(xpos,ypos, notes, 0.012, 0.,-1.)
c     
c     ypos = yposb(1)-(0.6*yposb(1))
c     call plchhq(xpos,ypos, axislabel(1), 0.012, 0., 0.)
c     
         xpos = 0.0 + 0.2*(xposl(1))
         ypos = yposb(1) + (ypost(1)-yposb(1))/2.0
         call plchhq(xpos,ypos,axislabel(2), 0.012, 90., 0.)
c
c---------------------------------------------------------------------
c     draw date
c---------------------------------------------------------------------
c
         call pcsetc('FC','$')  ! sets function code character
         call getdate(datum)
         datestring = '(ng) '//datum
         call plchhq(.1,.03,datestring,0.007,0.,-1.)
c
c---------------------------------------------------------------------
c     call frame
c---------------------------------------------------------------------
c
         call frame
c
c---------------------------------------------------------------------
c     end of loop
c---------------------------------------------------------------------
c
      enddo
c
c ====================================================================
c     plot the observed and simulated rates
c ====================================================================
c
c      write(*,*) '--GENERATE_MC_NCAR_PLOTS: plotting obs rates...'
c
c---------------------------------------------------------------------
c     set yautoscale to true for the moment
c---------------------------------------------------------------------
c
      yautoscale = .true.
c     
c---------------------------------------------------------------------
c     loop over weighted and unweighted uncertainties
c---------------------------------------------------------------------
c
      do l=1,2
c
c---------------------------------------------------------------------
c     prepare the sets for plotting of the rates of change
c        convert to single precision for plotting
c---------------------------------------------------------------------
c
         nsets = 4
         do i = 1,nsets
            nvalplot(i) = nstep2
         enddo
c     
         time = tstart
         do k = 1,nstep2
            xvalplot(1,k) = sngl(time)
            xvalplot(2,k) = sngl(time)
            xvalplot(3,k) = sngl(time)
            xvalplot(4,k) = sngl(time)
            yvalplot(2,k) = sngl(mean_D_C(7,k)/ts)
            if (l .eq. 1) then
               yvalplot(1,k) = sngl(mean_D_C(6,k)/ts)
               yvalplot(3,k) = sngl((mean_d_c(6,k)+sg_d_c(6,k))/ts)
               yvalplot(4,k) = sngl((mean_d_c(6,k)-sg_d_c(6,k))/ts)
            elseif (l .eq. 2) then
               yvalplot(1,k) = sngl(wmean_D_C(6,k)/ts)
               yvalplot(3,k) = sngl((wmean_d_c(6,k)+wsg_d_c(6,k))/ts)
               yvalplot(4,k) = sngl((wmean_d_c(6,k)-wsg_d_c(6,k))/ts)
            endif
            time = time + float(rsmpl_step) * ts
         enddo
c
c---------------------------------------------------------------------
c     determine the legend
c---------------------------------------------------------------------
c
         legend = .true.
         legendpos(1) = 0.05
         legendpos(2) = 0.95
         legendlabel(1) = proc_rates_name(6)
         legendlabel(2) = proc_rates_name(7)
         do i = 3,4
            legendlabel(i) = ''
         enddo
c
c---------------------------------------------------------------------
c     determine the line and color style
c---------------------------------------------------------------------
c
         auto_style = .false.
         line_dashpat(1) = 1
         line_dashpat(2) = 1
         line_dashpat(3) = 2
         line_dashpat(4) = 2
         line_color(1) = 2
         line_color(2) = 3
         line_color(3) = 2
         line_color(4) = 2
c
c---------------------------------------------------------------------
c     set other plot parameters
c---------------------------------------------------------------------
c
         colored = .true.
         tickformat(2) = '(f7.2)'
c     
c---------------------------------------------------------------------
c     define viewport
c---------------------------------------------------------------------
c
         call getset(vpl,vpr,vpb,vpt,wdl,wdr,wdb,wdt,ls)
         call set(xposl(1),xposr(1),yposb(1),ypost(1),
     $        wdl,wdr,wdb,wdt,ls)
c
c---------------------------------------------------------------------
c     call routine which does the plotting 
c---------------------------------------------------------------------
c
         call plot_results(plottype,nsets,
     $        xvalplot,yvalplot,nvalplot,
     $        xautoscale,yautoscale,xplot,yplot,
     $        nticks,tickformat,
     $        legend,legendpos,legendlabel,
     $        auto_style,line_dashpat,line_color,
     $        colored)
c
c---------------------------------------------------------------------
c     draw title and axis labels
c---------------------------------------------------------------------
c
         title = 'Seasonal Diagnostic Box Model (SDBM)'
c
         if (l .eq. 1) then
            subtitle = 'unweighted uncertainties; Exp. : '//exp_name
         elseif (l .eq. 2) then
            subtitle = 'weighted uncertainties; Exp. : '//exp_name
         endif
c
         axislabel(2) = 'dC/dt [$G$l$R$mol kg$S$-1$N$ d$S$-1$N$]'
c     
         call pcsetc('FC','$')  ! sets function code character
         call set(0.,1.,0.,1.,0.,1.,0.,1.,1)
c     
         xpos = xposl(1)+(xposr(1)-xposl(1))/2.0
         ypos = ypost(1)+(1.0 - ypost(1))/1.5
         call plchhq(xpos,ypos, title, 0.017, 0.,0.)
         xpos = xposl(1)+0.25*(xposr(1)-xposl(1))
         ypos = ypost(1)+(1.0 - ypost(1))/2.5
         call plchhq(xpos,ypos, subtitle, 0.012, 0.,-1.)
         ypos = ypost(1)+(1.0 - ypost(1))/4.0
         call plchhq(xpos,ypos, notes, 0.012, 0.,-1.)
c     
c      ypos = yposb(1)-(0.6*yposb(1))
c      call plchhq(xpos,ypos, axislabel(1), 0.012, 0., 0.)
c
         xpos = 0.0 + 0.2*(xposl(1))
         ypos = yposb(1) + (ypost(1)-yposb(1))/2.0
         call plchhq(xpos,ypos,axislabel(2), 0.012, 90., 0.)
c     
c---------------------------------------------------------------------
c     draw date
c---------------------------------------------------------------------
c
         call pcsetc('FC','$')  ! sets function code character
         call getdate(datum)
         datestring = '(ng) '//datum
         call plchhq(.1,.03,datestring,0.007,0.,-1.)
c
c---------------------------------------------------------------------
c     advance frame
c---------------------------------------------------------------------
c
         call frame
c
c---------------------------------------------------------------------
c     end of loop
c---------------------------------------------------------------------
c
      enddo
c
c ====================================================================
c     plot the observed and simulated seasonal cycle of C
c ====================================================================
c
c      write(*,*) '--GENERATE_MC_NCAR_PLOTS: plotting C and C_sim...'
c
c---------------------------------------------------------------------
c     set yautoscale to true for the moment
c---------------------------------------------------------------------
c
      yautoscale = .true.
c     
c---------------------------------------------------------------------
c     loop over weighted and unweighted uncertainties
c---------------------------------------------------------------------
c
      do l=1,2
c
c---------------------------------------------------------------------
c     prepare the sets for plotting of the rates of change
c        convert to single precision for plotting
c---------------------------------------------------------------------
c
         nvalplot(1) = nstep
         nvalplot(2) = nstep
         nvalplot(3) = nstep2
         nvalplot(4) = nstep2
         nvalplot(5) = nstep2
c
         nsets = 5
c     
         time = tstart
         do k = 1,nstep
            xvalplot(1,k) = sngl(time)
            yvalplot(1,k) = sngl(c_sim_std(k))
            xvalplot(2,k) = sngl(time)
            yvalplot(2,k) = sngl(C_obs(k))
            time = time + ts
         enddo
c     
         time = tstart
         do k = 1,nstep2
            k2 = (k-1)*rsmpl_step + 1

            xvalplot(3,k) = sngl(time)
            xvalplot(4,k) = sngl(time)
            xvalplot(5,k) = sngl(time)
            if (l .eq. 1) then
               yvalplot(4,k) = sngl(c_sim_std(k2)+sg_c_sim(nstep2))
               yvalplot(5,k) = sngl(c_sim_std(k2)-sg_c_sim(nstep2))
               yvalplot(3,k) = sngl(mean_c_sim(k))
            elseif (l .eq. 2) then
               yvalplot(3,k) = sngl(wmean_c_sim(k))
               yvalplot(4,k) = sngl(c_sim_std(k2)+wsg_c_sim(nstep2))
               yvalplot(5,k) = sngl(c_sim_std(k2)-wsg_c_sim(nstep2))
            endif
              
            time = time + float(rsmpl_step)*ts
         enddo
c
c---------------------------------------------------------------------
c     determine the legend
c---------------------------------------------------------------------
c
         legend = .true.
         legendpos(1) = 0.70
         legendpos(2) = 0.95
         legendlabel(1) = 'simulated std'
         legendlabel(2) = 'observed'
         legendlabel(3) = 'simulated mean'
         do i = 4,5
            legendlabel(i) = ''
         enddo
         
c
c---------------------------------------------------------------------
c     determine the line and color style
c---------------------------------------------------------------------
c
         auto_style = .false.
         line_dashpat(1) = 1
         line_dashpat(2) = 4
         line_dashpat(3) = 1
         line_dashpat(4) = 2
         line_dashpat(5) = 2
         line_color(1) = 3
         line_color(2) = 2
         line_color(3) = 4
         line_color(4) = 4
         line_color(5) = 4
c
c---------------------------------------------------------------------
c     set other plot parameters
c---------------------------------------------------------------------
c
         colored = .true.
         tickformat(2) = '(f7.1)'
c     
c---------------------------------------------------------------------
c     define viewport
c---------------------------------------------------------------------
c
         call getset(vpl,vpr,vpb,vpt,wdl,wdr,wdb,wdt,ls)
         call set(xposl(1),xposr(1),yposb(1),ypost(1),
     $        wdl,wdr,wdb,wdt,ls)
c
c---------------------------------------------------------------------
c     call routine which does the plotting 
c---------------------------------------------------------------------
c
         call plot_results(plottype,nsets,
     $        xvalplot,yvalplot,nvalplot,
     $        xautoscale,yautoscale,xplot,yplot,
     $        nticks,tickformat,
     $        legend,legendpos,legendlabel,
     $        auto_style,line_dashpat,line_color,
     $        colored)
c
c---------------------------------------------------------------------
c     draw title and axis labels
c---------------------------------------------------------------------
c
         title = 'Seasonal Diagnostic Box Model (SDBM)'
c
         if (l .eq. 1) then
            subtitle = 'unweighted uncertainties; Exp. : '//exp_name
         elseif (l .eq. 2) then
            subtitle = 'weighted uncertainties; Exp. : '//exp_name
         endif
c
         axislabel(2) = 'C [$G$l$R$mol kg$S$-1$N$]'
c     
         call pcsetc('FC','$')  ! sets function code character
         call set(0.,1.,0.,1.,0.,1.,0.,1.,1)
c     
         xpos = xposl(1)+(xposr(1)-xposl(1))/2.0
         ypos = ypost(1)+(1.0 - ypost(1))/1.5
         call plchhq(xpos,ypos, title, 0.017, 0.,0.)
         xpos = xposl(1)+0.25*(xposr(1)-xposl(1))
         ypos = ypost(1)+(1.0 - ypost(1))/2.5
         call plchhq(xpos,ypos, subtitle, 0.012, 0.,-1.)
         ypos = ypost(1)+(1.0 - ypost(1))/4.0
         call plchhq(xpos,ypos, notes, 0.012, 0.,-1.)
c     
c      ypos = yposb(1)-(0.6*yposb(1))
c      call plchhq(xpos,ypos, axislabel(1), 0.012, 0., -1.)
c
         xpos = 0.0 + 0.2*(xposl(1))
         ypos = yposb(1) + (ypost(1)-yposb(1))/2.0
         call plchhq(xpos,ypos,axislabel(2), 0.012, 90., 0.)
c
c---------------------------------------------------------------------
c     draw date
c---------------------------------------------------------------------
c
         call pcsetc('FC','$')  ! sets function code character
         call getdate(datum)
         datestring = '(ng) '//datum
         call plchhq(.1,.03,datestring,0.007,0.,-1.)
c
c---------------------------------------------------------------------
c     advance frame
c---------------------------------------------------------------------
c     
         call frame
c
c---------------------------------------------------------------------
c     end of loop
c---------------------------------------------------------------------
c     
      enddo
c
c---------------------------------------------------------------------
c     close frame and close GKS if last run
c---------------------------------------------------------------------
c
      call clsgks
c
c---------------------------------------------------------------------
c     return to calling routine
c---------------------------------------------------------------------
c
      return
c
c
c---------------------------------------------------------------------
c     error handling
c---------------------------------------------------------------------
c
 9900 write(*,9910)
 9910 format(//'An error occured.')
      return

      end
